@@ -477,6 +477,12 @@ horizon.d3_line_chart = {
         var hoverDetail = new Rickshaw.Graph.HoverDetail({
           graph: graph,
           formatter: function(series, x, y) {
+            if(y % 1 === 0) {
+              y = parseInt(y);
+            } else {
+              y = parseFloat(y).toFixed(2);
+            }
+
             var d = new Date(x * 1000);
             // Convert datetime to YYYY-MM-DD HH:MM:SS GMT
             var datetime_string = d.getUTCFullYear() + "-" +
@@ -488,8 +494,7 @@ horizon.d3_line_chart = {
 
             var date = '<span class="date">' + datetime_string + '</span>';
             var swatch = '<span class="detail_swatch" style="background-color: ' + series.color + '"></span>';
-            var content = swatch + series.name + ': ' + parseFloat(y).toFixed(2) + ' ' + series.unit + '<br>' + date;
-            return content;
+            return swatch + series.name + ': ' + y + ' ' + series.unit + '<br>' + date;
           }
         });
       }
@@ -750,15 +755,9 @@ horizon.d3_line_chart = {
      * A helper function for catching changeDate event of form datepickers
      * connected to charts.
      */
-    bind_datepicker_change = function(settings) {
+    var bind_datepicker_change = function(settings) {
       var now = new Date();
-
-      $(datepicker_selector).each(function() {
-        var el = $(this);
-        el.datepicker({format: 'yyyy-mm-dd',
-          setDate: new Date(),
-          showButtonPanel: true});
-      });
+      horizon.datepickers.add(datepicker_selector);
       delegate_event_and_refresh_charts(datepicker_selector, 'changeDate', settings);
     };
 
