@@ -33,9 +33,11 @@ horizon.modals.create = function (title, body, confirm, cancel) {
     cancel = gettext("Cancel");
   }
   var template = horizon.templates.compiled_templates["#modal_template"],
-    params = {title: title, body: body, confirm: confirm, cancel: cancel},
-    modal = $(template.render(params)).appendTo("#modal_wrapper");
-  return modal;
+    params = {
+      title: title, body: body, confirm: confirm, cancel: cancel,
+      modal_backdrop: horizon.modals.MODAL_BACKDROP
+    };
+  return $(template.render(params)).appendTo("#modal_wrapper");
 };
 
 horizon.modals.success = function (data, textStatus, jqXHR) {
@@ -166,7 +168,9 @@ horizon.modals.init_wizard = function () {
 };
 
 
-horizon.addInitFunction(function() {
+horizon.addInitFunction(horizon.modals.init = function() {
+
+  var $document = $(document);
 
   // Bind handler for initializing new modals.
   $('#modal_wrapper').on('new_modal', function (evt, modal) {
@@ -174,13 +178,13 @@ horizon.addInitFunction(function() {
   });
 
   // Bind "cancel" button handler.
-  $(document).on('click', '.modal .cancel', function (evt) {
+  $document.on('click', '.modal .cancel', function (evt) {
     $(this).closest('.modal').modal('hide');
     evt.preventDefault();
   });
 
   // AJAX form submissions from modals. Makes validation happen in-modal.
-  $(document).on('submit', '.modal form', function (evt) {
+  $document.on('submit', '.modal form', function (evt) {
     var $form = $(this),
       form = this,
       $button = $form.find(".modal-footer .btn-primary"),
@@ -224,8 +228,11 @@ horizon.addInitFunction(function() {
         $('.ajax-modal, .dropdown-toggle').attr('disabled', true);
         horizon.modals.modal_spinner(gettext("Working"));
       },
-      complete: function () {
-        horizon.modals.spinner.modal('hide');
+      complete: function (jqXHR) {
+        var redirect_header = jqXHR.getResponseHeader("X-Horizon-Location");
+        if (redirect_header === null) {
+          horizon.modals.spinner.modal('hide');
+        }
         $("#modal_wrapper .modal").last().modal("show");
         $button.prop("disabled", false);
       },
@@ -234,7 +241,7 @@ horizon.addInitFunction(function() {
           add_to_field_header = jqXHR.getResponseHeader("X-Horizon-Add-To-Field"),
           json_data, field_to_update;
         if (redirect_header === null) {
-            $('.ajax-modal, .dropdown-toggle').removeAttr("disabled");
+          $('.ajax-modal, .dropdown-toggle').removeAttr("disabled");
         }
         $form.closest(".modal").modal("hide");
         if (redirect_header) {
@@ -269,7 +276,7 @@ horizon.addInitFunction(function() {
   });
 
   // Position modal so it's in-view even when scrolled down.
-  $(document).on('show.bs.modal', '.modal', function (evt) {
+  $document.on('show.bs.modal', '.modal', function (evt) {
     // Filter out indirect triggers of "show" from (for example) tabs.
     if ($(evt.target).hasClass("modal")) {
       var scrollShift = $('body').scrollTop() || $('html').scrollTop(),
@@ -292,11 +299,13 @@ horizon.addInitFunction(function() {
     $(modal).find(":text, select, textarea").filter(":visible:first").focus();
   });
 
-  horizon.modals.addModalInitFunction(horizon.datatables.validate_button);
+  horizon.modals.addModalInitFunction(function(modal) {
+    horizon.datatables.validate_button($(modal).find(".table_wrapper > form"));
+  });
   horizon.modals.addModalInitFunction(horizon.utils.loadAngular);
 
   // Load modals for ajax-modal links.
-  $(document).on('click', '.ajax-modal', function (evt) {
+  $document.on('click', '.ajax-modal', function (evt) {
     var $this = $(this);
 
     // If there's an existing modal request open, cancel it out.
@@ -350,7 +359,7 @@ horizon.addInitFunction(function() {
 
   // After a modal has been shown, hide any other modals that are already in
   // the stack. Only one modal can be visible at the same time.
-  $(document).on("show.bs.modal", ".modal", function () {
+  $document.on("show.bs.modal", ".modal", function () {
     var modal_stack = $("#modal_wrapper .modal");
     modal_stack.splice(modal_stack.length - 1, 1);
     modal_stack.modal("hide");
@@ -360,7 +369,7 @@ horizon.addInitFunction(function() {
   // Note: the modal should only be removed if it is the "top" of the stack of
   // modals, e.g. it's the one currently being interacted with and isn't just
   // temporarily being hidden.
-  $(document).on('hidden.bs.modal', '.modal', function () {
+  $document.on('hidden.bs.modal', '.modal', function () {
     var $this = $(this),
       modal_stack = $("#modal_wrapper .modal");
     if ($this[0] === modal_stack.last()[0] || $this.hasClass("loading")) {
@@ -370,4 +379,11 @@ horizon.addInitFunction(function() {
       }
     }
   });
+
+  // Make modals draggable
+  $document.on("show.bs.modal", ".modal", function () {
+    $(".modal-content").draggable({
+      handle: ".modal-header"
+    });
+  });
 });
