@@ -1,14 +1,20 @@
 /* Namespace for core functionality related to DataTables. */
 horizon.datatables = {
   update: function () {
-    var $rows_to_update = $('tr.status_unknown.ajax-update');
-    if ($rows_to_update.length) {
+    var $rows_to_update = $('tr.status_unknown.ajax-update'),
+      rows_to_update = $rows_to_update.length;
+    if ( rows_to_update > 0 ) {
       var interval = $rows_to_update.attr('data-update-interval'),
         $table = $rows_to_update.closest('table'),
+        submit_in_progress = $table.closest('form').attr('data-submitted'),
         decay_constant = $table.attr('decay_constant');
 
-      // Do not update this row if the action column is expanded
-      if ($rows_to_update.find('.actions_column .btn-group.open').length) {
+      // Do not update this row if the action column is expanded or the form
+      // is in the process of being submitted. If we update the row while the
+      // form is still submitting any disabled action buttons would potentially
+      // be enabled again, allowing for multiple form submits.
+      if ($rows_to_update.find('.actions_column .btn-group.open').length ||
+          submit_in_progress) {
         // Wait and try to update again in next interval instead
         setTimeout(horizon.datatables.update, interval);
         // Remove interval decay, since this will not hit server
@@ -91,19 +97,22 @@ horizon.datatables = {
           complete: function (jqXHR, textStatus) {
             // Revalidate the button check for the updated table
             horizon.datatables.validate_button();
-
-            // Set interval decay to this table, and increase if it already exist
-            if(decay_constant === undefined) {
-              decay_constant = 1;
-            } else {
-              decay_constant++;
+            rows_to_update--;
+            // Schedule next poll when all the rows are updated
+            if ( rows_to_update === 0 ) {
+              // Set interval decay to this table, and increase if it already exist
+              if(decay_constant === undefined) {
+                decay_constant = 1;
+              } else {
+                decay_constant++;
+              }
+              $table.attr('decay_constant', decay_constant);
+              // Poll until there are no rows in an "unknown" state on the page.
+              var next_poll = interval * decay_constant;
+              // Limit the interval to 30 secs
+              if(next_poll > 30 * 1000) { next_poll = 30 * 1000; }
+              setTimeout(horizon.datatables.update, next_poll);
             }
-            $table.attr('decay_constant', decay_constant);
-            // Poll until there are no rows in an "unknown" state on the page.
-            next_poll = interval * decay_constant;
-            // Limit the interval to 30 secs
-            if(next_poll > 30 * 1000) { next_poll = 30 * 1000; }
-            setTimeout(horizon.datatables.update, next_poll);
           }
         });
       });
@@ -131,15 +140,13 @@ horizon.datatables = {
     });
   },
 
-  validate_button: function () {
-    // Disable form button if checkbox are not checked
-    $("form").each(function (i) {
+  validate_button: function ($form) {
+    // Enable or disable table batch action buttons based on row selection.
+    $form = $form || $(".table_wrapper > form");
+    $form.each(function () {
       var checkboxes = $(this).find(".table-row-multi-select:checkbox");
-      var action_buttons = $(this).find(".table_actions button.btn-danger");
-
-      // Buttons should be enabled only if there are checked checkboxes
-      action_buttons.toggleClass("disabled",
-                                 !checkboxes.filter(":checked").length);
+      var action_buttons = $(this).find('.table_actions button[data-batch-action="true"]');
+      action_buttons.toggleClass("disabled", !checkboxes.filter(":checked").length);
     });
   },
 
@@ -159,18 +166,33 @@ horizon.datatables = {
       var any_unchecked = $table.find("tbody .table-row-multi-select:checkbox").not(":checked");
       $multi_select_checkbox.prop('checked', any_unchecked.length === 0);
     });
-    // Enable dangerous buttons only if one or more checkbox is checked.
+    // Enable/disable table batch action buttons when row selection changes.
     $("div.table_wrapper, #modal_wrapper").on("click", '.table-row-multi-select:checkbox', function (evt) {
-      var $form = $(this).closest("form");
-      var any_checked = $form.find("tbody .table-row-multi-select:checkbox").is(":checked");
-      if(any_checked) {
-        $form.find(".table_actions button.btn-danger").removeClass("disabled");
-      }else {
-        $form.find(".table_actions button.btn-danger").addClass("disabled");
-      }
+      horizon.datatables.validate_button($(this).closest("form"));
+    });
+  },
+
+  initialize_table_tooltips: function() {
+    $('div.table_wrapper').tooltip({selector: '[data-toggle="tooltip"]', container: 'body'});
+  },
+
+  disable_actions_on_submit: function($form) {
+    // This applies changes to the table form when a user takes an action that
+    // submits the form. It relies on the form being re-rendered after the
+    // submit is completed to remove these changes.
+    $form = $form || $(".table_wrapper > form");
+    $form.on("submit", function () {
+      // Add the 'submitted' flag to the form so the row update interval knows
+      // not to update the row and therefore re-enable the actions that we are
+      // disabling here.
+      $(this).attr('data-submitted', 'true');
+      // Disable row action buttons. This prevents multiple form submission.
+      $(this).find('td.actions_column button[type="submit"]').addClass("disabled");
+      // Use CSS to update the cursor so it's very clear that an action is
+      // in progress.
+      $(this).addClass('wait');
     });
   }
-
 };
 
 /* Generates a confirmation modal dialog for the given action. */
@@ -179,11 +201,13 @@ horizon.datatables.confirm = function (action) {
     $modal_parent = $(action).closest('.modal'),
     name_array = [],
     closest_table_id, action_string, name_string,
+    help_text,
     title, body, modal, form;
   if($action.hasClass("disabled")) {
     return;
   }
   action_string = $action.text();
+  help_text = $action.attr("help_text") || "";
   name_string = "";
   // Add the display name defined by table.get_object_display(datum)
   closest_table_id = $(action).closest("table").attr("id");
@@ -204,7 +228,7 @@ horizon.datatables.confirm = function (action) {
     name_string = interpolate(gettext("You have selected %s. "), [name_string]);
   }
   title = interpolate(gettext("Confirm %s"), [action_string]);
-  body = name_string + gettext("Please confirm your selection. This action cannot be undone.");
+  body = name_string + gettext("Please confirm your selection. ") + help_text;
   modal = horizon.modals.create(title, body, action_string);
   modal.modal();
   if($modal_parent.length) {
@@ -310,6 +334,10 @@ $.tablesorter.addParser({
     // innertext smashed together with no delimiters, so we need to find
     // the original cell and grab its first element to do the work
     var a = $(cell).find('li').first().text().split('.');
+    // if the cell doesn't contains the list, try to get the text directly
+    if (a === "") {
+        a = $(cell).text().split('.');
+    }
     if (a.length !== 4) {
       return false;
     }
@@ -326,6 +354,10 @@ $.tablesorter.addParser({
   format: function(s, table, cell) {
     var result = 0;
     var a = $(cell).find('li').first().text().split('.');
+    // if the cell doesn't contains the list, try to get the text directly
+    if (a === "") {
+        a = $(cell).text().split('.');
+    }
     var last_index = a.length - 1;
     // inet_aton(3), Javascript-style.  The unsigned-right-shift operation is
     // needed to keep the result from flipping over to negative when suitably
@@ -346,6 +378,30 @@ horizon.datatables.disable_buttons = function() {
   });
 };
 
+$.tablesorter.addParser({
+  id: 'uuid',
+  is: function(s) {
+    return false;
+  },
+  format: function(s) {
+    // Calculate a float that is based on the strings alphabetical position.
+    //
+    // Each character in the string has some significance in the
+    // overall calculation, starting at 1.0 and is divided down by 2 decimal
+    // places according to the chars position in the string.
+    // For example the string "SO" would become 83.79 which is then
+    // numerically comparable to other strings.
+    s = s.toUpperCase();
+    value = 0.0;
+    for(i = 0; i < s.length; i++) {
+      char_offset = 1.0 / Math.pow(100, i);
+      value = value + (s.charCodeAt(i) * char_offset);
+    }
+    return value;
+  },
+  type: 'numeric'
+});
+
 horizon.datatables.update_footer_count = function (el, modifier) {
   var $el = $(el),
     $browser, $footer, row_count, footer_text_template, footer_text;
@@ -412,6 +468,8 @@ horizon.datatables.set_table_sorting = function (parent) {
           header_options[i] = {sorter: 'timestampSorter'};
         } else if ($th.data('type') == 'naturalSort'){
           header_options[i] = {sorter: 'naturalSort'};
+        } else if ($th.data('type') == 'uuid'){
+          header_options[i] = {sorter: 'uuid'};
         }
       });
       $table.tablesorter({
@@ -449,7 +507,7 @@ horizon.datatables.set_table_query_filter = function (parent) {
           return false;
         }
       });
-      input.next('button.btn span.glyphicon-search').on('click keypress', function (evt) {
+      input.next('button.btn span.search-icon').on('click keypress', function (evt) {
         return false;
       });
 
@@ -511,25 +569,31 @@ horizon.datatables.set_table_fixed_filter = function (parent) {
   });
 };
 
-horizon.addInitFunction(function() {
+horizon.addInitFunction(horizon.datatables.init = function() {
   horizon.datatables.validate_button();
   horizon.datatables.disable_buttons();
   $('table.datatable').each(function (idx, el) {
     horizon.datatables.update_footer_count($(el), 0);
   });
   horizon.datatables.initialize_checkboxes_behavior();
+  horizon.datatables.initialize_table_tooltips();
 
   // Trigger run-once setup scripts for tables.
   horizon.datatables.add_table_checkboxes($('body'));
   horizon.datatables.set_table_sorting($('body'));
   horizon.datatables.set_table_query_filter($('body'));
   horizon.datatables.set_table_fixed_filter($('body'));
+  horizon.datatables.disable_actions_on_submit();
 
   // Also apply on tables in modal views.
   horizon.modals.addModalInitFunction(horizon.datatables.add_table_checkboxes);
   horizon.modals.addModalInitFunction(horizon.datatables.set_table_sorting);
   horizon.modals.addModalInitFunction(horizon.datatables.set_table_query_filter);
   horizon.modals.addModalInitFunction(horizon.datatables.set_table_fixed_filter);
+  horizon.modals.addModalInitFunction(horizon.datatables.initialize_table_tooltips);
+  horizon.modals.addModalInitFunction(function modalInitActionDisable(modal) {
+    horizon.datatables.disable_actions_on_submit($(modal).find(".table_wrapper > form"));
+  });
 
   // Also apply on tables in tabs views for lazy-loaded data.
   horizon.tabs.addTabLoadFunction(horizon.datatables.add_table_checkboxes);
@@ -537,7 +601,11 @@ horizon.addInitFunction(function() {
   horizon.tabs.addTabLoadFunction(horizon.datatables.set_table_query_filter);
   horizon.tabs.addTabLoadFunction(horizon.datatables.set_table_fixed_filter);
   horizon.tabs.addTabLoadFunction(horizon.datatables.initialize_checkboxes_behavior);
-  horizon.tabs.addTabLoadFunction(horizon.datatables.validate_button);
+  horizon.tabs.addTabLoadFunction(horizon.datatables.initialize_table_tooltips);
+  horizon.tabs.addTabLoadFunction(function(tab) {
+    horizon.datatables.validate_button($(tab).find(".table_wrapper > form"));
+    horizon.datatables.disable_actions_on_submit($(tab).find(".table_wrapper > form"));
+  });
 
   horizon.datatables.update();
 });
