@@ -16,6 +16,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import django
 import logging
 import os
 import socket
@@ -31,9 +32,16 @@ from django.core.handlers import wsgi
 from django import http
 from django import test as django_test
 from django.test.client import RequestFactory  # noqa
+from django.test import testcases
 from django.utils.encoding import force_text
 from django.utils import unittest
 
+if django.VERSION < (1, 7):
+    from django.test import LiveServerTestCase  # noqa
+else:
+    from django.contrib.staticfiles.testing \
+            import StaticLiveServerTestCase as LiveServerTestCase  # noqa
+
 LOG = logging.getLogger(__name__)
 
 
@@ -118,18 +126,32 @@ class TestCase(django_test.TestCase):
       * A ready-to-go request object via ``self.request``.
     """
     def setUp(self):
+        super(TestCase, self).setUp()
         self.mox = mox.Mox()
-        self.factory = RequestFactoryWithMessages()
-        self.user = User.objects.create_user(username='test', password='test')
-        self.assertTrue(self.client.login(username="test", password="test"))
-
-        self.request = http.HttpRequest()
-        self.request.session = self.client._session()
+        self._setup_test_data()
+        self._setup_factory()
+        self._setup_user()
+        self._setup_request()
         middleware.HorizonMiddleware().process_request(self.request)
         AuthenticationMiddleware().process_request(self.request)
         os.environ["HORIZON_TEST_RUN"] = "True"
 
+    def _setup_test_data(self):
+        pass
+
+    def _setup_factory(self):
+        self.factory = RequestFactoryWithMessages()
+
+    def _setup_user(self):
+        self.user = User.objects.create_user(username='test', password='test')
+        self.assertTrue(self.client.login(username="test", password="test"))
+
+    def _setup_request(self):
+        self.request = http.HttpRequest()
+        self.request.session = self.client._session()
+
     def tearDown(self):
+        super(TestCase, self).tearDown()
         self.mox.UnsetStubs()
         self.mox.VerifyAll()
         del os.environ["HORIZON_TEST_RUN"]
@@ -194,10 +216,52 @@ class TestCase(django_test.TestCase):
                 "%s messages not as expected: %s" % (msg_type.title(),
                                                      ", ".join(msgs))
 
+    def assertNotContains(self, response, text, status_code=200,
+                          msg_prefix='', html=False):
+        """Asserts that a response indicates that some content was retrieved
+        successfully, (i.e., the HTTP status code was as expected), and that
+        ``text`` doesn't occurs in the content of the response.
+
+        This is an override of django_test.TestCase.assertNotContains method,
+        which is able to work with StreamingHttpResponse.
+        """
+        # If the response supports deferred rendering and hasn't been rendered
+        # yet, then ensure that it does get rendered before proceeding further.
+        if (hasattr(response, 'render') and callable(response.render) and
+                not response.is_rendered):
+            response.render()
+
+        if msg_prefix:
+            msg_prefix += ": "
+
+        self.assertEqual(
+            response.status_code, status_code,
+            msg_prefix + "Couldn't retrieve content: Response code was %d"
+            " (expected %d)" % (response.status_code, status_code))
+
+        if getattr(response, 'streaming', False):
+            content = b''.join(response.streaming_content)
+        else:
+            content = response.content
+        if not isinstance(text, bytes) or html:
+            text = force_text(text, encoding=response._charset)
+            content = content.decode(response._charset)
+            text_repr = "'%s'" % text
+        else:
+            text_repr = repr(text)
+        if html:
+            content = testcases.assert_and_parse_html(
+                self, content, None, 'Response\'s content is not valid HTML:')
+            text = testcases.assert_and_parse_html(
+                self, text, None, 'Second argument is not valid HTML:')
+        self.assertEqual(
+            content.count(text), 0,
+            msg_prefix + "Response should not contain %s" % text_repr)
+
 
 @unittest.skipUnless(os.environ.get('WITH_SELENIUM', False),
                      "The WITH_SELENIUM env variable is not set.")
-class SeleniumTestCase(django_test.LiveServerTestCase):
+class SeleniumTestCase(LiveServerTestCase):
     @classmethod
     def setUpClass(cls):
         socket.setdefaulttimeout(60)
@@ -236,12 +300,12 @@ class JasmineTests(SeleniumTestCase):
 
     .. attribute:: sources
 
-        A list of JS source files (the {{STATIC_URL}} will be added
+        A list of JS source files (the {{ STATIC_URL }} will be added
         automatically, these are the source files tested
 
     .. attribute:: specs
 
-        A list of Jasmine JS spec files (the {{STATIC_URL}} will be added
+        A list of Jasmine JS spec files (the {{ STATIC_URL }} will be added
         automatically
 
     .. attribute:: template_name
@@ -270,14 +334,14 @@ class JasmineTests(SeleniumTestCase):
 
         wait.until(jasmine_done)
         failures = \
-            self.selenium.find_elements_by_css_selector(".specDetail.failed")
+            self.selenium.find_elements_by_css_selector(".spec-detail.failed")
 
         results = []
         for failure in failures:
             results.append(
                 failure.find_element_by_class_name("description").text)
             results.append(
-                failure.find_element_by_class_name("stackTrace").text)
+                failure.find_element_by_class_name("stack-trace").text)
 
         self.assertEqual(results, [], '\n\n' + '\n\n'.join(results) + '\n\n')
 
