@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,7 +15,7 @@
 import json
 
 from django import http
-from django.utils.encoding import force_unicode
+from django.utils.encoding import force_text
 from django.utils.safestring import mark_safe
 
 from horizon import messages
@@ -29,7 +27,7 @@ class MessageTests(test.TestCase):
     def test_middleware_header(self):
         req = self.request
         string = "Giant ants are attacking San Francisco!"
-        expected = ["error", force_unicode(string), ""]
+        expected = ["error", force_text(string), ""]
         self.assertTrue("async_messages" in req.horizon)
         self.assertItemsEqual(req.horizon['async_messages'], [])
         req.META['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest'
@@ -37,13 +35,13 @@ class MessageTests(test.TestCase):
         self.assertItemsEqual(req.horizon['async_messages'], [expected])
         res = http.HttpResponse()
         res = middleware.HorizonMiddleware().process_response(req, res)
-        self.assertEqual(res['X-Horizon-Messages'],
-                         json.dumps([expected]))
+        self.assertEqual(json.dumps([expected]),
+                         res['X-Horizon-Messages'])
 
     def test_safe_message(self):
         req = self.request
         string = mark_safe("We are now safe from ants! Go <a>here</a>!")
-        expected = ["error", force_unicode(string), " safe"]
+        expected = ["error", force_text(string), " safe"]
         self.assertTrue("async_messages" in req.horizon)
         self.assertItemsEqual(req.horizon['async_messages'], [])
         req.META['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest'
@@ -51,5 +49,5 @@ class MessageTests(test.TestCase):
         self.assertItemsEqual(req.horizon['async_messages'], [expected])
         res = http.HttpResponse()
         res = middleware.HorizonMiddleware().process_response(req, res)
-        self.assertEqual(res['X-Horizon-Messages'],
-                         json.dumps([expected]))
+        self.assertEqual(json.dumps([expected]),
+                         res['X-Horizon-Messages'])
