@@ -751,7 +751,7 @@ def port_create(request, network_id, **kwargs):
     LOG.debug("port_create(): netid=%s, kwargs=%s" % (network_id, kwargs))
     # In the case policy profiles are being used, profile id is needed.
     if 'policy_profile_id' in kwargs:
-        kwargs['n1kv:profile_id'] = kwargs.pop('policy_profile_id')
+        kwargs['n1kv:profile'] = kwargs.pop('policy_profile_id')
     kwargs = unescape_port_kwargs(**kwargs)
     body = {'port': {'network_id': network_id}}
     if 'tenant_id' not in kwargs:
