@@ -30,8 +30,6 @@ def troveclient(request):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
     trove_url = base.url_for(request, 'database')
-    LOG.debug('troveclient connection created using token "%s" and url "%s"' %
-              (request.user.token.id, trove_url))
     c = client.Client(request.user.username,
                       request.user.token.id,
                       project_id=request.user.project_id,
@@ -59,7 +57,8 @@ def instance_delete(request, instance_id):
 
 def instance_create(request, name, volume, flavor, databases=None,
                     users=None, restore_point=None, nics=None,
-                    datastore=None, datastore_version=None):
+                    datastore=None, datastore_version=None,
+                    replica_of=None):
     # TODO(dklyle): adding conditional to support trove without volume
     # support for now until API supports checking for volume support
     if volume > 0:
@@ -75,13 +74,19 @@ def instance_create(request, name, volume, flavor, databases=None,
         restorePoint=restore_point,
         nics=nics,
         datastore=datastore,
-        datastore_version=datastore_version)
+        datastore_version=datastore_version,
+        replica_of=replica_of)
 
 
 def instance_resize_volume(request, instance_id, size):
     return troveclient(request).instances.resize_volume(instance_id, size)
 
 
+def instance_resize(request, instance_id, flavor_id):
+    return troveclient(request).instances.resize_instance(instance_id,
+                                                          flavor_id)
+
+
 def instance_backups(request, instance_id):
     return troveclient(request).instances.backups(instance_id)
 
@@ -90,6 +95,11 @@ def instance_restart(request, instance_id):
     return troveclient(request).instances.restart(instance_id)
 
 
+def instance_detach_replica(request, instance_id):
+    return troveclient(request).instances.edit(instance_id,
+                                               detach_replica_source=True)
+
+
 def database_list(request, instance_id):
     return troveclient(request).databases.list(instance_id)
 
