@@ -10,7 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -25,7 +25,6 @@ class SetAggregateInfoAction(workflows.Action):
                            max_length=255)
 
     availability_zone = forms.CharField(label=_("Availability Zone"),
-                                        required=False,
                                         max_length=255)
 
     class Meta(object):
@@ -36,14 +35,14 @@ class SetAggregateInfoAction(workflows.Action):
         slug = "set_aggregate_info"
 
     def clean(self):
-        cleaned_data = super().clean()
-        name = cleaned_data.get('name', '')
+        cleaned_data = super(SetAggregateInfoAction, self).clean()
+        name = cleaned_data.get('name')
 
         try:
             aggregates = api.nova.aggregate_details_list(self.request)
         except Exception:
             msg = _('Unable to get host aggregate list')
-            exceptions.handle(self.request, msg)
+            exceptions.check_message(["Connection", "refused"], msg)
             raise
         if aggregates is not None:
             for aggregate in aggregates:
@@ -64,7 +63,9 @@ class SetAggregateInfoStep(workflows.Step):
 
 class AddHostsToAggregateAction(workflows.MembershipAction):
     def __init__(self, request, *args, **kwargs):
-        super().__init__(request, *args, **kwargs)
+        super(AddHostsToAggregateAction, self).__init__(request,
+                                                        *args,
+                                                        **kwargs)
         err_msg = _('Unable to get the available hosts')
 
         default_role_field_name = self.get_default_role_field_name()
@@ -74,13 +75,16 @@ class AddHostsToAggregateAction(workflows.MembershipAction):
         field_name = self.get_member_field_name('member')
         self.fields[field_name] = forms.MultipleChoiceField(required=False)
 
-        services = []
+        hosts = []
         try:
-            services = api.nova.service_list(request, binary='nova-compute')
+            hosts = api.nova.host_list(request)
         except Exception:
             exceptions.handle(request, err_msg)
 
-        host_names = [s.host for s in services]
+        host_names = []
+        for host in hosts:
+            if host.host_name not in host_names and host.service == u'compute':
+                host_names.append(host.host_name)
         host_names.sort()
 
         self.fields[field_name].choices = \
@@ -93,7 +97,9 @@ class AddHostsToAggregateAction(workflows.MembershipAction):
 
 class ManageAggregateHostsAction(workflows.MembershipAction):
     def __init__(self, request, *args, **kwargs):
-        super().__init__(request, *args, **kwargs)
+        super(ManageAggregateHostsAction, self).__init__(request,
+                                                         *args,
+                                                         **kwargs)
         err_msg = _('Unable to get the available hosts')
 
         default_role_field_name = self.get_default_role_field_name()
@@ -107,13 +113,16 @@ class ManageAggregateHostsAction(workflows.MembershipAction):
         aggregate = api.nova.aggregate_get(request, aggregate_id)
         current_aggregate_hosts = aggregate.hosts
 
-        services = []
+        hosts = []
         try:
-            services = api.nova.service_list(request, binary='nova-compute')
+            hosts = api.nova.host_list(request)
         except Exception:
             exceptions.handle(request, err_msg)
 
-        host_names = [s.host for s in services]
+        host_names = []
+        for host in hosts:
+            if host.host_name not in host_names and host.service == u'compute':
+                host_names.append(host.host_name)
         host_names.sort()
 
         self.fields[field_name].choices = \
@@ -171,16 +180,13 @@ class CreateAggregateWorkflow(workflows.Workflow):
     success_url = constants.AGGREGATES_INDEX_URL
     default_steps = (SetAggregateInfoStep, AddHostsToAggregateStep)
 
-    def format_status_message(self, message):
-        return message % self.context['name']
-
     def handle(self, request, context):
         try:
             self.object = \
                 api.nova.aggregate_create(
                     request,
                     name=context['name'],
-                    availability_zone=context.get('availability_zone') or None)
+                    availability_zone=context['availability_zone'])
         except Exception:
             exceptions.handle(request, _('Unable to create host aggregate.'))
             return False
@@ -192,9 +198,7 @@ class CreateAggregateWorkflow(workflows.Workflow):
             except Exception:
                 exceptions.handle(
                     request, _('Error adding Hosts to the aggregate.'))
-                # Host aggregate itself has been created successfully,
-                # so we return True here
-                return True
+                return False
 
         return True
 
