@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -18,7 +16,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
@@ -28,6 +26,7 @@ from openstack_dashboard.dashboards.admin import dashboard
 class Images(horizon.Panel):
     name = _("Images")
     slug = 'images'
+    permissions = ('openstack.services.image',)
 
 
 dashboard.Admin.register(Images)
