@@ -16,21 +16,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
+from openstack_dashboard.dashboards.admin import dashboard
+
 
 class Instances(horizon.Panel):
     name = _("Instances")
     slug = 'instances'
-    permissions = ('openstack.services.compute',)
-    policy_rules = ((("compute", "context_is_admin"),
-                     ("compute", "os_compute_api:servers:detail")),)
+    permissions = ('openstack.roles.admin', 'openstack.services.compute')
 
-    def allowed(self, context):
-        if (('compute' in settings.SYSTEM_SCOPE_SERVICES) !=
-                bool(context['request'].user.system_scoped)):
-            return False
-        return super().allowed(context)
+
+dashboard.Admin.register(Instances)
