@@ -40,11 +40,11 @@ class InstanceViewTest(test.BaseAdminViewTests):
         api.nova.extension_supported('AdminActions', IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(True)
         api.keystone.tenant_list(IsA(http.HttpRequest)).\
-                                 AndReturn([tenants, False])
+            AndReturn([tenants, False])
         search_opts = {'marker': None, 'paginate': True}
         api.nova.server_list(IsA(http.HttpRequest),
                              all_tenants=True, search_opts=search_opts) \
-                                .AndReturn([servers, False])
+            .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
         api.nova.flavor_list(IsA(http.HttpRequest)).AndReturn(flavors)
@@ -56,7 +56,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         self.assertItemsEqual(instances, servers)
 
     @test.create_stubs({api.nova: ('flavor_list', 'flavor_get',
-                                    'server_list', 'extension_supported',),
+                                   'server_list', 'extension_supported',),
                         api.keystone: ('tenant_list',),
                         api.network: ('servers_update_addresses',)})
     def test_index_flavor_list_exception(self):
@@ -68,15 +68,15 @@ class InstanceViewTest(test.BaseAdminViewTests):
         search_opts = {'marker': None, 'paginate': True}
         api.nova.server_list(IsA(http.HttpRequest),
                              all_tenants=True, search_opts=search_opts) \
-                                .AndReturn([servers, False])
+            .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
         api.nova.extension_supported('AdminActions', IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(True)
         api.nova.flavor_list(IsA(http.HttpRequest)). \
-                            AndRaise(self.exceptions.nova)
+            AndRaise(self.exceptions.nova)
         api.keystone.tenant_list(IsA(http.HttpRequest)).\
-                                 AndReturn([tenants, False])
+            AndReturn([tenants, False])
         for server in servers:
             api.nova.flavor_get(IsA(http.HttpRequest), server.flavor["id"]). \
                 AndReturn(full_flavors[server.flavor["id"]])
@@ -89,7 +89,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         self.assertItemsEqual(instances, servers)
 
     @test.create_stubs({api.nova: ('flavor_list', 'flavor_get',
-                                    'server_list', 'extension_supported', ),
+                                   'server_list', 'extension_supported', ),
                         api.keystone: ('tenant_list',),
                         api.network: ('servers_update_addresses',)})
     def test_index_flavor_get_exception(self):
@@ -104,15 +104,15 @@ class InstanceViewTest(test.BaseAdminViewTests):
         search_opts = {'marker': None, 'paginate': True}
         api.nova.server_list(IsA(http.HttpRequest),
                              all_tenants=True, search_opts=search_opts) \
-                                .AndReturn([servers, False])
+            .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
         api.nova.extension_supported('AdminActions', IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(True)
         api.nova.flavor_list(IsA(http.HttpRequest)). \
-                            AndReturn(flavors)
+            AndReturn(flavors)
         api.keystone.tenant_list(IsA(http.HttpRequest)).\
-                                 AndReturn([tenants, False])
+            AndReturn([tenants, False])
         for server in servers:
             api.nova.flavor_get(IsA(http.HttpRequest), server.flavor["id"]). \
                 AndRaise(self.exceptions.nova)
@@ -132,7 +132,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         search_opts = {'marker': None, 'paginate': True}
         api.nova.server_list(IsA(http.HttpRequest),
                              all_tenants=True, search_opts=search_opts) \
-                                .AndRaise(self.exceptions.nova)
+            .AndRaise(self.exceptions.nova)
 
         self.mox.ReplayAll()
 
@@ -157,11 +157,11 @@ class InstanceViewTest(test.BaseAdminViewTests):
                                 admin=True).AndReturn(tenant)
         self.mox.ReplayAll()
 
-        url = INDEX_URL + \
-                "?action=row_update&table=instances&obj_id=" + server.id
+        url = (INDEX_URL +
+               "?action=row_update&table=instances&obj_id=" + server.id)
 
         res = self.client.get(url, {},
-                               HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+                              HTTP_X_REQUESTED_WITH='XMLHttpRequest')
 
         self.assertTemplateUsed(res, "horizon/common/_data_table_row.html")
         self.assertContains(res, "test_tenant", 1, 200)
@@ -186,7 +186,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         search_opts = {'marker': None, 'paginate': True}
         api.nova.server_list(IsA(http.HttpRequest),
                              all_tenants=True, search_opts=search_opts) \
-                                .AndReturn([servers, False])
+            .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
         api.nova.extension_supported('AdminActions', IsA(http.HttpRequest)) \
@@ -211,17 +211,17 @@ class InstanceViewTest(test.BaseAdminViewTests):
         server2 = servers[2]
         server2.status = "VERIFY_RESIZE"
         api.keystone.tenant_list(IsA(http.HttpRequest)) \
-                    .AndReturn([self.tenants.list(), False])
+            .AndReturn([self.tenants.list(), False])
         search_opts = {'marker': None, 'paginate': True}
         api.nova.extension_supported('AdminActions', IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(True)
         api.nova.server_list(IsA(http.HttpRequest),
                              all_tenants=True, search_opts=search_opts) \
-                                .AndReturn([servers, False])
+            .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
         api.nova.flavor_list(IsA(http.HttpRequest)).\
-                             AndReturn(self.flavors.list())
+            AndReturn(self.flavors.list())
         self.mox.ReplayAll()
 
         res = self.client.get(INDEX_URL)
@@ -234,9 +234,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
     def test_instance_live_migrate_get(self):
         server = self.servers.first()
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
-                .AndReturn(server)
+            .AndReturn(server)
         api.nova.host_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hosts.list())
+            .AndReturn(self.hosts.list())
 
         self.mox.ReplayAll()
 
@@ -250,7 +250,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
     def test_instance_live_migrate_get_server_get_exception(self):
         server = self.servers.first()
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
-                .AndRaise(self.exceptions.nova)
+            .AndRaise(self.exceptions.nova)
 
         self.mox.ReplayAll()
 
@@ -265,9 +265,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
     def test_instance_live_migrate_list_hypervisor_get_exception(self):
         server = self.servers.first()
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
-                .AndReturn(server)
+            .AndReturn(server)
         api.nova.host_list(IsA(http.HttpRequest)) \
-                .AndRaise(self.exceptions.nova)
+            .AndRaise(self.exceptions.nova)
 
         self.mox.ReplayAll()
         url = reverse('horizon:admin:instances:live_migrate',
@@ -281,9 +281,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
     def test_instance_live_migrate_list_hypervisor_without_current(self):
         server = self.servers.first()
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
-                .AndReturn(server)
+            .AndReturn(server)
         api.nova.host_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hosts.list())
+            .AndReturn(self.hosts.list())
 
         self.mox.ReplayAll()
 
@@ -307,13 +307,13 @@ class InstanceViewTest(test.BaseAdminViewTests):
         host = self.hosts.first().host_name
 
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
-                .AndReturn(server)
+            .AndReturn(server)
         api.nova.host_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hosts.list())
+            .AndReturn(self.hosts.list())
         api.nova.server_live_migrate(IsA(http.HttpRequest), server.id, host,
                                      block_migration=False,
                                      disk_over_commit=False) \
-                .AndReturn([])
+            .AndReturn([])
 
         self.mox.ReplayAll()
 
@@ -331,13 +331,13 @@ class InstanceViewTest(test.BaseAdminViewTests):
         host = self.hosts.first().host_name
 
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
-                .AndReturn(server)
+            .AndReturn(server)
         api.nova.host_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hosts.list())
+            .AndReturn(self.hosts.list())
         api.nova.server_live_migrate(IsA(http.HttpRequest), server.id, host,
                                      block_migration=False,
                                      disk_over_commit=False) \
-                .AndRaise(self.exceptions.nova)
+            .AndRaise(self.exceptions.nova)
 
         self.mox.ReplayAll()
 
@@ -351,7 +351,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         server = self.servers.first()
 
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
-                        .AndRaise(self.exceptions.nova)
+            .AndRaise(self.exceptions.nova)
 
         self.mox.ReplayAll()
 
