@@ -14,8 +14,7 @@
 
 import json
 
-from django.urls import reverse
-from django.urls import reverse_lazy
+from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -60,19 +59,17 @@ class AdminIndexView(tables.DataTableView):
             marker = self.request.GET.get(
                 admin_tables.AdminNamespacesTable._meta.pagination_param, None)
 
-        filters = self.get_filters()
-
         try:
             namespaces, self._more, self._prev =\
                 glance.metadefs_namespace_list(self.request,
                                                marker=marker,
                                                paginate=True,
-                                               sort_dir=sort_dir,
-                                               filters=filters)
+                                               sort_dir=sort_dir)
 
             if prev_marker is not None:
                 namespaces = sorted(namespaces,
-                                    key=lambda ns: getattr(ns, 'namespace'))
+                                    key=lambda ns: getattr(ns, 'namespace'),
+                                    reverse=True)
         except Exception:
             self._prev = False
             self._more = False
@@ -87,52 +84,16 @@ class CreateView(forms.ModalFormView):
     context_object_name = 'namespace'
     success_url = reverse_lazy(constants.METADATA_INDEX_URL)
     page_title = _("Create a Metadata Namespace")
-    submit_label = _("Import Namespace")
-
-
-class UpdateView(forms.ModalFormView):
-    form_class = admin_forms.UpdateNamespaceForm
-    form_id = 'update_namespace_attributes_form'
-    template_name = constants.METADATA_UPDATE_TEMPLATE
-    context_object_name = 'namespace'
-    success_url = reverse_lazy(constants.METADATA_INDEX_URL)
-    submit_url = constants.METADATA_UPDATE_URL
-    page_title = _("Edit Metadata Namespace")
-    submit_label = _("Save Changes")
-
-    def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
-        args = (self.kwargs['namespace_id'],)
-        context["namespace_id"] = self.kwargs['namespace_id']
-        context["submit_url"] = reverse(self.submit_url, args=args)
-        return context
-
-    def _get_object(self, *args, **kwargs):
-        namespace_id = self.kwargs['namespace_id']
-        try:
-            return glance.metadefs_namespace_get(self.request, namespace_id)
-        except Exception:
-            redirect = self.success_url
-            msg = _('Unable to retrieve namespace details.')
-            exceptions.handle(self.request, msg, redirect=redirect)
-
-    def get_initial(self):
-        namespace = self._get_object()
-        visibility = namespace['visibility'] == 'public'
-        return {'namespace_id': namespace['namespace'],
-                'public': visibility,
-                'protected': namespace['protected'],
-                }
 
 
 class DetailView(tabs.TabView):
     redirect_url = constants.METADATA_INDEX_URL
     tab_group_class = admin_tabs.NamespaceDetailTabs
     template_name = constants.METADATA_DETAIL_TEMPLATE
-    page_title = "{{ namespace.namespace }}"
+    page_title = _("Namespace Details: {{ namespace.namespace }}")
 
     def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
+        context = super(DetailView, self).get_context_data(**kwargs)
         context["namespace"] = self.get_data()
         return context
 
@@ -171,7 +132,7 @@ class ManageResourceTypes(forms.ModalFormView):
                 'resource_types': resource_types}
 
     def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
+        context = super(ManageResourceTypes, self).get_context_data(**kwargs)
 
         selected_type_names = [selected_type['name'] for selected_type in
                                context['form'].initial['resource_types']]
