@@ -27,7 +27,8 @@ from openstack_dashboard import api
 
 LOG = logging.getLogger(__name__)
 PROVIDER_TYPES = [('local', _('Local')), ('flat', _('Flat')),
-                  ('vlan', 'VLAN'), ('gre', 'GRE'), ('vxlan', 'VXLAN')]
+                  ('vlan', _('VLAN')), ('gre', _('GRE')),
+                  ('vxlan', _('VXLAN'))]
 SEGMENTATION_ID_RANGE = {'vlan': [1, 4094], 'gre': [0, (2 ** 32) - 1],
                          'vxlan': [0, (2 ** 24) - 1]}
 
@@ -37,13 +38,6 @@ class CreateNetwork(forms.SelfHandlingForm):
                            label=_("Name"),
                            required=False)
     tenant_id = forms.ChoiceField(label=_("Project"))
-    if api.neutron.is_port_profiles_supported():
-        widget = None
-    else:
-        widget = forms.HiddenInput()
-    net_profile_id = forms.ChoiceField(label=_("Network Profile"),
-                                       required=False,
-                                       widget=widget)
     network_type = forms.ChoiceField(
         label=_("Provider Network Type"),
         help_text=_("The physical mechanism by which the virtual "
@@ -73,8 +67,8 @@ class CreateNetwork(forms.SelfHandlingForm):
             'data-network_type-gre': _('Segmentation ID'),
             'data-network_type-vxlan': _('Segmentation ID')
         }))
-    # TODO(amotoki): make UP/DOWN translatable
-    admin_state = forms.ChoiceField(choices=[(True, 'UP'), (False, 'DOWN')],
+    admin_state = forms.ChoiceField(choices=[(True, _('UP')),
+                                             (False, _('DOWN'))],
                                     label=_("Admin State"))
     shared = forms.BooleanField(label=_("Shared"),
                                 initial=False, required=False)
@@ -94,10 +88,6 @@ class CreateNetwork(forms.SelfHandlingForm):
                 tenant_choices.append((tenant.id, tenant.name))
         self.fields['tenant_id'].choices = tenant_choices
 
-        if api.neutron.is_port_profiles_supported():
-            self.fields['net_profile_id'].choices = (
-                self.get_network_profile_choices(request))
-
         if api.neutron.is_extension_supported(request, 'provider'):
             neutron_settings = getattr(settings,
                                        'OPENSTACK_NEUTRON_NETWORK', {})
@@ -110,18 +100,19 @@ class CreateNetwork(forms.SelfHandlingForm):
                 'vxlan': seg_id_range.get('vxlan',
                                           SEGMENTATION_ID_RANGE.get('vxlan'))
             }
-            seg_id_help = (_("For VLAN networks, the VLAN VID on the physical "
-                "network that realizes the virtual network. Valid VLAN VIDs "
-                "are %(vlan_min)s through %(vlan_max)s. For GRE or VXLAN "
-                "networks, the tunnel ID. Valid tunnel IDs for GRE networks "
-                "are %(gre_min)s through %(gre_max)s. For VXLAN networks, "
-                "%(vxlan_min)s through %(vxlan_max)s.") % {
-                    'vlan_min': self.seg_id_range['vlan'][0],
-                    'vlan_max': self.seg_id_range['vlan'][1],
-                    'gre_min': self.seg_id_range['gre'][0],
-                    'gre_max': self.seg_id_range['gre'][1],
-                    'vxlan_min': self.seg_id_range['vxlan'][0],
-                    'vxlan_max': self.seg_id_range['vxlan'][1]})
+            seg_id_help = (
+                _("For VLAN networks, the VLAN VID on the physical "
+                  "network that realizes the virtual network. Valid VLAN VIDs "
+                  "are %(vlan_min)s through %(vlan_max)s. For GRE or VXLAN "
+                  "networks, the tunnel ID. Valid tunnel IDs for GRE networks "
+                  "are %(gre_min)s through %(gre_max)s. For VXLAN networks, "
+                  "%(vxlan_min)s through %(vxlan_max)s.")
+                % {'vlan_min': self.seg_id_range['vlan'][0],
+                   'vlan_max': self.seg_id_range['vlan'][1],
+                   'gre_min': self.seg_id_range['gre'][0],
+                   'gre_max': self.seg_id_range['gre'][1],
+                   'vxlan_min': self.seg_id_range['vxlan'][0],
+                   'vxlan_max': self.seg_id_range['vxlan'][1]})
             self.fields['segmentation_id'].help_text = seg_id_help
 
             supported_provider_types = neutron_settings.get(
@@ -129,8 +120,9 @@ class CreateNetwork(forms.SelfHandlingForm):
             if supported_provider_types == ['*']:
                 network_type_choices = PROVIDER_TYPES
             else:
-                network_type_choices = [net_type for net_type in
-                    PROVIDER_TYPES if net_type[0] in supported_provider_types]
+                network_type_choices = [
+                    net_type for net_type in PROVIDER_TYPES
+                    if net_type[0] in supported_provider_types]
             if len(network_type_choices) == 0:
                 self._hide_provider_network_type()
             else:
@@ -138,21 +130,6 @@ class CreateNetwork(forms.SelfHandlingForm):
         else:
             self._hide_provider_network_type()
 
-    def get_network_profile_choices(self, request):
-        profile_choices = [('', _("Select a profile"))]
-        for profile in self._get_profiles(request, 'network'):
-            profile_choices.append((profile.id, profile.name))
-        return profile_choices
-
-    def _get_profiles(self, request, type_p):
-        profiles = []
-        try:
-            profiles = api.neutron.profile_list(request, type_p)
-        except Exception:
-            msg = _('Network Profiles could not be retrieved.')
-            exceptions.handle(request, msg)
-        return profiles
-
     def _hide_provider_network_type(self):
         self.fields['network_type'].widget = forms.HiddenInput()
         self.fields['physical_network'].widget = forms.HiddenInput()
@@ -168,8 +145,6 @@ class CreateNetwork(forms.SelfHandlingForm):
                       'admin_state_up': (data['admin_state'] == 'True'),
                       'shared': data['shared'],
                       'router:external': data['external']}
-            if api.neutron.is_port_profiles_supported():
-                params['net_profile_id'] = data['net_profile_id']
             if api.neutron.is_extension_supported(request, 'provider'):
                 network_type = data['network_type']
                 params['provider:network_type'] = network_type
@@ -230,11 +205,8 @@ class CreateNetwork(forms.SelfHandlingForm):
 class UpdateNetwork(forms.SelfHandlingForm):
     name = forms.CharField(label=_("Name"), required=False)
     tenant_id = forms.CharField(widget=forms.HiddenInput)
-    network_id = forms.CharField(label=_("ID"),
-                                 widget=forms.TextInput(
-                                     attrs={'readonly': 'readonly'}))
-    # TODO(amotoki): make UP/DOWN translatable
-    admin_state = forms.ChoiceField(choices=[(True, 'UP'), (False, 'DOWN')],
+    admin_state = forms.ChoiceField(choices=[(True, _('UP')),
+                                             (False, _('DOWN'))],
                                     label=_("Admin State"))
     shared = forms.BooleanField(label=_("Shared"), required=False)
     external = forms.BooleanField(label=_("External Network"), required=False)
@@ -246,7 +218,8 @@ class UpdateNetwork(forms.SelfHandlingForm):
                       'admin_state_up': (data['admin_state'] == 'True'),
                       'shared': data['shared'],
                       'router:external': data['external']}
-            network = api.neutron.network_update(request, data['network_id'],
+            network = api.neutron.network_update(request,
+                                                 self.initial['network_id'],
                                                  **params)
             msg = _('Network %s was successfully updated.') % data['name']
             LOG.debug(msg)
