@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 NEC Corporation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -22,21 +20,29 @@ from horizon import forms
 from horizon.utils import memoized
 
 from openstack_dashboard import api
+
+from openstack_dashboard.dashboards.admin.networks.ports \
+    import forms as ports_forms
+from openstack_dashboard.dashboards.admin.networks.ports \
+    import tables as ports_tables
+from openstack_dashboard.dashboards.admin.networks.ports \
+    import tabs as ports_tabs
 from openstack_dashboard.dashboards.project.networks.ports \
     import views as project_views
 
-from openstack_dashboard.dashboards.admin.networks.ports \
-    import forms as project_forms
-
 
 class CreateView(forms.ModalFormView):
-    form_class = project_forms.CreatePort
+    form_class = ports_forms.CreatePort
+    form_id = "create_port_form"
+    modal_header = _("Create Port")
+    submit_label = _("Create Port")
+    submit_url = "horizon:admin:networks:addport"
+    page_title = _("Create Port")
     template_name = 'admin/networks/ports/create.html'
-    success_url = 'horizon:admin:networks:detail'
-    failure_url = 'horizon:admin:networks:detail'
+    url = 'horizon:admin:networks:detail'
 
     def get_success_url(self):
-        return reverse(self.success_url,
+        return reverse(self.url,
                        args=(self.kwargs['network_id'],))
 
     @memoized.memoized_method
@@ -45,7 +51,7 @@ class CreateView(forms.ModalFormView):
             network_id = self.kwargs["network_id"]
             return api.neutron.network_get(self.request, network_id)
         except Exception:
-            redirect = reverse(self.failure_url,
+            redirect = reverse(self.url,
                                args=(self.kwargs['network_id'],))
             msg = _("Unable to retrieve network.")
             exceptions.handle(self.request, msg, redirect=redirect)
@@ -53,6 +59,8 @@ class CreateView(forms.ModalFormView):
     def get_context_data(self, **kwargs):
         context = super(CreateView, self).get_context_data(**kwargs)
         context['network'] = self.get_object()
+        args = (self.kwargs['network_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
@@ -61,8 +69,32 @@ class CreateView(forms.ModalFormView):
                 "network_name": network.name}
 
 
+class DetailView(project_views.DetailView):
+    tab_group_class = ports_tabs.PortDetailTabs
+
+    def get_context_data(self, **kwargs):
+        context = super(DetailView, self).get_context_data(**kwargs)
+        port = context["port"]
+        table = ports_tables.PortsTable(self.request,
+                                        network_id=port.network_id)
+        context["url"] = reverse('horizon:admin:networks:index')
+        context["actions"] = table.render_row_actions(port)
+        return context
+
+    @staticmethod
+    def get_redirect_url():
+        return reverse('horizon:admin:networks:index')
+
+
 class UpdateView(project_views.UpdateView):
-    form_class = project_forms.UpdatePort
+    form_class = ports_forms.UpdatePort
     template_name = 'admin/networks/ports/update.html'
     context_object_name = 'port'
+    submit_url = "horizon:admin:networks:editport"
     success_url = 'horizon:admin:networks:detail'
+
+    def get_initial(self):
+        initial = super(UpdateView, self).get_initial()
+        port = self._get_object()
+        initial['binding__host_id'] = port['binding__host_id']
+        return initial
