@@ -56,8 +56,8 @@ class UpdateRow(tables.Row):
 
 
 class VolumeSnapshotsTable(volumes_tables.VolumesTableBase):
-    name = tables.WrappingColumn("name", verbose_name=_("Name"),
-                                 link="horizon:admin:volumes:snapshots:detail")
+    name = tables.Column("name", verbose_name=_("Name"),
+                         link="horizon:admin:volumes:snapshots:detail")
     volume_name = snapshots_tables.SnapshotVolumeNameColumn(
         "name", verbose_name=_("Volume Name"),
         link="horizon:admin:volumes:volumes:detail")
@@ -67,13 +67,10 @@ class VolumeSnapshotsTable(volumes_tables.VolumesTableBase):
     class Meta(object):
         name = "volume_snapshots"
         verbose_name = _("Volume Snapshots")
-        pagination_param = 'snapshot_marker'
-        prev_pagination_param = 'prev_snapshot_marker'
         table_actions = (snapshots_tables.VolumeSnapshotsFilterAction,
                          snapshots_tables.DeleteVolumeSnapshot,)
         row_actions = (snapshots_tables.DeleteVolumeSnapshot,
-                       UpdateVolumeSnapshotStatus,
-                       snapshots_tables.UpdateMetadata)
+                       UpdateVolumeSnapshotStatus,)
         row_class = UpdateRow
         status_columns = ("status",)
         columns = ('tenant', 'host', 'name', 'description', 'size', 'status',
