@@ -10,13 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.core.urlresolvers import reverse
 from django.template import defaultfilters as filters
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
-from horizon import forms
 from horizon import tables
 
 from openstack_dashboard.api import cinder
@@ -31,21 +29,11 @@ class CreateVolumeType(tables.LinkAction):
     policy_rules = (("volume", "volume_extension:types_manage"),)
 
 
-class EditVolumeType(tables.LinkAction):
-    name = "edit"
-    verbose_name = _("Edit Volume Type")
-    url = "horizon:admin:volumes:volume_types:update_type"
-    classes = ("ajax-modal",)
-    icon = "pencil"
-    policy_rules = (("volume", "volume_extension:types_manage"),)
-
-
 class ViewVolumeTypeExtras(tables.LinkAction):
     name = "extras"
     verbose_name = _("View Extra Specs")
     url = "horizon:admin:volumes:volume_types:extras:index"
-    classes = ("ajax-modal",)
-    icon = "pencil"
+    classes = ("btn-edit",)
     policy_rules = (("volume", "volume_extension:types_manage"),)
 
 
@@ -77,11 +65,7 @@ class DeleteVolumeType(tables.DeleteAction):
     policy_rules = (("volume", "volume_extension:types_manage"),)
 
     def delete(self, request, obj_id):
-        try:
-            cinder.volume_type_delete(request, obj_id)
-        except exceptions.BadRequest as e:
-            redirect_url = reverse("horizon:admin:volumes:index")
-            exceptions.handle(request, e, redirect=redirect_url)
+        cinder.volume_type_delete(request, obj_id)
 
 
 class CreateVolumeTypeEncryption(tables.LinkAction):
@@ -93,21 +77,11 @@ class CreateVolumeTypeEncryption(tables.LinkAction):
     policy_rules = (("volume", "volume_extension:volume_type_encryption"),)
 
     def allowed(self, request, volume_type):
-        return (_is_vol_type_enc_possible(request) and
-                not _does_vol_type_enc_exist(volume_type))
-
-
-class UpdateVolumeTypeEncryption(tables.LinkAction):
-    name = "update_encryption"
-    verbose_name = _("Update Encryption")
-    url = "horizon:admin:volumes:volume_types:update_type_encryption"
-    classes = ("ajax-modal",)
-    icon = "pencil"
-    policy_rules = (("volume", "volume_extension:volume_type_encryption"),)
-
-    def allowed(self, request, volume_type=None):
-        return (_is_vol_type_enc_possible(request) and
-                _does_vol_type_enc_exist(volume_type))
+        if _is_vol_type_enc_possible(request):
+            return (hasattr(volume_type, 'encryption')
+                    and not hasattr(volume_type.encryption, 'provider'))
+        else:
+            return False
 
 
 class DeleteVolumeTypeEncryption(tables.DeleteAction):
@@ -136,14 +110,8 @@ class DeleteVolumeTypeEncryption(tables.DeleteAction):
 
     def allowed(self, request, volume_type=None):
         return (_is_vol_type_enc_possible(request) and
-                _does_vol_type_enc_exist(volume_type))
-
-
-def _does_vol_type_enc_exist(volume_type):
-    # Check to see if there is an existing encryption information
-    # for the volume type or not
-    return (hasattr(volume_type, 'encryption') and
-            hasattr(volume_type.encryption, 'provider'))
+                hasattr(volume_type, 'encryption') and
+                hasattr(volume_type.encryption, 'provider'))
 
 
 def _is_vol_type_enc_possible(request):
@@ -165,13 +133,6 @@ def get_volume_type_encryption(volume_type):
     return provider
 
 
-def get_volume_type_encryption_link(volume_type):
-    if _does_vol_type_enc_exist(volume_type):
-        return reverse("horizon:admin:volumes:volume_types:"
-                       "type_encryption_detail",
-                       kwargs={'volume_type_id': volume_type.id})
-
-
 class VolumeTypesFilterAction(tables.FilterAction):
 
     def filter(self, table, volume_types, filter_string):
@@ -181,56 +142,14 @@ class VolumeTypesFilterAction(tables.FilterAction):
                 if query in volume_type.name.lower()]
 
 
-class UpdateRow(tables.Row):
-    ajax = True
-
-    def get_data(self, request, volume_type_id):
-        try:
-            volume_type = \
-                cinder.volume_type_get_with_qos_association(request,
-                                                            volume_type_id)
-        except Exception:
-            exceptions.handle(request,
-                              _('Unable to retrieve volume type qos.'))
-        return volume_type
-
-
-class UpdateMetadata(tables.LinkAction):
-    name = "update_metadata"
-    verbose_name = _("Update Metadata")
-    ajax = False
-    attrs = {"ng-controller": "MetadataModalHelperController as modal"}
-
-    def __init__(self, **kwargs):
-        kwargs['preempt'] = True
-        super(UpdateMetadata, self).__init__(**kwargs)
-
-    def get_link_url(self, datum):
-        obj_id = self.table.get_object_id(datum)
-        self.attrs['ng-click'] = (
-            "modal.openMetadataModal('volume_type', '%s', true)" % obj_id)
-        return "javascript:void(0);"
-
-
 class VolumeTypesTable(tables.DataTable):
-    name = tables.WrappingColumn("name", verbose_name=_("Name"),
-                                 form_field=forms.CharField(max_length=64))
-    description = tables.Column(lambda obj: getattr(obj, 'description', None),
-                                verbose_name=_('Description'),
-                                form_field=forms.CharField(
-                                    widget=forms.Textarea(attrs={'rows': 4}),
-                                    required=False))
-
+    name = tables.Column("name", verbose_name=_("Name"))
     assoc_qos_spec = tables.Column("associated_qos_spec",
                                    verbose_name=_("Associated QoS Spec"))
     encryption = tables.Column(get_volume_type_encryption,
                                verbose_name=_("Encryption"),
-                               link=get_volume_type_encryption_link)
-    public = tables.Column("is_public",
-                           verbose_name=_("Public"),
-                           filters=(filters.yesno, filters.capfirst),
-                           form_field=forms.BooleanField(
-                               label=_('Public'), required=False))
+                               link="horizon:admin:volumes:volume_types:"
+                                    "type_encryption_detail")
 
     def get_object_display(self, vol_type):
         return vol_type.name
@@ -247,12 +166,8 @@ class VolumeTypesTable(tables.DataTable):
         row_actions = (CreateVolumeTypeEncryption,
                        ViewVolumeTypeExtras,
                        ManageQosSpecAssociation,
-                       EditVolumeType,
-                       UpdateVolumeTypeEncryption,
                        DeleteVolumeTypeEncryption,
-                       DeleteVolumeType,
-                       UpdateMetadata)
-        row_class = UpdateRow
+                       DeleteVolumeType,)
 
 
 # QOS Specs section of panel
@@ -260,7 +175,6 @@ class ManageQosSpec(tables.LinkAction):
     name = "qos_spec"
     verbose_name = _("Manage Specs")
     url = "horizon:admin:volumes:volume_types:qos_specs:index"
-    classes = ("ajax-modal",)
     icon = "pencil"
     policy_rules = (("volume", "volume_extension:types_manage"),)
 
@@ -312,7 +226,7 @@ class EditConsumer(tables.LinkAction):
 
 
 class QosSpecsTable(tables.DataTable):
-    name = tables.WrappingColumn('name', verbose_name=_('Name'))
+    name = tables.Column('name', verbose_name=_('Name'))
     consumer = tables.Column('consumer', verbose_name=_('Consumer'))
     specs = tables.Column(render_spec_keys,
                           verbose_name=_('Specs'),
