@@ -17,32 +17,29 @@
 #    under the License.
 
 from django.core.urlresolvers import reverse
+from django.forms import ValidationError  # noqa
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
 from horizon import messages
-from horizon.utils import validators as utils_validators
 
 from openstack_dashboard.api import cinder
-from openstack_dashboard.dashboards.admin.volumes.snapshots.forms \
-    import populate_status_choices
 from openstack_dashboard.dashboards.project.volumes.volumes \
     import forms as project_forms
 
 
-# This set of states was pulled from cinder's admin_actions.py
-STATUS_CHOICES = (
-    ('attaching', _('Attaching')),
-    ('available', _('Available')),
-    ('creating', _('Creating')),
-    ('deleting', _('Deleting')),
-    ('detaching', _('Detaching')),
-    ('error', _('Error')),
-    ('error_deleting', _('Error Deleting')),
-    ('in-use', _('In Use')),
-    ('maintenance', _('Maintenance')),
-)
+def validate_metadata(value):
+    error_msg = _('Invalid metadata entry. Use comma-separated'
+                  ' key=value pairs')
+
+    if value:
+        specs = value.split(",")
+        for spec in specs:
+            keyval = spec.split("=")
+            # ensure both sides of "=" exist, but allow blank value
+            if not len(keyval) == 2 or not keyval[0]:
+                raise ValidationError(error_msg)
 
 
 class ManageVolume(forms.SelfHandlingForm):
@@ -64,13 +61,13 @@ class ManageVolume(forms.SelfHandlingForm):
         required=False,
         help_text=_("Volume name to be assigned"))
     description = forms.CharField(max_length=255, widget=forms.Textarea(
-        attrs={'rows': 4}),
+        attrs={'class': 'modal-body-fixed-width', 'rows': 4}),
         label=_("Description"), required=False)
     metadata = forms.CharField(max_length=255, widget=forms.Textarea(
-        attrs={'rows': 2}),
+        attrs={'class': 'modal-body-fixed-width', 'rows': 2}),
         label=_("Metadata"), required=False,
         help_text=_("Comma-separated key=value pairs"),
-        validators=[utils_validators.validate_metadata])
+        validators=[validate_metadata])
     volume_type = forms.ChoiceField(
         label=_("Volume Type"),
         required=False)
@@ -151,6 +148,9 @@ class UnmanageVolume(forms.SelfHandlingForm):
                                 widget=forms.TextInput(
                                     attrs={'readonly': 'readonly'}))
 
+    def __init__(self, request, *args, **kwargs):
+        super(UnmanageVolume, self).__init__(request, *args, **kwargs)
+
     def handle(self, request, data):
         try:
             cinder.volume_unmanage(request, self.initial['volume_id'])
@@ -165,52 +165,21 @@ class UnmanageVolume(forms.SelfHandlingForm):
                               redirect=redirect)
 
 
-class MigrateVolume(forms.SelfHandlingForm):
-    name = forms.CharField(label=_("Volume Name"),
-                           required=False,
-                           widget=forms.TextInput(
-                           attrs={'readonly': 'readonly'}))
-    current_host = forms.CharField(label=_("Current Host"),
-                                   required=False,
-                                   widget=forms.TextInput(
-                                   attrs={'readonly': 'readonly'}))
-    host = forms.ChoiceField(label=_("Destination Host"),
-                             help_text=_("Choose a Host to migrate to."))
-    force_host_copy = forms.BooleanField(label=_("Force Host Copy"),
-                                         initial=False, required=False)
-
-    def __init__(self, request, *args, **kwargs):
-        super(MigrateVolume, self).__init__(request, *args, **kwargs)
-        initial = kwargs.get('initial', {})
-        self.fields['host'].choices = self.populate_host_choices(request,
-                                                                 initial)
-
-    def populate_host_choices(self, request, initial):
-        hosts = initial.get('hosts')
-        current_host = initial.get('current_host')
-        host_list = [(host.name, host.name)
-                     for host in hosts
-                     if host.name != current_host]
-        if host_list:
-            host_list.insert(0, ("", _("Select a new host")))
-        else:
-            host_list.insert(0, ("", _("No other hosts available")))
-        return sorted(host_list)
+class CreateVolumeType(forms.SelfHandlingForm):
+    name = forms.CharField(max_length=255, label=_("Name"))
 
     def handle(self, request, data):
         try:
-            cinder.volume_migrate(request,
-                                  self.initial['volume_id'],
-                                  data['host'],
-                                  data['force_host_copy'])
-            messages.success(
-                request,
-                _('Successfully sent the request to migrate volume: %s')
-                % data['name'])
-            return True
+            # Remove any new lines in the public key
+            volume_type = cinder.volume_type_create(request,
+                                                    data['name'])
+            messages.success(request, _('Successfully created volume type: %s')
+                             % data['name'])
+            return volume_type
         except Exception:
-            redirect = reverse("horizon:admin:volumes:volumes_tab")
-            exceptions.handle(request, _("Failed to migrate volume."),
+            redirect = reverse("horizon:admin:volumes:index")
+            exceptions.handle(request,
+                              _('Unable to create volume type.'),
                               redirect=redirect)
 
 
@@ -218,11 +187,19 @@ class UpdateStatus(forms.SelfHandlingForm):
     status = forms.ChoiceField(label=_("Status"))
 
     def __init__(self, request, *args, **kwargs):
-        super(UpdateStatus, self).__init__(request, *args, **kwargs)
+        super(forms.SelfHandlingForm, self).__init__(request, *args, **kwargs)
 
-        initial = kwargs.get('initial', {})
+        # This set of states was culled from cinder's admin_actions.py
         self.fields['status'].choices = (
-            populate_status_choices(initial, STATUS_CHOICES))
+            ('attaching', _('Attaching')),
+            ('available', _('Available')),
+            ('creating', _('Creating')),
+            ('deleting', _('Deleting')),
+            ('detaching', _('Detaching')),
+            ('error', _('Error')),
+            ('error_deleting', _('Error Deleting')),
+            ('in-use', _('In Use')),
+        )
 
     def handle(self, request, data):
         # Obtain the localized status for including in the message
@@ -246,3 +223,24 @@ class UpdateStatus(forms.SelfHandlingForm):
             exceptions.handle(request,
                               _('Unable to update volume status to "%s".') %
                               new_status, redirect=redirect)
+
+
+class CreateQosSpec(forms.SelfHandlingForm):
+    name = forms.CharField(max_length=255, label=_("Name"))
+    consumer = forms.ChoiceField(label=_("Consumer"),
+                                 choices=cinder.CONSUMER_CHOICES)
+
+    def handle(self, request, data):
+        try:
+            qos_spec = cinder.qos_spec_create(request,
+                                              data['name'],
+                                              {'consumer': data['consumer']})
+            messages.success(request,
+                             _('Successfully created QoS Spec: %s')
+                             % data['name'])
+            return qos_spec
+        except Exception:
+            redirect = reverse("horizon:admin:volumes:index")
+            exceptions.handle(request,
+                              _('Unable to create QoS Spec.'),
+                              redirect=redirect)
