@@ -12,12 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
 from openstack_dashboard.api import keystone
+from openstack_dashboard.dashboards.identity import dashboard
 
 
 class Groups(horizon.Panel):
@@ -25,8 +25,6 @@ class Groups(horizon.Panel):
     slug = 'groups'
     policy_rules = (("identity", "identity:list_groups"),)
 
-    def can_access(self, context):
-        if (settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT and
-                not keystone.is_domain_admin(context['request'])):
-            return False
-        return super().can_access(context)
+
+if keystone.VERSIONS.active >= 3:
+    dashboard.Identity.register(Groups)
