@@ -20,6 +20,7 @@ import os
 import django
 from django.core.urlresolvers import reverse
 from django import http
+from django.test.utils import override_settings
 from django.utils import timezone
 from django.utils import unittest
 
@@ -31,6 +32,7 @@ from horizon.workflows import views
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.identity.projects import workflows
+from openstack_dashboard import policy_backend
 from openstack_dashboard.test import helpers as test
 from openstack_dashboard import usage
 from openstack_dashboard.usage import quotas
@@ -44,8 +46,9 @@ from socket import timeout as socket_timeout  # noqa
 
 
 INDEX_URL = reverse('horizon:identity:projects:index')
-USER_ROLE_PREFIX = workflows.PROJECT_GROUP_MEMBER_SLUG + "_role_"
-GROUP_ROLE_PREFIX = workflows.PROJECT_USER_MEMBER_SLUG + "_role_"
+USER_ROLE_PREFIX = workflows.PROJECT_USER_MEMBER_SLUG + "_role_"
+GROUP_ROLE_PREFIX = workflows.PROJECT_GROUP_MEMBER_SLUG + "_role_"
+PROJECT_DETAIL_URL = reverse('horizon:identity:projects:detail', args=[1])
 
 
 class TenantsViewTests(test.BaseAdminViewTests):
@@ -83,6 +86,7 @@ class TenantsViewTests(test.BaseAdminViewTests):
 
 
 class ProjectsViewNonAdminTests(test.TestCase):
+    @override_settings(POLICY_CHECK_FUNCTION=policy_backend.check)
     @test.create_stubs({api.keystone: ('tenant_list',)})
     def test_index(self):
         api.keystone.tenant_list(IsA(http.HttpRequest),
@@ -212,11 +216,12 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
         self.assertEqual(step.action.initial['ram'], quota.get('ram').limit)
         self.assertEqual(step.action.initial['injected_files'],
                          quota.get('injected_files').limit)
-        self.assertQuerysetEqual(workflow.steps,
-                            ['<CreateProjectInfo: createprojectinfoaction>',
-                             '<UpdateProjectMembers: update_members>',
-                             '<UpdateProjectGroups: update_group_members>',
-                             '<CreateProjectQuota: create_quotas>'])
+        self.assertQuerysetEqual(
+            workflow.steps,
+            ['<CreateProjectInfo: createprojectinfoaction>',
+             '<UpdateProjectMembers: update_members>',
+             '<UpdateProjectGroups: update_group_members>',
+             '<CreateProjectQuota: create_quotas>'])
 
     def test_add_project_get_domain(self):
         domain = self.domains.get(id="1")
@@ -327,7 +332,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
         quota_data = self._get_quota_info(quota)
 
         api.keystone.tenant_create(IsA(http.HttpRequest), **project_details) \
-                    .AndReturn(project)
+            .AndReturn(project)
 
         workflow_data = {}
         for role in roles:
@@ -353,7 +358,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
                                      project.id,
                                      **nova_updated_quota)
         cinder_updated_quota = dict([(key, quota_data[key]) for key in
-                                   quotas.CINDER_QUOTA_FIELDS])
+                                     quotas.CINDER_QUOTA_FIELDS])
         api.cinder.tenant_quota_update(IsA(http.HttpRequest),
                                        project.id,
                                        **cinder_updated_quota)
@@ -757,6 +762,83 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         project_scope = {'project': {'id': project_id}}
         return self.role_assignments.filter(scope=project_scope)
 
+    def _check_role_list(self, keystone_api_version, role_assignments, groups,
+                         proj_users, roles, workflow_data):
+        if keystone_api_version >= 3:
+            # admin role with attempt to remove current admin, results in
+            # warning message
+            workflow_data[USER_ROLE_PREFIX + "1"] = ['3']
+
+            # member role
+            workflow_data[USER_ROLE_PREFIX + "2"] = ['1', '3']
+
+            # admin role
+            workflow_data[GROUP_ROLE_PREFIX + "1"] = ['2', '3']
+
+            # member role
+            workflow_data[GROUP_ROLE_PREFIX + "2"] = ['1', '2', '3']
+            api.keystone.role_assignments_list(IsA(http.HttpRequest),
+                                               project=self.tenant.id) \
+               .AndReturn(role_assignments)
+            # Give user 1 role 2
+            api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
+                                              project=self.tenant.id,
+                                              user='1',
+                                              role='2',)
+            # remove role 2 from user 2
+            api.keystone.remove_tenant_user_role(IsA(http.HttpRequest),
+                                                 project=self.tenant.id,
+                                                 user='2',
+                                                 role='2')
+
+            # Give user 3 role 1
+            api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
+                                              project=self.tenant.id,
+                                              user='3',
+                                              role='1',)
+            api.keystone.group_list(IsA(http.HttpRequest),
+                                    domain=self.domain.id,
+                                    project=self.tenant.id) \
+                .AndReturn(groups)
+            api.keystone.roles_for_group(IsA(http.HttpRequest),
+                                         group='1',
+                                         project=self.tenant.id) \
+                .AndReturn(roles)
+            api.keystone.remove_group_role(IsA(http.HttpRequest),
+                                           project=self.tenant.id,
+                                           group='1',
+                                           role='1')
+            api.keystone.roles_for_group(IsA(http.HttpRequest),
+                                         group='2',
+                                         project=self.tenant.id) \
+                .AndReturn(roles)
+            api.keystone.roles_for_group(IsA(http.HttpRequest),
+                                         group='3',
+                                         project=self.tenant.id) \
+                .AndReturn(roles)
+        else:
+            api.keystone.user_list(IsA(http.HttpRequest),
+                                   project=self.tenant.id) \
+               .AndReturn(proj_users)
+
+            # admin user - try to remove all roles on current project, warning
+            api.keystone.roles_for_user(IsA(http.HttpRequest), '1',
+                                        self.tenant.id).AndReturn(roles)
+
+            # member user 1 - has role 1, will remove it
+            api.keystone.roles_for_user(IsA(http.HttpRequest), '2',
+                                        self.tenant.id).AndReturn((roles[1],))
+
+            # member user 3 - has role 2
+            api.keystone.roles_for_user(IsA(http.HttpRequest), '3',
+                                        self.tenant.id).AndReturn((roles[0],))
+            # add role 2
+            api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
+                                              project=self.tenant.id,
+                                              user='3',
+                                              role='2')\
+                .AndRaise(self.exceptions.keystone)
+
     @test.create_stubs({api.keystone: ('get_default_role',
                                        'roles_for_user',
                                        'tenant_get',
@@ -815,11 +897,9 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        for group in groups:
-            api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                         group=group.id,
-                                         project=self.tenant.id) \
-                .AndReturn(roles)
+        api.keystone.role_assignments_list(IsA(http.HttpRequest),
+                                           project=self.tenant.id) \
+           .AndReturn(role_assignments)
 
         self.mox.ReplayAll()
 
@@ -840,11 +920,12 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         self.assertEqual(step.action.initial['name'], project.name)
         self.assertEqual(step.action.initial['description'],
                          project.description)
-        self.assertQuerysetEqual(workflow.steps,
-                            ['<UpdateProjectInfo: update_info>',
-                             '<UpdateProjectMembers: update_members>',
-                             '<UpdateProjectGroups: update_group_members>',
-                             '<UpdateProjectQuota: update_quotas>'])
+        self.assertQuerysetEqual(
+            workflow.steps,
+            ['<UpdateProjectInfo: update_info>',
+             '<UpdateProjectMembers: update_members>',
+             '<UpdateProjectGroups: update_group_members>',
+             '<UpdateProjectQuota: update_quotas>'])
 
     @test.create_stubs({api.keystone: ('tenant_get',
                                        'domain_get',
@@ -875,7 +956,6 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         users = self._get_all_users(domain_id)
         proj_users = self._get_proj_users(project.id)
         groups = self._get_all_groups(domain_id)
-        proj_groups = self._get_proj_groups(project.id)
         roles = self.roles.list()
         role_assignments = self._get_proj_role_assignment(project.id)
         quota_usages = self.quota_usages.first()
@@ -920,11 +1000,9 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        for group in groups:
-            api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                         group=group.id,
-                                         project=self.tenant.id) \
-                .AndReturn(roles)
+        api.keystone.role_assignments_list(IsA(http.HttpRequest),
+                                           project=self.tenant.id) \
+           .AndReturn(role_assignments)
 
         workflow_data[USER_ROLE_PREFIX + "1"] = ['3']  # admin role
         workflow_data[USER_ROLE_PREFIX + "2"] = ['2']  # member role
@@ -950,94 +1028,11 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                    **updated_project) \
             .AndReturn(project)
 
-        api.keystone.user_list(IsA(http.HttpRequest),
-                               project=self.tenant.id).AndReturn(proj_users)
-
-        # admin user - try to remove all roles on current project, warning
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '1',
-                                    self.tenant.id) \
-                           .AndReturn(roles)
-
-        # member user 1 - has role 1, will remove it
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '2',
-                                    self.tenant.id) \
-                           .AndReturn((roles[0],))
-        # remove role 1
-        api.keystone.remove_tenant_user_role(IsA(http.HttpRequest),
-                                             project=self.tenant.id,
-                                             user='2',
-                                             role='1')
-        # add role 2
-        api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
-                                          project=self.tenant.id,
-                                          user='2',
-                                          role='2')
-
-        # member user 3 - has role 2
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '3',
-                                    self.tenant.id) \
-                           .AndReturn((roles[1],))
-        # remove role 2
-        api.keystone.remove_tenant_user_role(IsA(http.HttpRequest),
-                                             project=self.tenant.id,
-                                             user='3',
-                                             role='2')
-        # add role 1
-        api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
-                                          project=self.tenant.id,
-                                          user='3',
-                                          role='1')
-
-        # Group assignments
-        api.keystone.group_list(IsA(http.HttpRequest),
-                                domain=domain_id,
-                                project=self.tenant.id).AndReturn(proj_groups)
-
-        # admin group - try to remove all roles on current project
-        api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                     group='1',
-                                     project=self.tenant.id) \
-                           .AndReturn(roles)
-        for role in roles:
-            api.keystone.remove_group_role(IsA(http.HttpRequest),
-                                           role=role.id,
-                                           group='1',
-                                           project=self.tenant.id)
-
-        # member group 1 - has role 1, will remove it
-        api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                     group='2',
-                                     project=self.tenant.id) \
-                           .AndReturn((roles[0],))
-        # remove role 1
-        api.keystone.remove_group_role(IsA(http.HttpRequest),
-                                       role='1',
-                                       group='2',
-                                       project=self.tenant.id)
-        # add role 2
-        api.keystone.add_group_role(IsA(http.HttpRequest),
-                                    role='2',
-                                    group='2',
-                                    project=self.tenant.id)
-
-        # member group 3 - has role 2
-        api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                     group='3',
-                                     project=self.tenant.id) \
-                           .AndReturn((roles[1],))
-        # remove role 2
-        api.keystone.remove_group_role(IsA(http.HttpRequest),
-                                       role='2',
-                                       group='3',
-                                       project=self.tenant.id)
-        # add role 1
-        api.keystone.add_group_role(IsA(http.HttpRequest),
-                                    role='1',
-                                    group='3',
-                                    project=self.tenant.id)
+        self._check_role_list(keystone_api_version, role_assignments, groups,
+                              proj_users, roles, workflow_data)
 
         quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
-                .AndReturn(quota_usages)
+            .AndReturn(quota_usages)
 
         nova_updated_quota = dict([(key, updated_quota[key]) for key in
                                    quotas.NOVA_QUOTA_FIELDS])
@@ -1046,7 +1041,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                      **nova_updated_quota)
 
         cinder_updated_quota = dict([(key, updated_quota[key]) for key in
-                                   quotas.CINDER_QUOTA_FIELDS])
+                                     quotas.CINDER_QUOTA_FIELDS])
         api.cinder.tenant_quota_update(IsA(http.HttpRequest),
                                        project.id,
                                        **cinder_updated_quota)
@@ -1176,12 +1171,12 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                 workflow_data.setdefault(USER_ROLE_PREFIX + role_ids[0], []) \
                              .append(user.id)
 
+        api.keystone.role_assignments_list(IsA(http.HttpRequest),
+                                           project=self.tenant.id) \
+           .AndReturn(role_assignments)
+
+        role_ids = [role.id for role in roles]
         for group in groups:
-            api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                         group=group.id,
-                                         project=self.tenant.id) \
-                .AndReturn(roles)
-            role_ids = [role.id for role in roles]
             if role_ids:
                 workflow_data.setdefault(GROUP_ROLE_PREFIX + role_ids[0], []) \
                              .append(group.id)
@@ -1200,7 +1195,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
         # handle
         quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
-                .AndReturn(quota_usages)
+            .AndReturn(quota_usages)
         api.keystone.tenant_update(IsA(http.HttpRequest),
                                    project.id,
                                    **updated_project) \
@@ -1251,7 +1246,6 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         users = self._get_all_users(domain_id)
         proj_users = self._get_proj_users(project.id)
         groups = self._get_all_groups(domain_id)
-        proj_groups = self._get_proj_groups(project.id)
         roles = self.roles.list()
         role_assignments = self._get_proj_role_assignment(project.id)
         quota_usages = self.quota_usages.first()
@@ -1293,11 +1287,9 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        for group in groups:
-            api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                         group=group.id,
-                                         project=self.tenant.id) \
-                .AndReturn(roles)
+        api.keystone.role_assignments_list(IsA(http.HttpRequest),
+                                           project=self.tenant.id) \
+           .AndReturn(role_assignments)
 
         workflow_data[USER_ROLE_PREFIX + "1"] = ['1', '3']  # admin role
         workflow_data[USER_ROLE_PREFIX + "2"] = ['1', '2', '3']  # member role
@@ -1323,67 +1315,18 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                    **updated_project) \
             .AndReturn(project)
 
-        api.keystone.user_list(IsA(http.HttpRequest),
-                               project=self.tenant.id).AndReturn(proj_users)
-
-        # admin user - try to remove all roles on current project, warning
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '1',
-                                    self.tenant.id) \
-                           .AndReturn(roles)
-
-        # member user 1 - has role 1, will remove it
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '2',
-                                    self.tenant.id) \
-                           .AndReturn((roles[1],))
-
-        # member user 3 - has role 2
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '3',
-                                    self.tenant.id) \
-                           .AndReturn((roles[0],))
-        # add role 2
-        api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
-                                          project=self.tenant.id,
-                                          user='3',
-                                          role='2')
-
-        # Group assignment
-        api.keystone.group_list(IsA(http.HttpRequest),
-                                domain=domain_id,
-                                project=self.tenant.id).AndReturn(proj_groups)
-
-        # admin group 1- try to remove all roles on current project
-        api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                     group='1',
-                                     project=self.tenant.id) \
-                           .AndReturn(roles)
-
-        # member group 1 - has no change
-        api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                     group='2',
-                                     project=self.tenant.id) \
-                           .AndReturn((roles[1],))
-
-        # member group 3 - has role 1
-        api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                     group='3',
-                                     project=self.tenant.id) \
-                           .AndReturn((roles[0],))
-
-        # add role 2
-        api.keystone.add_group_role(IsA(http.HttpRequest),
-                                    role='2',
-                                    group='3',
-                                    project=self.tenant.id)
+        self._check_role_list(keystone_api_version, role_assignments, groups,
+                              proj_users, roles, workflow_data)
 
         quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
-                .AndReturn(quota_usages)
+            .AndReturn(quota_usages)
 
         nova_updated_quota = dict([(key, updated_quota[key]) for key in
                                    quotas.NOVA_QUOTA_FIELDS])
         api.nova.tenant_quota_update(IsA(http.HttpRequest),
                                      project.id,
                                      **nova_updated_quota) \
-                            .AndRaise(self.exceptions.nova)
+            .AndRaise(self.exceptions.nova)
 
         self.mox.ReplayAll()
 
@@ -1400,7 +1343,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         res = self.client.post(url, workflow_data)
 
         self.assertNoFormErrors(res)
-        self.assertMessageCount(error=2, warning=0)
+        self.assertMessageCount(error=2, warning=1)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
     @test.create_stubs({api.keystone: ('tenant_get',
@@ -1471,11 +1414,9 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
                                             user.id,
                                             self.tenant.id).AndReturn(roles)
 
-        for group in groups:
-            api.keystone.roles_for_group(IsA(http.HttpRequest),
-                                         group=group.id,
-                                         project=self.tenant.id) \
-                .AndReturn(roles)
+        api.keystone.role_assignments_list(IsA(http.HttpRequest),
+                                           project=self.tenant.id) \
+           .AndReturn(role_assignments)
 
         workflow_data[USER_ROLE_PREFIX + "1"] = ['1', '3']  # admin role
         workflow_data[USER_ROLE_PREFIX + "2"] = ['1', '2', '3']  # member role
@@ -1496,33 +1437,14 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
 
         # handle
         quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
-                .AndReturn(quota_usages)
+            .AndReturn(quota_usages)
         api.keystone.tenant_update(IsA(http.HttpRequest),
                                    project.id,
                                    **updated_project) \
             .AndReturn(project)
 
-        api.keystone.user_list(IsA(http.HttpRequest),
-                               project=self.tenant.id).AndReturn(proj_users)
-
-        # admin user - try to remove all roles on current project, warning
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '1',
-                                    self.tenant.id).AndReturn(roles)
-
-        # member user 1 - has role 1, will remove it
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '2',
-                                    self.tenant.id).AndReturn((roles[1],))
-
-        # member user 3 - has role 2
-        api.keystone.roles_for_user(IsA(http.HttpRequest), '3',
-                                    self.tenant.id).AndReturn((roles[0],))
-        # add role 2
-        api.keystone.add_tenant_user_role(IsA(http.HttpRequest),
-                                          project=self.tenant.id,
-                                          user='3',
-                                          role='2')\
-            .AndRaise(self.exceptions.keystone)
-
+        self._check_role_list(keystone_api_version, role_assignments, groups,
+                              proj_users, roles, workflow_data)
         self.mox.ReplayAll()
 
         # submit form data
@@ -1538,44 +1460,49 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         res = self.client.post(url, workflow_data)
 
         self.assertNoFormErrors(res)
-        self.assertMessageCount(error=2, warning=0)
+        self.assertMessageCount(error=2, warning=1)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.keystone: ('get_default_role',
-                                       'tenant_get',
-                                       'domain_get'),
-                        quotas: ('get_tenant_quota_data',
-                                 'get_disabled_quotas')})
-    def test_update_project_when_default_role_does_not_exist(self):
-        project = self.tenants.first()
-        domain_id = project.domain_id
-        quota = self.quotas.first()
+        # django 1.7 and later does not handle the thrown keystoneclient
+        # exception well enough.
+        # TODO(mrunge): re-check when django-1.8 is stable
+        @unittest.skipIf(django.VERSION >= (1, 7, 0),
+                         'Currently skipped with Django >= 1.7')
+        @test.create_stubs({api.keystone: ('get_default_role',
+                                           'tenant_get',
+                                           'domain_get'),
+                            quotas: ('get_tenant_quota_data',
+                                     'get_disabled_quotas')})
+        def test_update_project_when_default_role_does_not_exist(self):
+            project = self.tenants.first()
+            domain_id = project.domain_id
+            quota = self.quotas.first()
 
-        api.keystone.get_default_role(IsA(http.HttpRequest)) \
-            .MultipleTimes().AndReturn(None)  # Default role doesn't exist
-        api.keystone.tenant_get(IsA(http.HttpRequest), self.tenant.id,
-                                admin=True) \
-            .AndReturn(project)
-        api.keystone.domain_get(IsA(http.HttpRequest), domain_id) \
-            .AndReturn(self.domain)
-        quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
-            .AndReturn(self.disabled_quotas.first())
-        quotas.get_tenant_quota_data(IsA(http.HttpRequest),
-                                     tenant_id=self.tenant.id) \
-            .AndReturn(quota)
-        self.mox.ReplayAll()
+            api.keystone.get_default_role(IsA(http.HttpRequest)) \
+                .MultipleTimes().AndReturn(None)  # Default role doesn't exist
+            api.keystone.tenant_get(IsA(http.HttpRequest), self.tenant.id,
+                                    admin=True) \
+                .AndReturn(project)
+            api.keystone.domain_get(IsA(http.HttpRequest), domain_id) \
+                .AndReturn(self.domain)
+            quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
+                .AndReturn(self.disabled_quotas.first())
+            quotas.get_tenant_quota_data(IsA(http.HttpRequest),
+                                         tenant_id=self.tenant.id) \
+                .AndReturn(quota)
+            self.mox.ReplayAll()
 
-        url = reverse('horizon:identity:projects:update',
-                      args=[self.tenant.id])
+            url = reverse('horizon:identity:projects:update',
+                          args=[self.tenant.id])
 
-        try:
-            # Avoid the log message in the test output when the workflow's
-            # step action cannot be instantiated
-            logging.disable(logging.ERROR)
-            with self.assertRaises(exceptions.NotFound):
-                self.client.get(url)
-        finally:
-            logging.disable(logging.NOTSET)
+            try:
+                # Avoid the log message in the test output when the workflow's
+                # step action cannot be instantiated
+                logging.disable(logging.ERROR)
+                with self.assertRaises(exceptions.NotFound):
+                    self.client.get(url)
+            finally:
+                logging.disable(logging.NOTSET)
 
 
 class UsageViewTests(test.BaseAdminViewTests):
@@ -1641,10 +1568,40 @@ class UsageViewTests(test.BaseAdminViewTests):
 
         self.assertTrue(isinstance(res.context['usage'], usage.ProjectUsage))
         hdr = ('Instance Name,VCPUs,RAM (MB),Disk (GB),Usage (Hours),'
-               'Uptime (Seconds),State')
+               'Time since created (Seconds),State')
         self.assertContains(res, '%s\r\n' % hdr)
 
 
+class DetailProjectViewTests(test.BaseAdminViewTests):
+    @test.create_stubs({api.keystone: ('tenant_get',)})
+    def test_detail_view(self):
+        project = self.tenants.first()
+
+        api.keystone.tenant_get(IsA(http.HttpRequest), self.tenant.id) \
+            .AndReturn(project)
+        self.mox.ReplayAll()
+
+        res = self.client.get(PROJECT_DETAIL_URL, args=[project.id])
+
+        self.assertTemplateUsed(res, 'identity/projects/detail.html')
+        self.assertEqual(res.context['project'].name, project.name)
+        self.assertEqual(res.context['project'].id, project.id)
+        self.assertContains(res, "Project Details: %s" % project.name,
+                            1, 200)
+
+    @test.create_stubs({api.keystone: ('tenant_get',)})
+    def test_detail_view_with_exception(self):
+        project = self.tenants.first()
+
+        api.keystone.tenant_get(IsA(http.HttpRequest), self.tenant.id) \
+            .AndRaise(self.exceptions.keystone)
+        self.mox.ReplayAll()
+
+        res = self.client.get(PROJECT_DETAIL_URL, args=[project.id])
+
+        self.assertRedirectsNoFollow(res, INDEX_URL)
+
+
 @unittest.skipUnless(os.environ.get('WITH_SELENIUM', False),
                      "The WITH_SELENIUM env variable is not set.")
 class SeleniumTests(test.SeleniumAdminTestCase):
@@ -1815,8 +1772,9 @@ class SeleniumTests(test.SeleniumAdminTestCase):
 
         self.mox.ReplayAll()
 
-        self.selenium.get("%s%s" % (self.live_server_url,
-                                reverse('horizon:identity:projects:create')))
+        self.selenium.get("%s%s" %
+                          (self.live_server_url,
+                           reverse('horizon:identity:projects:create')))
 
         members = self.selenium.find_element_by_css_selector(member_css_class)
 
