@@ -18,6 +18,7 @@
 
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
+from django.views import generic
 
 from horizon import exceptions
 from horizon import messages
@@ -67,6 +68,7 @@ class TenantContextMixin(object):
 class IndexView(tables.DataTableView):
     table_class = project_tables.TenantsTable
     template_name = 'identity/projects/index.html'
+    page_title = _("Projects")
 
     def has_more_data(self, table):
         return self._more
@@ -76,6 +78,7 @@ class IndexView(tables.DataTableView):
         marker = self.request.GET.get(
             project_tables.TenantsTable._meta.pagination_param, None)
         domain_context = self.request.session.get('domain_context', None)
+        self._more = False
         if policy.check((("identity", "identity:list_projects"),),
                         self.request):
             try:
@@ -85,7 +88,6 @@ class IndexView(tables.DataTableView):
                     paginate=True,
                     marker=marker)
             except Exception:
-                self._more = False
                 exceptions.handle(self.request,
                                   _("Unable to retrieve project list."))
         elif policy.check((("identity", "identity:list_user_projects"),),
@@ -98,11 +100,9 @@ class IndexView(tables.DataTableView):
                     marker=marker,
                     admin=False)
             except Exception:
-                self._more = False
                 exceptions.handle(self.request,
                                   _("Unable to retrieve project information."))
         else:
-            self._more = False
             msg = \
                 _("Insufficient privilege level to view project information.")
             messages.info(self.request, msg)
@@ -115,6 +115,7 @@ class ProjectUsageView(usage.UsageView):
     template_name = 'identity/projects/usage.html'
     csv_response_class = project_views.ProjectUsageCsvRenderer
     csv_template_name = 'project/overview/usage.csv'
+    page_title = _("Project Usage")
 
     def get_data(self):
         super(ProjectUsageView, self).get_data()
@@ -186,16 +187,16 @@ class UpdateProjectView(workflows.WorkflowView):
                     initial["domain_name"] = domain.name
                 except Exception:
                     exceptions.handle(self.request,
-                        _('Unable to retrieve project domain.'),
-                        redirect=reverse(INDEX_URL))
+                                      _('Unable to retrieve project domain.'),
+                                      redirect=reverse(INDEX_URL))
 
             # get initial project quota
             quota_data = quotas.get_tenant_quota_data(self.request,
                                                       tenant_id=project_id)
             if api.base.is_service_enabled(self.request, 'network') and \
                     api.neutron.is_quotas_extension_supported(self.request):
-                quota_data += api.neutron.tenant_quota_get(self.request,
-                                                          tenant_id=project_id)
+                quota_data += api.neutron.tenant_quota_get(
+                    self.request, tenant_id=project_id)
             for field in quotas.QUOTA_FIELDS:
                 initial[field] = quota_data.get(field).limit
         except Exception:
@@ -203,3 +204,28 @@ class UpdateProjectView(workflows.WorkflowView):
                               _('Unable to retrieve project details.'),
                               redirect=reverse(INDEX_URL))
         return initial
+
+
+class DetailProjectView(generic.TemplateView):
+    template_name = 'identity/projects/detail.html'
+
+    def get_context_data(self, **kwargs):
+        context = super(DetailProjectView, self).get_context_data(**kwargs)
+        project = self.get_data()
+        table = project_tables.TenantsTable(self.request)
+        context["project"] = project
+        context["page_title"] = _("Project Details: %s") % project.name
+        context["url"] = reverse(INDEX_URL)
+        context["actions"] = table.render_row_actions(project)
+        return context
+
+    @memoized.memoized_method
+    def get_data(self):
+        try:
+            project_id = self.kwargs['project_id']
+            project = api.keystone.tenant_get(self.request, project_id)
+        except Exception:
+            exceptions.handle(self.request,
+                              _('Unable to retrieve project details.'),
+                              redirect=reverse(INDEX_URL))
+        return project
