@@ -16,12 +16,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
-from openstack_dashboard.api import keystone
+from openstack_dashboard.dashboards.identity import dashboard
 
 
 class Users(horizon.Panel):
@@ -30,8 +29,5 @@ class Users(horizon.Panel):
     policy_rules = (("identity", "identity:get_user"),
                     ("identity", "identity:list_users"))
 
-    def can_access(self, context):
-        if (settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT and
-                not keystone.is_domain_admin(context['request'])):
-            return False
-        return super().can_access(context)
+
+dashboard.Identity.register(Users)
