@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,6 +19,7 @@ from django.template import defaultfilters as filters
 from django.utils import http
 from django.utils import safestring
 from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import messages
@@ -29,18 +28,13 @@ from horizon.utils.urlresolvers import reverse  # noqa
 
 from openstack_dashboard import api
 from openstack_dashboard.api import swift
+from openstack_dashboard.dashboards.project.containers import utils
 
 
 LOG = logging.getLogger(__name__)
 LOADING_IMAGE = '<img src="/static/dashboard/img/loading.gif" />'
 
 
-def wrap_delimiter(name):
-    if name and not name.endswith(swift.FOLDER_DELIMITER):
-        return name + swift.FOLDER_DELIMITER
-    return name
-
-
 class ViewContainer(tables.LinkAction):
     name = "view"
     verbose_name = _("View Details")
@@ -55,7 +49,7 @@ class ViewContainer(tables.LinkAction):
 class MakePublicContainer(tables.Action):
     name = "make_public"
     verbose_name = _("Make Public")
-    classes = ("btn-edit", )
+    icon = "pencil"
 
     def allowed(self, request, container):
         # Container metadata have not been loaded
@@ -81,7 +75,7 @@ class MakePublicContainer(tables.Action):
 class MakePrivateContainer(tables.Action):
     name = "make_private"
     verbose_name = _("Make Private")
-    classes = ("btn-edit", )
+    icon = "pencil"
 
     def allowed(self, request, container):
         # Container metadata have not been loaded
@@ -105,12 +99,33 @@ class MakePrivateContainer(tables.Action):
 
 
 class DeleteContainer(tables.DeleteAction):
-    data_type_singular = _("Container")
-    data_type_plural = _("Containers")
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Container",
+            u"Delete Containers",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Container",
+            u"Deleted Containers",
+            count
+        )
+
     success_url = "horizon:project:containers:index"
 
     def delete(self, request, obj_id):
-        api.swift.swift_delete_container(request, obj_id)
+        try:
+            api.swift.swift_delete_container(request, obj_id)
+        except exceptions.Conflict as exc:
+            exceptions.handle(request, exc, redirect=self.success_url)
+        except Exception:
+            exceptions.handle(request,
+                              _('Unable to delete container.'),
+                              redirect=self.success_url)
 
     def get_success_url(self, request=None):
         """Returns the URL to redirect to after a successful action.
@@ -128,18 +143,19 @@ class CreateContainer(tables.LinkAction):
     name = "create"
     verbose_name = _("Create Container")
     url = "horizon:project:containers:create"
-    classes = ("ajax-modal", "btn-create")
+    classes = ("ajax-modal",)
+    icon = "plus"
 
 
 class ListObjects(tables.LinkAction):
     name = "list_objects"
     verbose_name = _("View Container")
     url = "horizon:project:containers:index"
-    classes = ("btn-list",)
+    icon = "list"
 
     def get_link_url(self, datum=None):
         container_name = http.urlquote(datum.name)
-        args = (wrap_delimiter(container_name),)
+        args = (utils.wrap_delimiter(container_name),)
         return reverse(self.url, args=args)
 
 
@@ -147,7 +163,8 @@ class CreatePseudoFolder(tables.LinkAction):
     name = "create_pseudo_folder"
     verbose_name = _("Create Pseudo-folder")
     url = "horizon:project:containers:create_pseudo_folder"
-    classes = ("ajax-modal", "btn-create")
+    classes = ("ajax-modal",)
+    icon = "plus"
 
     def get_link_url(self, datum=None):
         # Usable for both the container and object tables
@@ -174,7 +191,8 @@ class UploadObject(tables.LinkAction):
     name = "upload"
     verbose_name = _("Upload Object")
     url = "horizon:project:containers:object_upload"
-    classes = ("ajax-modal", "btn-upload")
+    classes = ("ajax-modal",)
+    icon = "upload"
 
     def get_link_url(self, datum=None):
         # Usable for both the container and object tables
@@ -205,7 +223,7 @@ def get_size_used(container):
 
 def get_container_link(container):
     return reverse("horizon:project:containers:index",
-                   args=(wrap_delimiter(container.name),))
+                   args=(utils.wrap_delimiter(container.name),))
 
 
 class ContainerAjaxUpdateRow(tables.Row):
@@ -248,7 +266,7 @@ class ContainersTable(tables.DataTable):
                                     status_choices=METADATA_LOADED_CHOICES,
                                     hidden=True)
 
-    class Meta:
+    class Meta(object):
         name = "containers"
         verbose_name = _("Containers")
         row_class = ContainerAjaxUpdateRow
@@ -294,7 +312,8 @@ class UpdateObject(tables.LinkAction):
     name = "update_object"
     verbose_name = _("Edit")
     url = "horizon:project:containers:object_update"
-    classes = ("ajax-modal", "btn-edit")
+    classes = ("ajax-modal",)
+    icon = "pencil"
     allowed_data_types = ("objects",)
 
     def get_link_url(self, obj):
@@ -303,9 +322,23 @@ class UpdateObject(tables.LinkAction):
 
 
 class DeleteObject(tables.DeleteAction):
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Object",
+            u"Delete Objects",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Object",
+            u"Deleted Objects",
+            count
+        )
+
     name = "delete_object"
-    data_type_singular = _("Object")
-    data_type_plural = _("Objects")
     allowed_data_types = ("objects", "subfolders",)
 
     def delete(self, request, obj_id):
@@ -329,7 +362,8 @@ class CopyObject(tables.LinkAction):
     name = "copy"
     verbose_name = _("Copy")
     url = "horizon:project:containers:object_copy"
-    classes = ("ajax-modal", "btn-copy")
+    classes = ("ajax-modal",)
+    icon = "circle-arrow-right"
     allowed_data_types = ("objects",)
 
     def get_link_url(self, obj):
@@ -341,7 +375,7 @@ class DownloadObject(tables.LinkAction):
     name = "download"
     verbose_name = _("Download")
     url = "horizon:project:containers:object_download"
-    classes = ("btn-download",)
+    icon = "download"
     allowed_data_types = ("objects",)
 
     def get_link_url(self, obj):
@@ -357,7 +391,7 @@ class ObjectFilterAction(tables.FilterAction):
         request = table.request
         container = self.table.kwargs['container_name']
         subfolder = self.table.kwargs['subfolder_path']
-        prefix = wrap_delimiter(subfolder) if subfolder else ''
+        prefix = utils.wrap_delimiter(subfolder) if subfolder else ''
         self.filtered_data = api.swift.swift_filter_objects(request,
                                                             filter_string,
                                                             container,
@@ -393,8 +427,8 @@ def get_size(obj):
 def get_link_subfolder(subfolder):
     container_name = subfolder.container_name
     return reverse("horizon:project:containers:index",
-                   args=(wrap_delimiter(container_name),
-                         wrap_delimiter(subfolder.name)))
+                   args=(utils.wrap_delimiter(container_name),
+                         utils.wrap_delimiter(subfolder.name)))
 
 
 class ObjectsTable(tables.DataTable):
@@ -406,7 +440,7 @@ class ObjectsTable(tables.DataTable):
 
     size = tables.Column(get_size, verbose_name=_('Size'))
 
-    class Meta:
+    class Meta(object):
         name = "objects"
         verbose_name = _("Objects")
         table_actions = (ObjectFilterAction, CreatePseudoFolder, UploadObject,
