@@ -16,8 +16,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import tempfile
 
+import django
 from django.core.files.uploadedfile import InMemoryUploadedFile  # noqa
 from django import http
 from django.utils import http as utils_http
@@ -27,6 +29,7 @@ from mox import IsA  # noqa
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.containers import forms
 from openstack_dashboard.dashboards.project.containers import tables
+from openstack_dashboard.dashboards.project.containers import utils
 from openstack_dashboard.dashboards.project.containers import views
 from openstack_dashboard.test import helpers as test
 
@@ -49,7 +52,7 @@ def invalid_paths():
     if not INVALID_PATHS:
         for x in (CONTAINER_NAME_1_QUOTED, CONTAINER_NAME_2_QUOTED):
             y = reverse('horizon:project:containers:index',
-                        args=(tables.wrap_delimiter(x), ))
+                        args=(utils.wrap_delimiter(x), ))
             INVALID_PATHS.append(y)
         for x in (CONTAINER_NAME_1, CONTAINER_NAME_2):
             INVALID_PATHS.append(CONTAINER_INDEX_URL + x)
@@ -114,7 +117,7 @@ class SwiftTests(test.TestCase):
 
         self.assertEqual(unicode(list(req._messages)[0].message),
                          u"The container cannot be deleted "
-                         u"since it's not empty.")
+                         u"since it is not empty.")
 
     def test_create_container_get(self):
         res = self.client.get(reverse('horizon:project:containers:create'))
@@ -134,7 +137,7 @@ class SwiftTests(test.TestCase):
                         'method': forms.CreateContainer.__name__}
             res = self.client.post(
                 reverse('horizon:project:containers:create'), formData)
-            args = (tables.wrap_delimiter(container.name),)
+            args = (utils.wrap_delimiter(container.name),)
             url = reverse('horizon:project:containers:index', args=args)
             self.assertRedirectsNoFollow(res, url)
 
@@ -181,8 +184,10 @@ class SwiftTests(test.TestCase):
                                     prefix=None).AndReturn(ret)
         self.mox.ReplayAll()
 
-        res = self.client.get(reverse('horizon:project:containers:index',
-            args=[tables.wrap_delimiter(self.containers.first().name)]))
+        container_name = self.containers.first().name
+        res = self.client.get(
+            reverse('horizon:project:containers:index',
+                    args=[utils.wrap_delimiter(container_name)]))
         self.assertTemplateUsed(res, 'project/containers/index.html')
         # UTF8 encoding here to ensure there aren't problems with Nose output.
         expected = [obj.name.encode('utf8') for obj in self.objects.list()]
@@ -226,7 +231,7 @@ class SwiftTests(test.TestCase):
                     'object_file': temp_file}
         res = self.client.post(upload_url, formData)
 
-        args = (tables.wrap_delimiter(container.name),)
+        args = (utils.wrap_delimiter(container.name),)
         index_url = reverse('horizon:project:containers:index', args=args)
         self.assertRedirectsNoFollow(res, index_url)
 
@@ -258,7 +263,7 @@ class SwiftTests(test.TestCase):
                     'object_file': None}
         res = self.client.post(upload_url, formData)
 
-        args = (tables.wrap_delimiter(container.name),)
+        args = (utils.wrap_delimiter(container.name),)
         index_url = reverse('horizon:project:containers:index', args=args)
         self.assertRedirectsNoFollow(res, index_url)
 
@@ -268,8 +273,8 @@ class SwiftTests(test.TestCase):
         obj = self.objects.first()
 
         api.swift.swift_create_pseudo_folder(IsA(http.HttpRequest),
-                                      container.name,
-                                      obj.name + "/").AndReturn(obj)
+                                             container.name,
+                                             obj.name + "/").AndReturn(obj)
         self.mox.ReplayAll()
 
         create_pseudo_folder_url = reverse('horizon:project:containers:'
@@ -287,7 +292,7 @@ class SwiftTests(test.TestCase):
         res = self.client.post(create_pseudo_folder_url, formData)
 
         index_url = reverse('horizon:project:containers:index',
-                            args=[tables.wrap_delimiter(container.name)])
+                            args=[utils.wrap_delimiter(container.name)])
 
         self.assertRedirectsNoFollow(res, index_url)
 
@@ -295,7 +300,7 @@ class SwiftTests(test.TestCase):
     def test_delete(self):
         container = self.containers.first()
         obj = self.objects.first()
-        args = (tables.wrap_delimiter(container.name),)
+        args = (utils.wrap_delimiter(container.name),)
         index_url = reverse('horizon:project:containers:index', args=args)
         api.swift.swift_delete_object(IsA(http.HttpRequest),
                                       container.name,
@@ -314,7 +319,7 @@ class SwiftTests(test.TestCase):
     def test_delete_pseudo_folder(self):
         container = self.containers.first()
         folder = self.folder.first()
-        args = (tables.wrap_delimiter(container.name),)
+        args = (utils.wrap_delimiter(container.name),)
         index_url = reverse('horizon:project:containers:index', args=args)
         api.swift.swift_delete_object(IsA(http.HttpRequest),
                                       container.name,
@@ -335,19 +340,34 @@ class SwiftTests(test.TestCase):
         for container in self.containers.list():
             for obj in self.objects.list():
                 self.mox.ResetAll()  # mandatory in a for loop
-                api.swift.swift_get_object(IsA(http.HttpRequest),
-                                           container.name,
-                                           obj.name).AndReturn(obj)
+                obj = copy.copy(obj)
+                _data = obj.data
+
+                def make_iter():
+                    yield _data
+
+                obj.data = make_iter()
+                api.swift.swift_get_object(
+                    IsA(http.HttpRequest),
+                    container.name,
+                    obj.name,
+                    resp_chunk_size=api.swift.CHUNK_SIZE).AndReturn(obj)
                 self.mox.ReplayAll()
 
                 download_url = reverse(
                     'horizon:project:containers:object_download',
                     args=[container.name, obj.name])
                 res = self.client.get(download_url)
-                self.assertEqual(res.content, obj.data)
+
                 self.assertTrue(res.has_header('Content-Disposition'))
-                self.assertNotContains(res, INVALID_CONTAINER_NAME_1)
-                self.assertNotContains(res, INVALID_CONTAINER_NAME_2)
+                if django.VERSION >= (1, 5):
+                    self.assertEqual(b''.join(res.streaming_content), _data)
+                    self.assertNotContains(res, INVALID_CONTAINER_NAME_1)
+                    self.assertNotContains(res, INVALID_CONTAINER_NAME_2)
+                else:
+                    self.assertEqual(res.content, _data)
+                    self.assertNotContains(res, INVALID_CONTAINER_NAME_1)
+                    self.assertNotContains(res, INVALID_CONTAINER_NAME_2)
 
                 # Check that the returned Content-Disposition filename is well
                 # surrounded by double quotes and with commas removed
@@ -395,7 +415,7 @@ class SwiftTests(test.TestCase):
         copy_url = reverse('horizon:project:containers:object_copy',
                            args=[container_1.name, obj.name])
         res = self.client.post(copy_url, formData)
-        args = (tables.wrap_delimiter(container_2.name),)
+        args = (utils.wrap_delimiter(container_2.name),)
         index_url = reverse('horizon:project:containers:index', args=args)
         self.assertRedirectsNoFollow(res, index_url)
 
@@ -455,7 +475,7 @@ class SwiftTests(test.TestCase):
                     'object_file': temp_file}
         res = self.client.post(update_url, formData)
 
-        args = (tables.wrap_delimiter(container.name),)
+        args = (utils.wrap_delimiter(container.name),)
         index_url = reverse('horizon:project:containers:index', args=args)
         self.assertRedirectsNoFollow(res, index_url)
 
@@ -479,7 +499,7 @@ class SwiftTests(test.TestCase):
                     'name': obj.name}
         res = self.client.post(update_url, formData)
 
-        args = (tables.wrap_delimiter(container.name),)
+        args = (utils.wrap_delimiter(container.name),)
         index_url = reverse('horizon:project:containers:index', args=args)
         self.assertRedirectsNoFollow(res, index_url)
 
@@ -531,4 +551,4 @@ class SwiftTests(test.TestCase):
             'containerD/objectA': 'containerD/objectA/'
         }
         for name, expected_name in expected.items():
-            self.assertEqual(tables.wrap_delimiter(name), expected_name)
+            self.assertEqual(utils.wrap_delimiter(name), expected_name)
