@@ -45,25 +45,27 @@ class ObjectStorePanels(horizon.PanelGroup):
 
 
 class OrchestrationPanels(horizon.PanelGroup):
-    name = _("Orchestration")
     slug = "orchestration"
-    panels = ('stacks',)
+    name = _("Orchestration")
+    panels = ('stacks',
+              'stacks.resource_types',)
 
 
 class DatabasePanels(horizon.PanelGroup):
-    name = _("Database")
     slug = "database"
+    name = _("Database")
     panels = ('databases',
               'database_backups',)
 
 
 class DataProcessingPanels(horizon.PanelGroup):
-    name = _("Data Processing")
     slug = "data_processing"
-    panels = ('data_processing.clusters',
+    name = _("Data Processing")
+    panels = ('data_processing.wizard',
+              'data_processing.clusters',
+              'data_processing.job_executions',
               'data_processing.cluster_templates',
               'data_processing.nodegroup_templates',
-              'data_processing.job_executions',
               'data_processing.jobs',
               'data_processing.job_binaries',
               'data_processing.data_sources',
@@ -82,7 +84,6 @@ class Project(horizon.Dashboard):
         DatabasePanels,
         DataProcessingPanels,)
     default_panel = 'overview'
-    supports_tenants = True
 
 
 horizon.register(Project)
