@@ -14,10 +14,15 @@
 import logging
 
 from django.core.urlresolvers import reverse
+from django.http import Http404  # noqa
 from django.utils import http
+from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
+from saharaclient.api import base as api_base
+
+from horizon import messages
 from horizon import tables
 
 from openstack_dashboard.api import sahara as saharaclient
@@ -27,27 +32,38 @@ from openstack_dashboard.dashboards.project.data_processing. \
 LOG = logging.getLogger(__name__)
 
 
-class DeleteJobExecution(tables.BatchAction):
+class JobExecutionsFilterAction(tables.FilterAction):
+    filter_type = "server"
+    filter_choices = (('id', _("ID"), True),
+                      ('job', _("Job"), True),
+                      ('cluster', _("Cluster"), True),
+                      ('status', _("Status"), True))
+
+
+class JobExecutionGuide(tables.LinkAction):
+    name = "jobex_guide"
+    verbose_name = _("Job Guide")
+    url = "horizon:project:data_processing.wizard:jobex_guide"
+
+
+class DeleteJobExecution(tables.DeleteAction):
     @staticmethod
     def action_present(count):
         return ungettext_lazy(
-            u"Delete Job execution",
-            u"Delete Job executions",
+            u"Delete Job",
+            u"Delete Jobs",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ungettext_lazy(
-            u"Deleted Job execution",
-            u"Deleted Job executions",
+            u"Deleted Job",
+            u"Deleted Jobs",
             count
         )
 
-    name = "delete"
-    classes = ('btn-danger', 'btn-terminate')
-
-    def action(self, request, obj_id):
+    def delete(self, request, obj_id):
         saharaclient.job_execution_delete(request, obj_id)
 
 
@@ -107,19 +123,13 @@ class UpdateRow(tables.Row):
     ajax = True
 
     def get_data(self, request, job_execution_id):
-        job_execution = saharaclient.job_execution_get(request,
-                                                       job_execution_id)
-        return job_execution
-
-
-def get_job_link(job_execution):
-    return reverse("horizon:project:data_processing.jobs:details",
-                   args=(http.urlquote(job_execution.job_id),))
-
-
-def get_cluster_link(job_execution):
-    return reverse("horizon:project:data_processing.clusters:details",
-                   args=(http.urlquote(job_execution.cluster_id),))
+        try:
+            return saharaclient.job_execution_get(request, job_execution_id)
+        except api_base.APIException as e:
+            if e.error_code == 404:
+                raise Http404
+            else:
+                messages.error(request, _("Unable to update row"))
 
 
 class JobExecutionsTable(tables.DataTable):
@@ -127,39 +137,84 @@ class JobExecutionsTable(tables.DataTable):
         def get_raw_data(self, datum):
             return datum.info['status']
 
+    class JobNameColumn(tables.Column):
+        @staticmethod
+        def link(job_execution):
+            if job_execution.job_name:
+                return reverse("horizon:project:data_processing.jobs:details",
+                               args=(http.urlquote(job_execution.job_id),))
+            else:
+                # No link should be generated for a deleted Job.
+                return None
+
+        def get_data(self, job_execution):
+            return job_execution.job_name or _("Not available")
+
+    class ClusterNameColumn(tables.Column):
+
+        @staticmethod
+        def link(job_execution):
+            if job_execution.cluster_name:
+                return reverse(
+                    "horizon:project:data_processing.clusters:details",
+                    args=(http.urlquote(job_execution.cluster_id),))
+            else:
+                # No link should be generated for a deleted Cluster.
+                return None
+
+        def get_data(self, job_execution):
+            return job_execution.cluster_name or _("Not available")
+
     STATUS_CHOICES = (
         ("DONEWITHERROR", False),
         ("FAILED", False),
         ("KILLED", False),
         ("SUCCEEDED", True),
     )
+    STATUS_DISPLAY_CHOICES = (
+        ("DONEWITHERROR", pgettext_lazy("Current status of a Job",
+                                        u"Done with Error")),
+        ("FAILED", pgettext_lazy("Current status of a Job",
+                                 u"Failed")),
+        ("KILLED", pgettext_lazy("Current status of a Job",
+                                 u"Killed")),
+        ("SUCCEEDED", pgettext_lazy("Current status of a Job",
+                                    u"Succeeded")),
+    )
 
     name = tables.Column("id",
-        verbose_name=_("ID"),
-        display_choices=(("id", "ID"), ("name", "Name")),
-        link=("horizon:project:data_processing.job_executions:details"))
-    job_name = tables.Column(
+                         verbose_name=_("ID"),
+                         display_choices=(("id", "ID"),
+                                          ("name", pgettext_lazy("Name")),),
+                         link=("horizon:project:data_processing."
+                               "job_executions:details"))
+    job_name = JobNameColumn(
         "job_name",
-        verbose_name=_("Job"),
-        link=get_job_link)
-    cluster_name = tables.Column(
+        verbose_name=_("Job Template"),
+        link=JobNameColumn.link)
+
+    cluster_name = ClusterNameColumn(
         "cluster_name",
         verbose_name=_("Cluster"),
-        link=get_cluster_link)
+        link=ClusterNameColumn.link)
+
     status = StatusColumn("info",
-        status=True,
-        status_choices=STATUS_CHOICES,
-        verbose_name=_("Status"))
+                          status=True,
+                          status_choices=STATUS_CHOICES,
+                          display_choices=STATUS_DISPLAY_CHOICES,
+                          verbose_name=_("Status"))
 
     def get_object_display(self, datum):
         return datum.id
 
-    class Meta:
+    class Meta(object):
         name = "job_executions"
         row_class = UpdateRow
         status_columns = ["status"]
-        verbose_name = _("Job Executions")
-        table_actions = [DeleteJobExecution]
+        verbose_name = _("Jobs")
+        table_actions = [JobExecutionGuide,
+                         DeleteJobExecution,
+                         JobExecutionsFilterAction]
         row_actions = [DeleteJobExecution,
                        ReLaunchJobExistingCluster,
                        ReLaunchJobNewCluster]
