@@ -39,12 +39,14 @@ class JobExecutionGeneralConfigAction(workflows.Action):
     job_input = forms.DynamicChoiceField(
         label=_("Input"),
         initial=(None, "None"),
-        add_item_link=DATA_SOURCE_CREATE_URL)
+        add_item_link=DATA_SOURCE_CREATE_URL,
+        required=False)
 
     job_output = forms.DynamicChoiceField(
         label=_("Output"),
         initial=(None, "None"),
-        add_item_link=DATA_SOURCE_CREATE_URL)
+        add_item_link=DATA_SOURCE_CREATE_URL,
+        required=False)
 
     def __init__(self, request, *args, **kwargs):
         super(JobExecutionGeneralConfigAction, self).__init__(request,
@@ -93,7 +95,7 @@ class JobExecutionGeneralConfigAction(workflows.Action):
 
         return choices
 
-    class Meta:
+    class Meta(object):
         name = _("Job")
         help_text_template = (
             "project/data_processing.jobs/_launch_job_help.html")
@@ -118,7 +120,7 @@ class JobExecutionExistingGeneralConfigAction(JobExecutionGeneralConfigAction):
 
         return choices
 
-    class Meta:
+    class Meta(object):
         name = _("Job")
         help_text_template = (
             "project/data_processing.jobs/_launch_job_help.html")
@@ -179,8 +181,10 @@ class JobConfigAction(workflows.Action):
             if 'params' in job_configs:
                 self.fields['job_params'].initial = (
                     json.dumps(job_configs['params']))
-            job_args = json.dumps(job_configs['args'])
-            self.fields['job_args_array'].initial = job_args
+
+            if 'args' in job_configs:
+                self.fields['job_args_array'].initial = (
+                    json.dumps(job_configs['args']))
 
             if self.MAIN_CLASS in edp_configs:
                 self.fields['main_class'].initial = (
@@ -226,7 +230,7 @@ class JobConfigAction(workflows.Action):
             del configs[rmkey]
         return (configs, edp_configs)
 
-    class Meta:
+    class Meta(object):
         name = _("Configure")
         help_text_template = (
             "project/data_processing.jobs/_launch_job_configure_help.html")
@@ -238,7 +242,7 @@ class JobExecutionGeneralConfig(workflows.Step):
     def contribute(self, data, context):
         for k, v in data.items():
             if k in ["job_input", "job_output"]:
-                context["job_general_" + k] = None if v == "None" else v
+                context["job_general_" + k] = None if (v in [None, ""]) else v
             else:
                 context["job_general_" + k] = v
 
@@ -251,7 +255,7 @@ class JobExecutionExistingGeneralConfig(workflows.Step):
     def contribute(self, data, context):
         for k, v in data.items():
             if k in ["job_input", "job_output"]:
-                context["job_general_" + k] = None if v == "None" else v
+                context["job_general_" + k] = None if (v in [None, ""]) else v
             else:
                 context["job_general_" + k] = v
 
@@ -308,7 +312,7 @@ class NewClusterConfigAction(c_flow.GeneralConfigAction):
         label=_("Persist cluster after job exit"),
         required=False)
 
-    class Meta:
+    class Meta(object):
         name = _("Configure Cluster")
         help_text_template = (
             "project/data_processing.clusters/_configure_general_help.html")
@@ -390,7 +394,7 @@ class SelectHadoopPluginAction(t_flows.SelectPluginAction):
                 self.fields["job_args"].initial = (
                     json.dumps(job_configs["args"]))
 
-    class Meta:
+    class Meta(object):
         name = _("Select plugin and hadoop version for cluster")
         help_text_template = ("project/data_processing.clusters/"
                               "_create_general_help.html")
