@@ -10,12 +10,17 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import logging
 
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import forms
 from horizon import workflows
 
+from openstack_dashboard.api import network
+
+LOG = logging.getLogger(__name__)
+
 
 class Parameter(object):
     def __init__(self, config):
@@ -135,16 +140,26 @@ def parse_configs_from_context(context, defaults):
     return configs_dict
 
 
-def safe_call(func, *args, **kwargs):
-    try:
-        return func(*args, **kwargs)
-    except Exception:
-        return None
+def get_security_groups(request, security_group_ids):
+    security_groups = []
+    for group in security_group_ids or []:
+        try:
+            security_groups.append(network.security_group_get(
+                request, group))
+        except Exception:
+            LOG.info(_('Unable to retrieve security group %(group)s.') %
+                     {'group': group})
+            security_groups.append({'name': group})
+
+    return security_groups
 
 
 def get_plugin_and_hadoop_version(request):
-    plugin_name = request.REQUEST["plugin_name"]
-    hadoop_version = request.REQUEST["hadoop_version"]
+    plugin_name = None
+    hadoop_version = None
+    if request.REQUEST.get("plugin_name"):
+        plugin_name = request.REQUEST["plugin_name"]
+        hadoop_version = request.REQUEST["hadoop_version"]
     return (plugin_name, hadoop_version)
 
 
@@ -172,7 +187,7 @@ class PluginAndVersionMixin(object):
         for plugin in plugins:
             field_name = plugin.name + "_version"
             choice_field = forms.ChoiceField(
-                label=_("Hadoop Version"),
+                label=_("Version"),
                 choices=[(version, version) for version in plugin.versions],
                 widget=forms.Select(
                     attrs={"class": "plugin_version_choice "
