@@ -32,6 +32,7 @@ from openstack_dashboard.dashboards.project.database_backups import workflows
 class IndexView(horizon_tables.DataTableView):
     table_class = tables.BackupsTable
     template_name = 'project/database_backups/index.html'
+    page_title = _("Backups")
 
     def _get_extra_data(self, backup):
         """Apply extra info to the backup."""
@@ -65,6 +66,7 @@ class IndexView(horizon_tables.DataTableView):
 class BackupView(horizon_workflows.WorkflowView):
     workflow_class = workflows.CreateBackup
     template_name = "project/database_backups/backup.html"
+    page_title = _("Backup Database")
 
     def get_context_data(self, **kwargs):
         context = super(BackupView, self).get_context_data(**kwargs)
@@ -75,6 +77,7 @@ class BackupView(horizon_workflows.WorkflowView):
 
 class DetailView(horizon_views.APIView):
     template_name = "project/database_backups/details.html"
+    page_title = _("Backup Details: {{ backup.name }}")
 
     def get_data(self, request, context, *args, **kwargs):
         backup_id = kwargs.get("backup_id")
@@ -93,8 +96,8 @@ class DetailView(horizon_views.APIView):
                 backup.parent = api.trove.backup_get(request, backup.parent_id)
         except Exception:
             redirect = reverse('horizon:project:database_backups:index')
-            msg = _('Unable to retrieve details for parent backup: %s') % \
-                  backup.parent_id
+            msg = (_('Unable to retrieve details for parent backup: %s')
+                   % backup.parent_id)
             exceptions.handle(self.request, msg, redirect=redirect)
 
         try:
