@@ -39,7 +39,7 @@ class BackupDetailsAction(workflows.Action):
                                required=False,
                                help_text=_("Optional parent backup"))
 
-    class Meta:
+    class Meta(object):
         name = _("Details")
         help_text_template = \
             "project/database_backups/_backup_details_help.html"
@@ -59,7 +59,7 @@ class BackupDetailsAction(workflows.Action):
         try:
             backups = api.trove.backup_list(request)
             choices = [(b.id, b.name) for b in backups
-                if b.status == 'COMPLETED']
+                       if b.status == 'COMPLETED']
         except Exception:
             choices = []
             msg = _("Unable to list database backups for parent.")
