@@ -11,9 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: KC Wang
 
+import abc
 import logging
 
 from django.core.urlresolvers import reverse
@@ -38,9 +37,12 @@ class UpdateRule(forms.SelfHandlingForm):
         max_length=80, label=_("Description"))
     protocol = forms.ChoiceField(
         label=_("Protocol"), required=False,
+        choices=[('TCP', _('TCP')), ('UDP', _('UDP')), ('ICMP', _('ICMP')),
+                 ('ANY', _('ANY'))],
         help_text=_('Protocol for the firewall rule'))
     action = forms.ChoiceField(
         label=_("Action"), required=False,
+        choices=[('ALLOW', _('ALLOW')), ('DENY', _('DENY'))],
         help_text=_('Action for the firewall rule'))
     source_ip_address = forms.IPField(
         label=_("Source IP Address/Subnet"),
@@ -70,26 +72,6 @@ class UpdateRule(forms.SelfHandlingForm):
 
     failure_url = 'horizon:project:firewalls:index'
 
-    def __init__(self, request, *args, **kwargs):
-        super(UpdateRule, self).__init__(request, *args, **kwargs)
-
-        protocol = kwargs['initial']['protocol']
-        protocol = protocol.upper() if protocol else 'ANY'
-        action = kwargs['initial']['action'].upper()
-
-        protocol_choices = [(protocol, protocol)]
-        for tup in [('TCP', _('TCP')), ('UDP', _('UDP')), ('ICMP', _('ICMP')),
-                    ('ANY', _('ANY'))]:
-            if tup[0] != protocol:
-                protocol_choices.append(tup)
-        self.fields['protocol'].choices = protocol_choices
-
-        action_choices = [(action, action)]
-        for tup in [('ALLOW', _('ALLOW')), ('DENY', _('DENY'))]:
-            if tup[0] != action:
-                action_choices.append(tup)
-        self.fields['action'].choices = action_choices
-
     def handle(self, request, context):
         rule_id = self.initial['rule_id']
         name_or_id = context.get('name') or rule_id
@@ -147,8 +129,8 @@ class UpdateFirewall(forms.SelfHandlingForm):
                                   label=_("Description"),
                                   required=False)
     firewall_policy_id = forms.ChoiceField(label=_("Policy"))
-    # TODO(amotoki): make UP/DOWN translatable
-    admin_state_up = forms.ChoiceField(choices=[(True, 'UP'), (False, 'DOWN')],
+    admin_state_up = forms.ChoiceField(choices=[(True, _('UP')),
+                                                (False, _('DOWN'))],
                                        label=_("Admin State"))
 
     failure_url = 'horizon:project:firewalls:index'
@@ -158,7 +140,7 @@ class UpdateFirewall(forms.SelfHandlingForm):
 
         try:
             tenant_id = self.request.user.tenant_id
-            policies = api.fwaas.policy_list(request, tenant_id=tenant_id)
+            policies = api.fwaas.policy_list_for_tenant(request, tenant_id)
             policies = sorted(policies, key=lambda policy: policy.name)
         except Exception:
             exceptions.handle(request,
@@ -171,8 +153,7 @@ class UpdateFirewall(forms.SelfHandlingForm):
         firewall_policy_id_choices = [(policy_id, policy_name)]
         for p in policies:
             if p.id != policy_id:
-                p.set_id_as_name_if_empty()
-                firewall_policy_id_choices.append((p.id, p.name))
+                firewall_policy_id_choices.append((p.id, p.name_or_id))
 
         self.fields['firewall_policy_id'].choices = firewall_policy_id_choices
 
@@ -207,12 +188,10 @@ class InsertRuleToPolicy(forms.SelfHandlingForm):
     def __init__(self, request, *args, **kwargs):
         super(InsertRuleToPolicy, self).__init__(request, *args, **kwargs)
 
-        tenant_id = self.request.user.tenant_id
         try:
-            all_rules = api.fwaas.rule_list(request, tenant_id=tenant_id)
-            for r in all_rules:
-                r.set_id_as_name_if_empty()
-            all_rules = sorted(all_rules, key=lambda rule: rule.name)
+            tenant_id = self.request.user.tenant_id
+            all_rules = api.fwaas.rule_list_for_tenant(request, tenant_id)
+            all_rules = sorted(all_rules, key=lambda rule: rule.name_or_id)
 
             available_rules = [r for r in all_rules
                                if not r.firewall_policy_id]
@@ -222,8 +201,8 @@ class InsertRuleToPolicy(forms.SelfHandlingForm):
                 r_obj = [rule for rule in all_rules if r == rule.id][0]
                 current_rules.append(r_obj)
 
-            available_choices = [(r.id, r.name) for r in available_rules]
-            current_choices = [(r.id, r.name) for r in current_rules]
+            available_choices = [(r.id, r.name_or_id) for r in available_rules]
+            current_choices = [(r.id, r.name_or_id) for r in current_rules]
 
         except Exception as e:
             msg = _('Failed to retrieve available rules: %s') % e
@@ -268,18 +247,16 @@ class RemoveRuleFromPolicy(forms.SelfHandlingForm):
     def __init__(self, request, *args, **kwargs):
         super(RemoveRuleFromPolicy, self).__init__(request, *args, **kwargs)
 
-        tenant_id = request.user.tenant_id
         try:
-            all_rules = api.fwaas.rule_list(request, tenant_id=tenant_id)
-            for r in all_rules:
-                r.set_id_as_name_if_empty()
+            tenant_id = request.user.tenant_id
+            all_rules = api.fwaas.rule_list_for_tenant(request, tenant_id)
 
             current_rules = []
             for r in kwargs['initial']['firewall_rules']:
                 r_obj = [rule for rule in all_rules if r == rule.id][0]
                 current_rules.append(r_obj)
 
-            current_choices = [(r.id, r.name) for r in current_rules]
+            current_choices = [(r.id, r.name_or_id) for r in current_rules]
         except Exception as e:
             msg = _('Failed to retrieve current rules in policy %(name)s: '
                     '%(reason)s') % {'name': self.initial['name'], 'reason': e}
@@ -311,3 +288,94 @@ class RemoveRuleFromPolicy(forms.SelfHandlingForm):
             LOG.error(msg)
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
+
+
+class RouterInsertionFormBase(forms.SelfHandlingForm):
+
+    def __init__(self, request, *args, **kwargs):
+        super(RouterInsertionFormBase, self).__init__(request, *args, **kwargs)
+        try:
+            router_choices = self.get_router_choices(request, kwargs)
+            self.fields['router_ids'].choices = router_choices
+        except Exception as e:
+            msg = self.init_failure_msg % {'name': self.initial['name'],
+                                           'reason': e}
+            LOG.error(msg)
+            redirect = reverse(self.failure_url)
+            exceptions.handle(request, msg, redirect=redirect)
+
+    @abc.abstractmethod
+    def get_router_choices(self, request, kwargs):
+        """Return a list of selectable routers."""
+
+    @abc.abstractmethod
+    def get_new_router_ids(self, context):
+        """Return a new list of router IDs associated with the firewall."""
+
+    def handle(self, request, context):
+        firewall_id = self.initial['firewall_id']
+        firewall_name_or_id = self.initial['name'] or firewall_id
+        try:
+            body = {'router_ids': self.get_new_router_ids(context)}
+            firewall = api.fwaas.firewall_update(request, firewall_id, **body)
+            msg = self.success_msg % {'firewall': firewall_name_or_id}
+            LOG.debug(msg)
+            messages.success(request, msg)
+            return firewall
+        except Exception as e:
+            msg = self.failure_msg % {'name': firewall_name_or_id, 'reason': e}
+            LOG.error(msg)
+            redirect = reverse(self.failure_url)
+            exceptions.handle(request, msg, redirect=redirect)
+
+
+class AddRouterToFirewall(RouterInsertionFormBase):
+    router_ids = forms.MultipleChoiceField(
+        label=_("Add Routers"),
+        required=False,
+        widget=forms.CheckboxSelectMultiple(),
+        help_text=_("Add selected router(s) to the firewall."))
+
+    failure_url = 'horizon:project:firewalls:index'
+    success_msg = _('Router(s) was/were successfully added to firewall '
+                    '%(firewall)s.')
+    failure_msg = _('Failed to add router(s) to firewall %(name)s: %(reason)s')
+    init_failure_msg = _('Failed to retrieve available routers: %(reason)s')
+
+    def get_router_choices(self, request, kwargs):
+        tenant_id = self.request.user.tenant_id
+        routers_list = api.fwaas.firewall_unassociated_routers_list(
+            request, tenant_id)
+        return [(r.id, r.name_or_id) for r in routers_list]
+
+    def get_new_router_ids(self, context):
+        existing_router_ids = self.initial['router_ids']
+        add_router_ids = context['router_ids']
+        return add_router_ids + existing_router_ids
+
+
+class RemoveRouterFromFirewall(RouterInsertionFormBase):
+    router_ids = forms.MultipleChoiceField(
+        label=_("Remove Routers"),
+        required=False,
+        widget=forms.CheckboxSelectMultiple(),
+        help_text=_("Unselect the router(s) to be removed from firewall."))
+
+    failure_url = 'horizon:project:firewalls:index'
+    success_msg = _('Router(s)  was successfully removed from firewall '
+                    '%(firewall)s.')
+    failure_msg = _('Failed to remove router(s) from firewall %(name)s: '
+                    '%(reason)s')
+    init_failure_msg = _('Failed to retrieve current routers in firewall '
+                         '%(name)s: %(reason)s')
+
+    def get_router_choices(self, request, kwargs):
+        tenant_id = self.request.user.tenant_id
+        all_routers = api.neutron.router_list(request, tenant_id=tenant_id)
+        current_routers = [r for r in all_routers
+                           if r['id'] in kwargs['initial']['router_ids']]
+        return [(r.id, r.name_or_id) for r in current_routers]
+
+    def get_new_router_ids(self, context):
+        # context[router_ids] is router IDs to be kept.
+        return context['router_ids']
