@@ -11,17 +11,22 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: KC Wang, Big Switch Networks
+
+import logging
 
 from django.core.urlresolvers import reverse
 from django.template import defaultfilters as filters
+from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
+from horizon import exceptions
 from horizon import tables
+from openstack_dashboard import api
 from openstack_dashboard import policy
 
+LOG = logging.getLogger(__name__)
+
 
 class AddRuleLink(tables.LinkAction):
     name = "addrule"
@@ -37,6 +42,7 @@ class AddPolicyLink(tables.LinkAction):
     verbose_name = _("Add Policy")
     url = "horizon:project:firewalls:addpolicy"
     classes = ("ajax-modal", "btn-addpolicy",)
+    icon = "plus"
     policy_rules = (("network", "create_firewall_policy"),)
 
 
@@ -151,6 +157,13 @@ class UpdateFirewallLink(policy.PolicyTargetMixin, tables.LinkAction):
                            kwargs={'firewall_id': firewall.id})
         return base_url
 
+    def allowed(self, request, firewall):
+        if firewall.status in ("PENDING_CREATE",
+                               "PENDING_UPDATE",
+                               "PENDING_DELETE"):
+            return False
+        return True
+
 
 class InsertRuleToPolicyLink(policy.PolicyTargetMixin,
                              tables.LinkAction):
@@ -158,7 +171,7 @@ class InsertRuleToPolicyLink(policy.PolicyTargetMixin,
     verbose_name = _("Insert Rule")
     classes = ("ajax-modal", "btn-update",)
     policy_rules = (("network", "get_firewall_policy"),
-        ("network", "insert_rule"),)
+                    ("network", "insert_rule"),)
 
     def get_link_url(self, policy):
         base_url = reverse("horizon:project:firewalls:insertrule",
@@ -172,7 +185,7 @@ class RemoveRuleFromPolicyLink(policy.PolicyTargetMixin,
     verbose_name = _("Remove Rule")
     classes = ("ajax-modal", "btn-danger",)
     policy_rules = (("network", "get_firewall_policy"),
-        ("network", "remove_rule"),)
+                    ("network", "remove_rule"),)
 
     def get_link_url(self, policy):
         base_url = reverse("horizon:project:firewalls:removerule",
@@ -180,11 +193,59 @@ class RemoveRuleFromPolicyLink(policy.PolicyTargetMixin,
         return base_url
 
 
+class AddRouterToFirewallLink(policy.PolicyTargetMixin,
+                              tables.LinkAction):
+    name = "addrouter"
+    verbose_name = _("Add Router")
+    classes = ("ajax-modal", "btn-update",)
+    policy_rules = (("network", "get_firewall"),
+                    ("network", "add_router"),)
+
+    def get_link_url(self, firewall):
+        base_url = reverse("horizon:project:firewalls:addrouter",
+                           kwargs={'firewall_id': firewall.id})
+        return base_url
+
+    def allowed(self, request, firewall):
+        if not api.neutron.is_extension_supported(request,
+                                                  'fwaasrouterinsertion'):
+            return False
+        tenant_id = firewall['tenant_id']
+        available_routers = api.fwaas.firewall_unassociated_routers_list(
+            request, tenant_id)
+        return bool(available_routers)
+
+
+class RemoveRouterFromFirewallLink(policy.PolicyTargetMixin,
+                                   tables.LinkAction):
+    name = "removerouter"
+    verbose_name = _("Remove Router")
+    classes = ("ajax-modal", "btn-update",)
+    policy_rules = (("network", "get_firewall"),
+                    ("network", "remove_router"),)
+
+    def get_link_url(self, firewall):
+        base_url = reverse("horizon:project:firewalls:removerouter",
+                           kwargs={'firewall_id': firewall.id})
+        return base_url
+
+    def allowed(self, request, firewall):
+        if not api.neutron.is_extension_supported(request,
+                                                  'fwaasrouterinsertion'):
+            return False
+        return bool(firewall['router_ids'])
+
+
 def get_rules_name(datum):
     return ', '.join([rule.name or rule.id[:13]
                       for rule in datum.rules])
 
 
+def get_routers_name(firewall):
+    if firewall.routers:
+        return ', '.join(router['name'] for router in firewall.routers)
+
+
 def get_policy_name(datum):
     if datum.policy:
         return datum.policy.name or datum.policy.id
@@ -196,7 +257,11 @@ def get_policy_link(datum):
 
 
 class RulesTable(tables.DataTable):
-    name = tables.Column("name",
+    ACTION_DISPLAY_CHOICES = (
+        ("Allow", pgettext_lazy("Action Name of a Firewall Rule", u"ALLOW")),
+        ("Deny", pgettext_lazy("Action Name of a Firewall Rule", u"DENY")),
+    )
+    name = tables.Column("name_or_id",
                          verbose_name=_("Name"),
                          link="horizon:project:firewalls:ruledetails")
     protocol = tables.Column("protocol",
@@ -212,15 +277,16 @@ class RulesTable(tables.DataTable):
     destination_port = tables.Column("destination_port",
                                      verbose_name=_("Destination Port"))
     action = tables.Column("action",
-                           filters=(filters.upper,),
+                           display_choices=ACTION_DISPLAY_CHOICES,
                            verbose_name=_("Action"))
     enabled = tables.Column("enabled",
-                           verbose_name=_("Enabled"))
+                            verbose_name=_("Enabled"),
+                            filters=(filters.yesno, filters.capfirst))
     firewall_policy_id = tables.Column(get_policy_name,
                                        link=get_policy_link,
                                        verbose_name=_("In Policy"))
 
-    class Meta:
+    class Meta(object):
         name = "rulestable"
         verbose_name = _("Rules")
         table_actions = (AddRuleLink, DeleteRuleLink)
@@ -228,15 +294,16 @@ class RulesTable(tables.DataTable):
 
 
 class PoliciesTable(tables.DataTable):
-    name = tables.Column("name",
+    name = tables.Column("name_or_id",
                          verbose_name=_("Name"),
                          link="horizon:project:firewalls:policydetails")
     firewall_rules = tables.Column(get_rules_name,
                                    verbose_name=_("Rules"))
     audited = tables.Column("audited",
-                            verbose_name=_("Audited"))
+                            verbose_name=_("Audited"),
+                            filters=(filters.yesno, filters.capfirst))
 
-    class Meta:
+    class Meta(object):
         name = "policiestable"
         verbose_name = _("Policies")
         table_actions = (AddPolicyLink, DeletePolicyLink)
@@ -245,17 +312,61 @@ class PoliciesTable(tables.DataTable):
 
 
 class FirewallsTable(tables.DataTable):
-    name = tables.Column("name",
+    STATUS_DISPLAY_CHOICES = (
+        ("Active", pgettext_lazy("Current status of a Firewall",
+                                 u"Active")),
+        ("Down", pgettext_lazy("Current status of a Firewall",
+                               u"Down")),
+        ("Error", pgettext_lazy("Current status of a Firewall",
+                                u"Error")),
+        ("Created", pgettext_lazy("Current status of a Firewall",
+                                  u"Created")),
+        ("Pending_Create", pgettext_lazy("Current status of a Firewall",
+                                         u"Pending Create")),
+        ("Pending_Update", pgettext_lazy("Current status of a Firewall",
+                                         u"Pending Update")),
+        ("Pending_Delete", pgettext_lazy("Current status of a Firewall",
+                                         u"Pending Delete")),
+        ("Inactive", pgettext_lazy("Current status of a Firewall",
+                                   u"Inactive")),
+    )
+    ADMIN_STATE_DISPLAY_CHOICES = (
+        ("UP", pgettext_lazy("Admin state of a Firewall", u"UP")),
+        ("DOWN", pgettext_lazy("Admin state of a Firewall", u"DOWN")),
+    )
+
+    name = tables.Column("name_or_id",
                          verbose_name=_("Name"),
                          link="horizon:project:firewalls:firewalldetails")
     firewall_policy_id = tables.Column(get_policy_name,
                                        link=get_policy_link,
                                        verbose_name=_("Policy"))
+    router_ids = tables.Column(get_routers_name,
+                               verbose_name=_("Associated Routers"))
     status = tables.Column("status",
-                           verbose_name=_("Status"))
+                           verbose_name=_("Status"),
+                           display_choices=STATUS_DISPLAY_CHOICES)
+    admin_state = tables.Column("admin_state",
+                                verbose_name=_("Admin State"),
+                                display_choices=ADMIN_STATE_DISPLAY_CHOICES)
 
-    class Meta:
+    class Meta(object):
         name = "firewallstable"
         verbose_name = _("Firewalls")
         table_actions = (AddFirewallLink, DeleteFirewallLink)
-        row_actions = (UpdateFirewallLink, DeleteFirewallLink)
+        row_actions = (UpdateFirewallLink, DeleteFirewallLink,
+                       AddRouterToFirewallLink, RemoveRouterFromFirewallLink)
+
+    def __init__(self, request, data=None, needs_form_wrapper=None, **kwargs):
+        super(FirewallsTable, self).__init__(
+            request, data=data,
+            needs_form_wrapper=needs_form_wrapper, **kwargs)
+        try:
+            if not api.neutron.is_extension_supported(request,
+                                                      'fwaasrouterinsertion'):
+                del self.columns['router_ids']
+        except Exception as e:
+            msg = _('Failed to verify extension support %(reason)s') % {
+                'reason': e}
+            LOG.error(msg)
+            exceptions.handle(request, msg)
