@@ -18,6 +18,7 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.template import defaultfilters as filters
 from django.utils.http import urlencode
+from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
@@ -32,7 +33,7 @@ NOT_LAUNCHABLE_FORMATS = ['aki', 'ari']
 
 class LaunchImage(tables.LinkAction):
     name = "launch_image"
-    verbose_name = _("Launch")
+    verbose_name = _("Launch Instance")
     url = "horizon:project:instances:launch"
     classes = ("ajax-modal", "btn-launch")
     icon = "cloud-upload"
@@ -56,7 +57,33 @@ class LaunchImage(tables.LinkAction):
         return False
 
 
+class LaunchImageNG(LaunchImage):
+    name = "launch_image_ng"
+    verbose_name = _("Launch")
+    classes = ("btn-launch")
+    ajax = False
+
+    def __init__(self,
+                 attrs={
+                     "ng-controller": "LaunchInstanceModalCtrl"
+                 },
+                 **kwargs):
+        kwargs['preempt'] = True
+        super(LaunchImage, self).__init__(attrs, **kwargs)
+
+    def get_link_url(self, datum):
+        imageId = self.table.get_object_id(datum)
+        clickValue = "openLaunchInstanceWizard({successUrl: " +\
+                     "'/project/images/', imageId: '%s'})" % (imageId)
+        self.attrs['ng-click'] = clickValue
+        return "javascript:void(0);"
+
+
 class DeleteImage(tables.DeleteAction):
+    # NOTE: The bp/add-batchactions-help-text
+    # will add appropriate help text to some batch/delete actions.
+    help_text = _("Deleted images are not recoverable.")
+
     @staticmethod
     def action_present(count):
         return ungettext_lazy(
@@ -99,7 +126,7 @@ class CreateImage(tables.LinkAction):
 
 class EditImage(tables.LinkAction):
     name = "edit"
-    verbose_name = _("Edit")
+    verbose_name = _("Edit Image")
     url = "horizon:project:images:images:update"
     classes = ("ajax-modal",)
     icon = "pencil"
@@ -193,8 +220,13 @@ def get_format(image):
     format = getattr(image, "disk_format", "")
     # The "container_format" attribute can actually be set to None,
     # which will raise an error if you call upper() on it.
-    if format is not None:
-        return format.upper()
+    if not format:
+        return format
+    # Most image formats are untranslated acronyms, but raw is a word
+    # and should be translated
+    if format == "raw":
+        return pgettext_lazy("Image format for display in table", u"Raw")
+    return format.upper()
 
 
 class UpdateRow(tables.Row):
@@ -223,17 +255,30 @@ class ImagesTable(tables.DataTable):
         ("killed", False),
         ("deleted", False),
     )
+    STATUS_DISPLAY_CHOICES = (
+        ("active", pgettext_lazy("Current status of an Image", u"Active")),
+        ("saving", pgettext_lazy("Current status of an Image", u"Saving")),
+        ("queued", pgettext_lazy("Current status of an Image", u"Queued")),
+        ("pending_delete", pgettext_lazy("Current status of an Image",
+                                         u"Pending Delete")),
+        ("killed", pgettext_lazy("Current status of an Image", u"Killed")),
+        ("deleted", pgettext_lazy("Current status of an Image", u"Deleted")),
+    )
+    TYPE_CHOICES = (
+        ("image", pgettext_lazy("Type of an image", u"Image")),
+        ("snapshot", pgettext_lazy("Type of an image", u"Snapshot")),
+    )
     name = tables.Column(get_image_name,
-                         link=("horizon:project:images:images:detail"),
+                         link="horizon:project:images:images:detail",
                          verbose_name=_("Image Name"))
     image_type = tables.Column(get_image_type,
                                verbose_name=_("Type"),
-                               filters=(filters.title,))
+                               display_choices=TYPE_CHOICES)
     status = tables.Column("status",
-                           filters=(filters.title,),
                            verbose_name=_("Status"),
                            status=True,
-                           status_choices=STATUS_CHOICES)
+                           status_choices=STATUS_CHOICES,
+                           display_choices=STATUS_DISPLAY_CHOICES)
     public = tables.Column("is_public",
                            verbose_name=_("Public"),
                            empty_value=False,
@@ -248,12 +293,17 @@ class ImagesTable(tables.DataTable):
                          attrs=({"data-type": "size"}),
                          verbose_name=_("Size"))
 
-    class Meta:
+    class Meta(object):
         name = "images"
         row_class = UpdateRow
         status_columns = ["status"]
         verbose_name = _("Images")
         table_actions = (OwnerFilter, CreateImage, DeleteImage,)
-        row_actions = (LaunchImage, CreateVolumeFromImage,
-                       EditImage, DeleteImage,)
+        launch_actions = ()
+        if getattr(settings, 'LAUNCH_INSTANCE_LEGACY_ENABLED', True):
+            launch_actions = (LaunchImage,) + launch_actions
+        if getattr(settings, 'LAUNCH_INSTANCE_NG_ENABLED', False):
+            launch_actions = (LaunchImageNG,) + launch_actions
+        row_actions = launch_actions + (CreateVolumeFromImage,
+                                        EditImage, DeleteImage,)
         pagination_param = "image_marker"
