@@ -20,6 +20,8 @@ import json
 import logging
 import operator
 
+from oslo_utils import units
+
 from django.template.defaultfilters import filesizeformat  # noqa
 from django.utils.text import normalize_newlines  # noqa
 from django.utils.translation import ugettext_lazy as _
@@ -29,12 +31,14 @@ from django.views.decorators.debug import sensitive_variables  # noqa
 from horizon import exceptions
 from horizon import forms
 from horizon.utils import functions
+from horizon.utils import memoized
 from horizon.utils import validators
 from horizon import workflows
 
 from openstack_dashboard import api
 from openstack_dashboard.api import base
 from openstack_dashboard.api import cinder
+from openstack_dashboard.api import nova
 from openstack_dashboard.usage import quotas
 
 from openstack_dashboard.dashboards.project.images \
@@ -61,7 +65,7 @@ class SelectProjectUserAction(workflows.Action):
         users = [(request.user.id, request.user.username)]
         self.fields['user_id'].choices = users
 
-    class Meta:
+    class Meta(object):
         name = _("Project & User")
         # Unusable permission so this is always hidden. However, we
         # keep this step in the workflow for validation/verification purposes.
@@ -98,7 +102,7 @@ class SetInstanceDetailsAction(workflows.Action):
     volume_id = forms.ChoiceField(label=_("Volume"), required=False)
 
     volume_snapshot_id = forms.ChoiceField(label=_("Volume Snapshot"),
-                                               required=False)
+                                           required=False)
 
     image_id = forms.ChoiceField(
         label=_("Image Name"),
@@ -109,17 +113,20 @@ class SetInstanceDetailsAction(workflows.Action):
                                               filesizeformat(x.bytes)))))
 
     volume_size = forms.IntegerField(label=_("Device size (GB)"),
-                                  initial=1,
-                                  min_value=0,
-                                  required=False,
-                                  help_text=_("Volume size in gigabytes "
-                                              "(integer value)."))
+                                     initial=1,
+                                     min_value=0,
+                                     required=False,
+                                     help_text=_("Volume size in gigabytes "
+                                                 "(integer value)."))
 
     device_name = forms.CharField(label=_("Device Name"),
                                   required=False,
                                   initial="vda",
                                   help_text=_("Volume mount point (e.g. 'vda' "
-                                              "mounts at '/dev/vda')."))
+                                              "mounts at '/dev/vda'). Leave "
+                                              "this field blank to let the "
+                                              "system choose a device name "
+                                              "for you."))
 
     delete_on_terminate = forms.BooleanField(label=_("Delete on Terminate"),
                                              initial=False,
@@ -127,7 +134,7 @@ class SetInstanceDetailsAction(workflows.Action):
                                              help_text=_("Delete volume on "
                                                          "instance terminate"))
 
-    class Meta:
+    class Meta(object):
         name = _("Details")
         help_text_template = ("project/instances/"
                               "_launch_details_help.html")
@@ -138,6 +145,11 @@ class SetInstanceDetailsAction(workflows.Action):
         self.context = context
         super(SetInstanceDetailsAction, self).__init__(
             request, context, *args, **kwargs)
+
+        # Hide the device field if the hypervisor doesn't support it.
+        if not nova.can_set_mount_point():
+            self.fields['device_name'].widget = forms.widgets.HiddenInput()
+
         source_type_choices = [
             ('', _("Select source")),
             ("image_id", _("Boot from image")),
@@ -149,38 +161,21 @@ class SetInstanceDetailsAction(workflows.Action):
             try:
                 if api.nova.extension_supported("BlockDeviceMappingV2Boot",
                                                 request):
-                    source_type_choices.append(("volume_image_id",
-                            _("Boot from image (creates a new volume)")))
+                    source_type_choices.append(
+                        ("volume_image_id",
+                         _("Boot from image (creates a new volume)")))
             except Exception:
                 exceptions.handle(request, _('Unable to retrieve extensions '
-                                            'information.'))
+                                             'information.'))
 
-            source_type_choices.append(("volume_snapshot_id",
-                    _("Boot from volume snapshot (creates a new volume)")))
+            source_type_choices.append(
+                ("volume_snapshot_id",
+                 _("Boot from volume snapshot (creates a new volume)")))
         self.fields['source_type'].choices = source_type_choices
 
-    def clean(self):
-        cleaned_data = super(SetInstanceDetailsAction, self).clean()
-
-        count = cleaned_data.get('count', 1)
-        # Prevent launching more instances than the quota allows
-        usages = quotas.tenant_quota_usages(self.request)
-        available_count = usages['instances']['available']
-        if available_count < count:
-            error_message = ungettext_lazy('The requested instance '
-                                           'cannot be launched as you only '
-                                           'have %(avail)i of your quota '
-                                           'available. ',
-                                           'The requested %(req)i instances '
-                                           'cannot be launched as you only '
-                                           'have %(avail)i of your quota '
-                                           'available.',
-                                           count)
-            params = {'req': count,
-                      'avail': available_count}
-            raise forms.ValidationError(error_message % params)
+    @memoized.memoized_method
+    def _get_flavor(self, flavor_id):
         try:
-            flavor_id = cleaned_data.get('flavor')
             # We want to retrieve details for a given flavor,
             # however flavor_list uses a memoized decorator
             # so it is used instead of flavor_get to reduce the number
@@ -189,6 +184,43 @@ class SetInstanceDetailsAction(workflows.Action):
             flavor = [x for x in flavors if x.id == flavor_id][0]
         except IndexError:
             flavor = None
+        return flavor
+
+    @memoized.memoized_method
+    def _get_image(self, image_id):
+        try:
+            # We want to retrieve details for a given image,
+            # however get_available_images uses a cache of image list,
+            # so it is used instead of image_get to reduce the number
+            # of API calls.
+            images = image_utils.get_available_images(
+                self.request,
+                self.context.get('project_id'),
+                self._images_cache)
+            image = [x for x in images if x.id == image_id][0]
+        except IndexError:
+            image = None
+        return image
+
+    def _check_quotas(self, cleaned_data):
+        count = cleaned_data.get('count', 1)
+
+        # Prevent launching more instances than the quota allows
+        usages = quotas.tenant_quota_usages(self.request)
+        available_count = usages['instances']['available']
+        if available_count < count:
+            error_message = ungettext_lazy(
+                'The requested instance cannot be launched as you only '
+                'have %(avail)i of your quota available. ',
+                'The requested %(req)i instances cannot be launched as you '
+                'only have %(avail)i of your quota available.',
+                count)
+            params = {'req': count,
+                      'avail': available_count}
+            raise forms.ValidationError(error_message % params)
+
+        flavor_id = cleaned_data.get('flavor')
+        flavor = self._get_flavor(flavor_id)
 
         count_error = []
         # Validate cores and ram.
@@ -196,15 +228,15 @@ class SetInstanceDetailsAction(workflows.Action):
         if flavor and available_cores < count * flavor.vcpus:
             count_error.append(_("Cores(Available: %(avail)s, "
                                  "Requested: %(req)s)")
-                    % {'avail': available_cores,
-                       'req': count * flavor.vcpus})
+                               % {'avail': available_cores,
+                                  'req': count * flavor.vcpus})
 
         available_ram = usages['ram']['available']
         if flavor and available_ram < count * flavor.ram:
             count_error.append(_("RAM(Available: %(avail)s, "
                                  "Requested: %(req)s)")
-                    % {'avail': available_ram,
-                       'req': count * flavor.ram})
+                               % {'avail': available_ram,
+                                  'req': count * flavor.ram})
 
         if count_error:
             value_str = ", ".join(count_error)
@@ -216,103 +248,119 @@ class SetInstanceDetailsAction(workflows.Action):
             else:
                 self._errors['count'] = self.error_class([msg])
 
+    def _check_flavor_for_image(self, cleaned_data):
+        # Prevents trying to launch an image needing more resources.
+        image_id = cleaned_data.get('image_id')
+        image = self._get_image(image_id)
+        flavor_id = cleaned_data.get('flavor')
+        flavor = self._get_flavor(flavor_id)
+        if not image or not flavor:
+            return
+        props_mapping = (("min_ram", "ram"), ("min_disk", "disk"))
+        for iprop, fprop in props_mapping:
+            if getattr(image, iprop) > 0 and \
+                    getattr(image, iprop) > getattr(flavor, fprop):
+                msg = (_("The flavor '%(flavor)s' is too small "
+                         "for requested image.\n"
+                         "Minimum requirements: "
+                         "%(min_ram)s MB of RAM and "
+                         "%(min_disk)s GB of Root Disk.") %
+                       {'flavor': flavor.name,
+                        'min_ram': image.min_ram,
+                        'min_disk': image.min_disk})
+                self._errors['image_id'] = self.error_class([msg])
+                break  # Not necessary to continue the tests.
+
+    def _check_volume_for_image(self, cleaned_data):
+        image_id = cleaned_data.get('image_id')
+        image = self._get_image(image_id)
+        volume_size = cleaned_data.get('volume_size')
+        if not image or not volume_size:
+            return
+        volume_size = int(volume_size)
+        img_gigs = functions.bytes_to_gigabytes(image.size)
+        smallest_size = max(img_gigs, image.min_disk)
+        if volume_size < smallest_size:
+            msg = (_("The Volume size is too small for the"
+                     " '%(image_name)s' image and has to be"
+                     " greater than or equal to "
+                     "'%(smallest_size)d' GB.") %
+                   {'image_name': image.name,
+                    'smallest_size': smallest_size})
+            self._errors['volume_size'] = self.error_class([msg])
+
+    def _check_source_image(self, cleaned_data):
+        if not cleaned_data.get('image_id'):
+            msg = _("You must select an image.")
+            self._errors['image_id'] = self.error_class([msg])
+        else:
+            self._check_flavor_for_image(cleaned_data)
+
+    def _check_source_volume_image(self, cleaned_data):
+        volume_size = self.data.get('volume_size', None)
+        if not volume_size:
+            msg = _("You must set volume size")
+            self._errors['volume_size'] = self.error_class([msg])
+        if float(volume_size) <= 0:
+            msg = _("Volume size must be greater than 0")
+            self._errors['volume_size'] = self.error_class([msg])
+        if not cleaned_data.get('image_id'):
+            msg = _("You must select an image.")
+            self._errors['image_id'] = self.error_class([msg])
+            return
+        else:
+            self._check_flavor_for_image(cleaned_data)
+            self._check_volume_for_image(cleaned_data)
+
+    def _check_source_instance_snapshot(self, cleaned_data):
+        # using the array form of get blows up with KeyError
+        # if instance_snapshot_id is nil
+        if not cleaned_data.get('instance_snapshot_id'):
+            msg = _("You must select a snapshot.")
+            self._errors['instance_snapshot_id'] = self.error_class([msg])
+
+    def _check_source_volume(self, cleaned_data):
+        if not cleaned_data.get('volume_id'):
+            msg = _("You must select a volume.")
+            self._errors['volume_id'] = self.error_class([msg])
+        # Prevent launching multiple instances with the same volume.
+        # TODO(gabriel): is it safe to launch multiple instances with
+        # a snapshot since it should be cloned to new volumes?
+        count = cleaned_data.get('count', 1)
+        if count > 1:
+            msg = _('Launching multiple instances is only supported for '
+                    'images and instance snapshots.')
+            raise forms.ValidationError(msg)
+
+    def _check_source_volume_snapshot(self, cleaned_data):
+        if not cleaned_data.get('volume_snapshot_id'):
+            msg = _("You must select a snapshot.")
+            self._errors['volume_snapshot_id'] = self.error_class([msg])
+
+    def _check_source(self, cleaned_data):
         # Validate our instance source.
         source_type = self.data.get('source_type', None)
+        source_check_methods = {
+            'image_id': self._check_source_image,
+            'volume_image_id': self._check_source_volume_image,
+            'instance_snapshot_id': self._check_source_instance_snapshot,
+            'volume_id': self._check_source_volume,
+            'volume_snapshot_id': self._check_source_volume_snapshot
+        }
+        check_method = source_check_methods.get(source_type)
+        if check_method:
+            check_method(cleaned_data)
 
-        if source_type in ('image_id', 'volume_image_id'):
-            if source_type == 'volume_image_id':
-                volume_size = self.data.get('volume_size', None)
-                if not volume_size:
-                    msg = _("You must set volume size")
-                    self._errors['volume_size'] = self.error_class([msg])
-                if float(volume_size) <= 0:
-                    msg = _("Volume size must be greater than 0")
-                    self._errors['volume_size'] = self.error_class([msg])
-                if not cleaned_data.get('device_name'):
-                    msg = _("You must set device name")
-                    self._errors['device_name'] = self.error_class([msg])
-            if not cleaned_data.get('image_id'):
-                msg = _("You must select an image.")
-                self._errors['image_id'] = self.error_class([msg])
-            else:
-                # Prevents trying to launch an image needing more resources.
-                try:
-                    image_id = cleaned_data.get('image_id')
-                    # We want to retrieve details for a given image,
-                    # however get_available_images uses a cache of image list,
-                    # so it is used instead of image_get to reduce the number
-                    # of API calls.
-                    images = image_utils.get_available_images(
-                        self.request,
-                        self.context.get('project_id'),
-                        self._images_cache)
-                    image = [x for x in images if x.id == image_id][0]
-                except IndexError:
-                    image = None
+    def clean(self):
+        cleaned_data = super(SetInstanceDetailsAction, self).clean()
 
-                if image and flavor:
-                    props_mapping = (("min_ram", "ram"), ("min_disk", "disk"))
-                    for iprop, fprop in props_mapping:
-                        if getattr(image, iprop) > 0 and \
-                                getattr(image, iprop) > getattr(flavor, fprop):
-                            msg = (_("The flavor '%(flavor)s' is too small "
-                                     "for requested image.\n"
-                                     "Minimum requirements: "
-                                     "%(min_ram)s MB of RAM and "
-                                     "%(min_disk)s GB of Root Disk.") %
-                                   {'flavor': flavor.name,
-                                    'min_ram': image.min_ram,
-                                    'min_disk': image.min_disk})
-                            self._errors['image_id'] = self.error_class([msg])
-                            break  # Not necessary to continue the tests.
-
-                    volume_size = cleaned_data.get('volume_size')
-                    if volume_size and source_type == 'volume_image_id':
-                        volume_size = int(volume_size)
-                        img_gigs = functions.bytes_to_gigabytes(image.size)
-                        smallest_size = max(img_gigs, image.min_disk)
-                        if volume_size < smallest_size:
-                            msg = (_("The Volume size is too small for the"
-                                     " '%(image_name)s' image and has to be"
-                                     " greater than or equal to "
-                                     "'%(smallest_size)d' GB.") %
-                                   {'image_name': image.name,
-                                    'smallest_size': smallest_size})
-                            self._errors['volume_size'] = self.error_class(
-                                [msg])
-
-        elif source_type == 'instance_snapshot_id':
-            if not cleaned_data['instance_snapshot_id']:
-                msg = _("You must select a snapshot.")
-                self._errors['instance_snapshot_id'] = self.error_class([msg])
-
-        elif source_type == 'volume_id':
-            if not cleaned_data.get('volume_id'):
-                msg = _("You must select a volume.")
-                self._errors['volume_id'] = self.error_class([msg])
-            # Prevent launching multiple instances with the same volume.
-            # TODO(gabriel): is it safe to launch multiple instances with
-            # a snapshot since it should be cloned to new volumes?
-            if count > 1:
-                msg = _('Launching multiple instances is only supported for '
-                        'images and instance snapshots.')
-                raise forms.ValidationError(msg)
-
-        elif source_type == 'volume_snapshot_id':
-            if not cleaned_data.get('volume_snapshot_id'):
-                msg = _("You must select a snapshot.")
-                self._errors['volume_snapshot_id'] = self.error_class([msg])
-            if not cleaned_data.get('device_name'):
-                msg = _("You must set device name")
-                self._errors['device_name'] = self.error_class([msg])
+        self._check_quotas(cleaned_data)
+        self._check_source(cleaned_data)
 
         return cleaned_data
 
     def populate_flavor_choices(self, request, context):
-        flavors = instance_utils.flavor_list(request)
-        if flavors:
-            return instance_utils.sort_flavor_list(request, flavors)
-        return []
+        return instance_utils.flavor_field_data(request, False)
 
     def populate_availability_zone_choices(self, request, context):
         try:
@@ -323,7 +371,7 @@ class SetInstanceDetailsAction(workflows.Action):
                               _('Unable to retrieve availability zones.'))
 
         zone_list = [(zone.zoneName, zone.zoneName)
-                      for zone in zones if zone.zoneState['available']]
+                     for zone in zones if zone.zoneState['available']]
         zone_list.sort()
         if not zone_list:
             zone_list.insert(0, ("", _("No availability zones found")))
@@ -332,21 +380,21 @@ class SetInstanceDetailsAction(workflows.Action):
         return zone_list
 
     def get_help_text(self, extra_context=None):
-        extra = extra_context or {}
+        extra = {} if extra_context is None else dict(extra_context)
         try:
             extra['usages'] = api.nova.tenant_absolute_limits(self.request)
             extra['usages_json'] = json.dumps(extra['usages'])
             flavors = json.dumps([f._info for f in
                                   instance_utils.flavor_list(self.request)])
             extra['flavors'] = flavors
-            images = image_utils.get_available_images(self.request,
-                                                self.initial['project_id'],
-                                                self._images_cache)
+            images = image_utils.get_available_images(
+                self.request, self.initial['project_id'], self._images_cache)
             if images is not None:
                 attrs = [{'id': i.id,
                           'min_disk': getattr(i, 'min_disk', 0),
-                          'min_ram': getattr(i, 'min_ram', 0)}
-                          for i in images]
+                          'min_ram': getattr(i, 'min_ram', 0),
+                          'size': functions.bytes_to_gigabytes(i.size)}
+                         for i in images]
                 extra['images'] = json.dumps(attrs)
 
         except Exception:
@@ -374,10 +422,10 @@ class SetInstanceDetailsAction(workflows.Action):
     def populate_image_id_choices(self, request, context):
         choices = []
         images = image_utils.get_available_images(request,
-                                            context.get('project_id'),
-                                            self._images_cache)
+                                                  context.get('project_id'),
+                                                  self._images_cache)
         for image in images:
-            image.bytes = image.size
+            image.bytes = getattr(image, 'virtual_size', None) or image.size
             image.volume_size = max(
                 image.min_disk, functions.bytes_to_gigabytes(image.bytes))
             choices.append((image.id, image))
@@ -393,8 +441,8 @@ class SetInstanceDetailsAction(workflows.Action):
 
     def populate_instance_snapshot_id_choices(self, request, context):
         images = image_utils.get_available_images(request,
-                                            context.get('project_id'),
-                                            self._images_cache)
+                                                  context.get('project_id'),
+                                                  self._images_cache)
         choices = [(image.id, image.name)
                    for image in images
                    if image.properties.get("image_type", '') == "snapshot"]
@@ -409,10 +457,10 @@ class SetInstanceDetailsAction(workflows.Action):
         volumes = []
         try:
             if base.is_service_enabled(request, 'volume'):
+                available = api.cinder.VOLUME_STATE_AVAILABLE
                 volumes = [self._get_volume_display_name(v)
-                           for v in cinder.volume_list(self.request)
-                           if (v.status == api.cinder.VOLUME_STATE_AVAILABLE
-                               and v.bootable == 'true')]
+                           for v in cinder.volume_list(self.request,
+                           search_opts=dict(status=available, bootable=1))]
         except Exception:
             exceptions.handle(self.request,
                               _('Unable to retrieve list of volumes.'))
@@ -426,9 +474,10 @@ class SetInstanceDetailsAction(workflows.Action):
         snapshots = []
         try:
             if base.is_service_enabled(request, 'volume'):
-                snaps = cinder.volume_snapshot_list(self.request)
-                snapshots = [self._get_volume_display_name(s) for s in snaps
-                             if s.status == api.cinder.VOLUME_STATE_AVAILABLE]
+                available = api.cinder.VOLUME_STATE_AVAILABLE
+                snapshots = [self._get_volume_display_name(s)
+                             for s in cinder.volume_snapshot_list(
+                             self.request, search_opts=dict(status=available))]
         except Exception:
             exceptions.handle(self.request,
                               _('Unable to retrieve list of volume '
@@ -483,22 +532,23 @@ class SetAccessControlsAction(workflows.Action):
                                                    "authentication."),
                                        add_item_link=KEYPAIR_IMPORT_URL)
     admin_pass = forms.RegexField(
-        label=_("Admin Pass"),
+        label=_("Admin Password"),
         required=False,
         widget=forms.PasswordInput(render_value=False),
         regex=validators.password_validator(),
         error_messages={'invalid': validators.password_validator_msg()})
     confirm_admin_pass = forms.CharField(
-        label=_("Confirm Admin Pass"),
+        label=_("Confirm Admin Password"),
         required=False,
         widget=forms.PasswordInput(render_value=False))
     groups = forms.MultipleChoiceField(label=_("Security Groups"),
+                                       required=False,
                                        initial=["default"],
                                        widget=forms.CheckboxSelectMultiple(),
                                        help_text=_("Launch instance in these "
                                                    "security groups."))
 
-    class Meta:
+    class Meta(object):
         name = _("Access & Security")
         help_text = _("Control access to your instance via key pairs, "
                       "security groups, and other mechanisms.")
@@ -510,25 +560,19 @@ class SetAccessControlsAction(workflows.Action):
             del self.fields['confirm_admin_pass']
 
     def populate_keypair_choices(self, request, context):
-        try:
-            keypairs = api.nova.keypair_list(request)
-            keypair_list = [(kp.name, kp.name) for kp in keypairs]
-        except Exception:
-            keypair_list = []
-            exceptions.handle(request,
-                              _('Unable to retrieve key pairs.'))
-        if keypair_list:
-            if len(keypair_list) == 1:
-                self.fields['keypair'].initial = keypair_list[0][0]
-            keypair_list.insert(0, ("", _("Select a key pair")))
-        else:
-            keypair_list = (("", _("No key pairs available")),)
-        return keypair_list
+        keypairs = instance_utils.keypair_field_data(request, True)
+        if len(keypairs) == 2:
+            self.fields['keypair'].initial = keypairs[1][0]
+        return keypairs
 
     def populate_groups_choices(self, request, context):
         try:
             groups = api.network.security_group_list(request)
-            security_group_list = [(sg.name, sg.name) for sg in groups]
+            if base.is_service_enabled(request, 'network'):
+                security_group_list = [(sg.id, sg.name) for sg in groups]
+            else:
+                # Nova-Network requires the groups to be listed by name
+                security_group_list = [(sg.name, sg.name) for sg in groups]
         except Exception:
             exceptions.handle(request,
                               _('Unable to retrieve list of security groups'))
@@ -549,7 +593,7 @@ class SetAccessControls(workflows.Step):
     action_class = SetAccessControlsAction
     depends_on = ("project_id", "user_id")
     contributes = ("keypair_id", "security_group_ids",
-            "admin_pass", "confirm_admin_pass")
+                   "admin_pass", "confirm_admin_pass")
 
     def contribute(self, data, context):
         if data:
@@ -562,7 +606,7 @@ class SetAccessControls(workflows.Step):
 
 
 class CustomizeAction(workflows.Action):
-    class Meta:
+    class Meta(object):
         name = _("Post-Creation")
         help_text_template = ("project/instances/"
                               "_launch_customize_help.html")
@@ -621,7 +665,7 @@ class CustomizeAction(workflows.Action):
             log_script_name = upload_file.name
             LOG.info('got upload %s' % log_script_name)
 
-            if upload_file._size > 16 * 1024:  # 16kb
+            if upload_file._size > 16 * units.Ki:  # 16kb
                 msg = _('File exceeds maximum size (16kb)')
                 raise forms.ValidationError(msg)
             else:
@@ -672,24 +716,13 @@ class SetNetworkAction(workflows.Action):
             self.fields['profile'].choices = (
                 self.get_policy_profile_choices(request))
 
-    class Meta:
+    class Meta(object):
         name = _("Networking")
         permissions = ('openstack.services.network',)
         help_text = _("Select networks for your instance.")
 
     def populate_network_choices(self, request, context):
-        network_list = []
-        try:
-            tenant_id = self.request.user.tenant_id
-            networks = api.neutron.network_list_for_tenant(request, tenant_id)
-            for n in networks:
-                n.set_id_as_name_if_empty()
-                network_list.append((n.id, n.name))
-            sorted(network_list, key=lambda obj: obj[1])
-        except Exception:
-            exceptions.handle(request,
-                              _('Unable to retrieve networks.'))
-        return network_list
+        return instance_utils.network_field_data(request)
 
     def get_policy_profile_choices(self, request):
         profile_choices = [('', _("Select a profile"))]
@@ -733,11 +766,13 @@ class SetNetwork(workflows.Step):
 
 
 class SetAdvancedAction(workflows.Action):
-    disk_config = forms.ChoiceField(label=_("Disk Partition"), required=False,
+    disk_config = forms.ChoiceField(
+        label=_("Disk Partition"), required=False,
         help_text=_("Automatic: The entire disk is a single partition and "
                     "automatically resizes. Manual: Results in faster build "
                     "times but requires manual partitioning."))
-    config_drive = forms.BooleanField(label=_("Configuration Drive"),
+    config_drive = forms.BooleanField(
+        label=_("Configuration Drive"),
         required=False, help_text=_("Configure OpenStack to write metadata to "
                                     "a special configuration drive that "
                                     "attaches to the instance when it boots."))
@@ -763,7 +798,7 @@ class SetAdvancedAction(workflows.Action):
             exceptions.handle(request, _('Unable to retrieve extensions '
                                          'information.'))
 
-    class Meta:
+    class Meta(object):
         name = _("Advanced Options")
         help_text_template = ("project/instances/"
                               "_launch_advanced_help.html")
@@ -821,12 +856,14 @@ class LaunchInstance(workflows.Workflow):
         if source_type in ['image_id', 'instance_snapshot_id']:
             image_id = context['source_id']
         elif source_type in ['volume_id', 'volume_snapshot_id']:
-            dev_mapping_1 = {context['device_name']: '%s::%s' %
-                                                     (context['source_id'],
-                           int(bool(context['delete_on_terminate'])))}
+            dev_mapping_1 = {context['device_name']:
+                             '%s::%s' %
+                             (context['source_id'],
+                              int(bool(context['delete_on_terminate'])))}
         elif source_type == 'volume_image_id':
+            device_name = context.get('device_name', '').strip() or None
             dev_mapping_2 = [
-                {'device_name': str(context['device_name']),
+                {'device_name': device_name,  # None auto-selects device
                  'source_type': 'image',
                  'destination_type': 'volume',
                  'delete_on_termination':
@@ -846,26 +883,12 @@ class LaunchInstance(workflows.Workflow):
 
         avail_zone = context.get('availability_zone', None)
 
-        # Create port with Network Name and Port Profile
-        # for the use with the plugin supporting port profiles.
-        # neutron port-create <Network name> --n1kv:profile <Port Profile ID>
-        # for net_id in context['network_id']:
-        # HACK for now use first network.
-        if api.neutron.is_port_profiles_supported():
-            net_id = context['network_id'][0]
-            LOG.debug("Horizon->Create Port with %(netid)s %(profile_id)s",
-                      {'netid': net_id, 'profile_id': context['profile_id']})
-            port = None
-            try:
-                port = api.neutron.port_create(
-                    request, net_id, policy_profile_id=context['profile_id'])
-            except Exception:
-                msg = (_('Port not created for profile-id (%s).') %
-                       context['profile_id'])
-                exceptions.handle(request, msg)
+        port_profiles_supported = api.neutron.is_port_profiles_supported()
 
-            if port and port.id:
-                nics = [{"port-id": port.id}]
+        if port_profiles_supported:
+            nics = self.set_network_port_profiles(request,
+                                                  context['network_id'],
+                                                  context['profile_id'])
 
         try:
             api.nova.server_create(request,
@@ -885,5 +908,62 @@ class LaunchInstance(workflows.Workflow):
                                    config_drive=context.get('config_drive'))
             return True
         except Exception:
+            if port_profiles_supported:
+                ports_failing_deletes = _cleanup_ports_on_failed_vm_launch(
+                    request, nics)
+                if ports_failing_deletes:
+                    ports_str = ', '.join(ports_failing_deletes)
+                    msg = ('Port cleanup failed for these port-ids (%s).'
+                           % ports_str)
+                    LOG.exception(msg)
             exceptions.handle(request)
-            return False
+        return False
+
+    def set_network_port_profiles(self, request, net_ids, profile_id):
+        # Create port with Network ID and Port Profile
+        # for the use with the plugin supporting port profiles.
+        nics = []
+        for net_id in net_ids:
+            try:
+                port = api.neutron.port_create(
+                    request,
+                    net_id,
+                    policy_profile_id=profile_id,
+                )
+            except Exception as e:
+                msg = (_('Unable to create port for profile '
+                         '"%(profile_id)s": %(reason)s'),
+                       {'profile_id': profile_id,
+                        'reason': e})
+                for nic in nics:
+                    try:
+                        port_id = nic['port-id']
+                        api.neutron.port_delete(request, port_id)
+                    except Exception:
+                        msg = (msg +
+                               _(' Also failed to delete port %s') % port_id)
+                redirect = self.success_url
+                exceptions.handle(request, msg, redirect=redirect)
+
+            if port:
+                nics.append({"port-id": port.id})
+                LOG.debug("Created Port %(portid)s with "
+                          "network %(netid)s "
+                          "policy profile %(profile_id)s",
+                          {'portid': port.id,
+                           'netid': net_id,
+                           'profile_id': profile_id})
+
+        return nics
+
+
+def _cleanup_ports_on_failed_vm_launch(request, nics):
+    ports_failing_deletes = []
+    LOG.debug('Cleaning up stale VM ports.')
+    for nic in nics:
+        try:
+            LOG.debug('Deleting port with id: %s' % nic['port-id'])
+            api.neutron.port_delete(request, nic['port-id'])
+        except Exception:
+            ports_failing_deletes.append(nic['port-id'])
+    return ports_failing_deletes
