@@ -10,6 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import logging
+
 from django.utils.translation import ugettext_lazy as _
 
 import horizon
@@ -17,21 +19,29 @@ import horizon
 from openstack_dashboard.api import neutron
 from openstack_dashboard.dashboards.project import dashboard
 
+LOG = logging.getLogger(__name__)
+
 
 class LoadBalancer(horizon.Panel):
     name = _("Load Balancers")
     slug = "loadbalancers"
     permissions = ('openstack.services.network',)
 
-    def can_access(self, context):
+    def allowed(self, context):
         request = context['request']
         if not request.user.has_perms(self.permissions):
             return False
-        if not neutron.is_service_enabled(request,
-                                          config_name='enable_lb',
-                                          ext_name='lbaas'):
+        try:
+            if not neutron.is_service_enabled(request,
+                                              config_name='enable_lb',
+                                              ext_name='lbaas'):
+                return False
+        except Exception:
+            LOG.error("Call to list enabled services failed. This is likely "
+                      "due to a problem communicating with the Neutron "
+                      "endpoint. Load Balancers panel will not be displayed.")
             return False
-        if not super(LoadBalancer, self).can_access(context):
+        if not super(LoadBalancer, self).allowed(context):
             return False
         return True
 
