@@ -22,10 +22,14 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.core.urlresolvers import reverse_lazy
 from django.http import HttpResponse  # noqa
-from django.views.generic import TemplateView  # noqa
+from django.utils.translation import ugettext_lazy as _
 from django.views.generic import View  # noqa
 
+from horizon import exceptions
+from horizon import views
+
 from openstack_dashboard import api
+from openstack_dashboard.usage import quotas
 
 from openstack_dashboard.dashboards.project.network_topology.instances \
     import tables as instances_tables
@@ -34,6 +38,8 @@ from openstack_dashboard.dashboards.project.network_topology.ports \
 from openstack_dashboard.dashboards.project.network_topology.routers \
     import tables as routers_tables
 
+from openstack_dashboard.dashboards.project.instances import\
+    console as i_console
 from openstack_dashboard.dashboards.project.instances import\
     views as i_views
 from openstack_dashboard.dashboards.project.instances.workflows import\
@@ -49,6 +55,7 @@ from openstack_dashboard.dashboards.project.routers import\
 class NTCreateRouterView(r_views.CreateView):
     template_name = 'project/network_topology/create_router.html'
     success_url = reverse_lazy("horizon:project:network_topology:index")
+    page_title = _("Create a Router")
 
 
 class NTCreateNetwork(n_workflows.CreateNetwork):
@@ -89,8 +96,9 @@ class RouterDetailView(r_views.DetailView):
         pass
 
 
-class NetworkTopologyView(TemplateView):
+class NetworkTopologyView(views.HorizonTemplateView):
     template_name = 'project/network_topology/index.html'
+    page_title = _("Network Topology")
 
     def _has_permission(self, policy):
         has_permission = True
@@ -101,19 +109,29 @@ class NetworkTopologyView(TemplateView):
 
         return has_permission
 
+    def _quota_exceeded(self, quota):
+        usages = quotas.tenant_quota_usages(self.request)
+        available = usages.get(quota, {}).get('available', 1)
+        return available <= 0
+
     def get_context_data(self, **kwargs):
         context = super(NetworkTopologyView, self).get_context_data(**kwargs)
         network_config = getattr(settings, 'OPENSTACK_NEUTRON_NETWORK', {})
 
         context['launch_instance_allowed'] = self._has_permission(
             (("compute", "compute:create"),))
+        context['instance_quota_exceeded'] = self._quota_exceeded('instances')
         context['create_network_allowed'] = self._has_permission(
             (("network", "create_network"),))
+        context['network_quota_exceeded'] = self._quota_exceeded('networks')
         context['create_router_allowed'] = (
             network_config.get('enable_router', True) and
             self._has_permission((("network", "create_router"),)))
+        context['router_quota_exceeded'] = self._quota_exceeded('routers')
         context['console_type'] = getattr(
             settings, 'CONSOLE_TYPE', 'AUTO')
+        context['show_ng_launch'] = getattr(
+            settings, 'LAUNCH_INSTANCE_NG_ENABLED', False)
         return context
 
 
@@ -145,16 +163,23 @@ class JSONView(View):
             servers, more = api.nova.server_list(request)
         except Exception:
             servers = []
+        data = []
         console_type = getattr(settings, 'CONSOLE_TYPE', 'AUTO')
-        if console_type == 'SPICE':
-            console = 'spice'
-        else:
-            console = 'vnc'
-        data = [{'name': server.name,
-                 'status': server.status,
-                 'console': console,
-                 'task': getattr(server, 'OS-EXT-STS:task_state'),
-                 'id': server.id} for server in servers]
+        # lowercase of the keys will be used at the end of the console URL.
+        for server in servers:
+            try:
+                console = i_console.get_console(
+                    request, console_type, server)[0].lower()
+            except exceptions.NotAvailable:
+                console = None
+
+            server_data = {'name': server.name,
+                           'status': server.status,
+                           'task': getattr(server, 'OS-EXT-STS:task_state'),
+                           'id': server.id}
+            if console:
+                server_data['console'] = console
+            data.append(server_data)
         self.add_resource_url('horizon:project:instances:detail', data)
         return data
 
@@ -220,7 +245,7 @@ class JSONView(View):
                     'name': router.name,
                     'status': router.status,
                     'external_gateway_info': router.external_gateway_info}
-            for router in neutron_routers]
+                   for router in neutron_routers]
         self.add_resource_url('horizon:project:routers:detail', routers)
         return routers
 
@@ -236,7 +261,8 @@ class JSONView(View):
                   'fixed_ips': port.fixed_ips,
                   'device_owner': port.device_owner,
                   'status': port.status}
-                 for port in neutron_ports]
+                 for port in neutron_ports
+                 if port.device_owner != 'network:router_ha_interface']
         self.add_resource_url('horizon:project:networks:ports:detail',
                               ports)
         return ports
