@@ -16,6 +16,7 @@ import logging
 from django.core.urlresolvers import reverse
 from django import template
 from django.template import defaultfilters as filters
+from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
@@ -24,6 +25,8 @@ from horizon import tables
 
 from openstack_dashboard import api
 from openstack_dashboard import policy
+from openstack_dashboard.usage import quotas
+
 
 LOG = logging.getLogger(__name__)
 
@@ -59,22 +62,24 @@ class DeleteNetwork(policy.PolicyTargetMixin, CheckNetworkEditable,
     policy_rules = (("network", "delete_network"),)
 
     def delete(self, request, network_id):
+        network_name = network_id
         try:
-            # Retrieve existing subnets belonging to the network.
-            subnets = api.neutron.subnet_list(request, network_id=network_id)
-            LOG.debug('Network %s has subnets: %s' %
-                      (network_id, [s.id for s in subnets]))
-            for s in subnets:
-                api.neutron.subnet_delete(request, s.id)
-                LOG.debug('Deleted subnet %s' % s.id)
-
+            # Retrieve the network list.
+            network = api.neutron.network_get(request, network_id,
+                                              expand_subnet=False)
+            network_name = network.name
+            LOG.debug('Network %(network_id)s has subnets: %(subnets)s',
+                      {'network_id': network_id, 'subnets': network.subnets})
+            for subnet_id in network.subnets:
+                api.neutron.subnet_delete(request, subnet_id)
+                LOG.debug('Deleted subnet %s', subnet_id)
             api.neutron.network_delete(request, network_id)
-            LOG.debug('Deleted network %s successfully' % network_id)
+            LOG.debug('Deleted network %s successfully', network_id)
         except Exception:
-            msg = _('Failed to delete network %s') % network_id
-            LOG.info(msg)
+            msg = _('Failed to delete network %s')
+            LOG.info(msg, network_id)
             redirect = reverse("horizon:project:networks:index")
-            exceptions.handle(request, msg, redirect=redirect)
+            exceptions.handle(request, msg % network_name, redirect=redirect)
 
 
 class CreateNetwork(tables.LinkAction):
@@ -85,6 +90,20 @@ class CreateNetwork(tables.LinkAction):
     icon = "plus"
     policy_rules = (("network", "create_network"),)
 
+    def allowed(self, request, datum=None):
+        usages = quotas.tenant_quota_usages(request)
+        # when Settings.OPENSTACK_NEUTRON_NETWORK['enable_quotas'] = False
+        # usages["networks"] is empty
+        if usages.get('networks', {}).get('available', 1) <= 0:
+            if "disabled" not in self.classes:
+                self.classes = [c for c in self.classes] + ["disabled"]
+                self.verbose_name = _("Create Network (Quota exceeded)")
+        else:
+            self.verbose_name = _("Create Network")
+            self.classes = [c for c in self.classes if c != "disabled"]
+
+        return True
+
 
 class EditNetwork(policy.PolicyTargetMixin, CheckNetworkEditable,
                   tables.LinkAction):
@@ -106,6 +125,20 @@ class CreateSubnet(policy.PolicyTargetMixin, CheckNetworkEditable,
     policy_rules = (("network", "create_subnet"),)
     policy_target_attrs = (("network:project_id", "tenant_id"),)
 
+    def allowed(self, request, datum=None):
+        usages = quotas.tenant_quota_usages(request)
+        # when Settings.OPENSTACK_NEUTRON_NETWORK['enable_quotas'] = False
+        # usages["subnets'] is empty
+        if usages.get('subnets', {}).get('available', 1) <= 0:
+            if 'disabled' not in self.classes:
+                self.classes = [c for c in self.classes] + ['disabled']
+                self.verbose_name = _('Add Subnet (Quota exceeded)')
+        else:
+            self.verbose_name = _('Add Subnet')
+            self.classes = [c for c in self.classes if c != 'disabled']
+
+        return True
+
 
 def get_subnets(network):
     template_name = 'project/networks/_network_ips.html'
@@ -113,20 +146,44 @@ def get_subnets(network):
     return template.loader.render_to_string(template_name, context)
 
 
+DISPLAY_CHOICES = (
+    ("UP", pgettext_lazy("Admin state of a Network", u"UP")),
+    ("DOWN", pgettext_lazy("Admin state of a Network", u"DOWN")),
+)
+STATUS_DISPLAY_CHOICES = (
+    ("ACTIVE", pgettext_lazy("Current status of a Network", u"Active")),
+    ("BUILD", pgettext_lazy("Current status of a Network", u"Build")),
+    ("DOWN", pgettext_lazy("Current status of a Network", u"Down")),
+    ("ERROR", pgettext_lazy("Current status of a Network", u"Error")),
+)
+
+
+class NetworksFilterAction(tables.FilterAction):
+
+    def filter(self, table, networks, filter_string):
+        """Naive case-insensitive search."""
+        query = filter_string.lower()
+        return [network for network in networks
+                if query in network.name.lower()]
+
+
 class NetworksTable(tables.DataTable):
-    name = tables.Column("name",
+    name = tables.Column("name_or_id",
                          verbose_name=_("Name"),
                          link='horizon:project:networks:detail')
     subnets = tables.Column(get_subnets,
                             verbose_name=_("Subnets Associated"),)
     shared = tables.Column("shared", verbose_name=_("Shared"),
                            filters=(filters.yesno, filters.capfirst))
-    status = tables.Column("status", verbose_name=_("Status"))
+    status = tables.Column("status", verbose_name=_("Status"),
+                           display_choices=STATUS_DISPLAY_CHOICES)
     admin_state = tables.Column("admin_state",
-                                verbose_name=_("Admin State"))
+                                verbose_name=_("Admin State"),
+                                display_choices=DISPLAY_CHOICES)
 
-    class Meta:
+    class Meta(object):
         name = "networks"
         verbose_name = _("Networks")
-        table_actions = (CreateNetwork, DeleteNetwork)
+        table_actions = (CreateNetwork, DeleteNetwork,
+                         NetworksFilterAction)
         row_actions = (EditNetwork, CreateSubnet, DeleteNetwork)
