@@ -22,18 +22,26 @@ from horizon.utils import memoized
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.volumes.backups \
     import forms as backup_forms
+from openstack_dashboard.dashboards.project.volumes.backups \
+    import tables as backup_tables
 from openstack_dashboard.dashboards.project.volumes.backups \
     import tabs as backup_tabs
 
 
 class CreateBackupView(forms.ModalFormView):
     form_class = backup_forms.CreateBackupForm
+    modal_header = _("Create Volume Backup")
     template_name = 'project/volumes/backups/create_backup.html'
+    submit_label = _("Create Volume Backup")
+    submit_url = "horizon:project:volumes:volumes:create_backup"
     success_url = reverse_lazy("horizon:project:volumes:backups_tab")
+    page_title = _("Create a Volume Backup")
 
     def get_context_data(self, **kwargs):
         context = super(CreateBackupView, self).get_context_data(**kwargs)
         context['volume_id'] = self.kwargs['volume_id']
+        args = (self.kwargs['volume_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
@@ -43,10 +51,15 @@ class CreateBackupView(forms.ModalFormView):
 class BackupDetailView(tabs.TabView):
     tab_group_class = backup_tabs.BackupDetailTabs
     template_name = 'project/volumes/backups/detail.html'
+    page_title = _("Volume Backup Details: {{ backup.name }}")
 
     def get_context_data(self, **kwargs):
         context = super(BackupDetailView, self).get_context_data(**kwargs)
-        context["backup"] = self.get_data()
+        backup = self.get_data()
+        table = backup_tables.BackupsTable(self.request)
+        context["backup"] = backup
+        context["url"] = self.get_redirect_url()
+        context["actions"] = table.render_row_actions(backup)
         return context
 
     @memoized.memoized_method
@@ -56,25 +69,34 @@ class BackupDetailView(tabs.TabView):
             backup = api.cinder.volume_backup_get(self.request,
                                                   backup_id)
         except Exception:
-            redirect = reverse('horizon:project:volumes:index')
             exceptions.handle(self.request,
                               _('Unable to retrieve backup details.'),
-                              redirect=redirect)
+                              redirect=self.get_redirect_url())
         return backup
 
     def get_tabs(self, request, *args, **kwargs):
         backup = self.get_data()
         return self.tab_group_class(request, backup=backup, **kwargs)
 
+    @staticmethod
+    def get_redirect_url():
+        return reverse('horizon:project:volumes:index')
+
 
 class RestoreBackupView(forms.ModalFormView):
     form_class = backup_forms.RestoreBackupForm
+    modal_header = _("Restore Volume Backup")
     template_name = 'project/volumes/backups/restore_backup.html'
+    submit_label = _("Restore Backup to Volume")
+    submit_url = "horizon:project:volumes:volumes:create_backup"
     success_url = reverse_lazy('horizon:project:volumes:index')
+    page_title = _("Restore a Volume Backup")
 
     def get_context_data(self, **kwargs):
         context = super(RestoreBackupView, self).get_context_data(**kwargs)
         context['backup_id'] = self.kwargs['backup_id']
+        args = (self.kwargs['backup_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
