@@ -19,6 +19,7 @@ Views for managing volumes.
 from django.core.urlresolvers import reverse
 from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
+from django.views import generic
 
 from horizon import exceptions
 from horizon import forms
@@ -42,10 +43,15 @@ from openstack_dashboard.dashboards.project.volumes \
 class DetailView(tabs.TabView):
     tab_group_class = project_tabs.VolumeDetailTabs
     template_name = 'project/volumes/volumes/detail.html'
+    page_title = _("Volume Details: {{ volume.name }}")
 
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
-        context["volume"] = self.get_data()
+        volume = self.get_data()
+        table = project_tables.VolumesTable(self.request)
+        context["volume"] = volume
+        context["url"] = self.get_redirect_url()
+        context["actions"] = table.render_row_actions(volume)
         return context
 
     @memoized.memoized_method
@@ -73,8 +79,12 @@ class DetailView(tabs.TabView):
 
 class CreateView(forms.ModalFormView):
     form_class = project_forms.CreateForm
+    modal_header = _("Create Volume")
     template_name = 'project/volumes/volumes/create.html'
+    submit_label = _("Create Volume")
+    submit_url = reverse_lazy("horizon:project:volumes:volumes:create")
     success_url = reverse_lazy('horizon:project:volumes:volumes_tab')
+    page_title = _("Create a Volume")
 
     def get_context_data(self, **kwargs):
         context = super(CreateView, self).get_context_data(**kwargs)
@@ -87,8 +97,12 @@ class CreateView(forms.ModalFormView):
 
 class ExtendView(forms.ModalFormView):
     form_class = project_forms.ExtendForm
+    modal_header = _("Extend Volume")
     template_name = 'project/volumes/volumes/extend.html'
+    submit_label = _("Extend Volume")
+    submit_url = "horizon:project:volumes:volumes:extend"
     success_url = reverse_lazy("horizon:project:volumes:index")
+    page_title = _("Extend Volume")
 
     def get_object(self):
         if not hasattr(self, "_object"):
@@ -104,6 +118,8 @@ class ExtendView(forms.ModalFormView):
     def get_context_data(self, **kwargs):
         context = super(ExtendView, self).get_context_data(**kwargs)
         context['volume'] = self.get_object()
+        args = (self.kwargs['volume_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         try:
             usages = quotas.tenant_limit_usages(self.request)
             usages['gigabytesUsed'] = (usages['gigabytesUsed']
@@ -122,12 +138,17 @@ class ExtendView(forms.ModalFormView):
 
 class CreateSnapshotView(forms.ModalFormView):
     form_class = project_forms.CreateSnapshotForm
+    modal_header = _("Create Volume Snapshot")
     template_name = 'project/volumes/volumes/create_snapshot.html'
+    submit_url = "horizon:project:volumes:volumes:create_snapshot"
     success_url = reverse_lazy('horizon:project:volumes:snapshots_tab')
+    page_title = _("Create a Volume Snapshot")
 
     def get_context_data(self, **kwargs):
         context = super(CreateSnapshotView, self).get_context_data(**kwargs)
         context['volume_id'] = self.kwargs['volume_id']
+        args = (self.kwargs['volume_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         try:
             volume = cinder.volume_get(self.request, context['volume_id'])
             if (volume.status == 'in-use'):
@@ -150,8 +171,12 @@ class CreateSnapshotView(forms.ModalFormView):
 
 class UploadToImageView(forms.ModalFormView):
     form_class = project_forms.UploadToImageForm
+    modal_header = _("Upload Volume to Image")
     template_name = 'project/volumes/volumes/upload_to_image.html'
+    submit_label = _("Upload")
+    submit_url = "horizon:project:volumes:volumes:upload_to_image"
     success_url = reverse_lazy("horizon:project:volumes:index")
+    page_title = _("Upload Volume to Image")
 
     @memoized.memoized_method
     def get_data(self):
@@ -171,7 +196,8 @@ class UploadToImageView(forms.ModalFormView):
     def get_context_data(self, **kwargs):
         context = super(UploadToImageView, self).get_context_data(**kwargs)
         context['volume'] = self.get_data()
-
+        args = (self.kwargs['volume_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
@@ -182,10 +208,84 @@ class UploadToImageView(forms.ModalFormView):
                 'status': volume.status}
 
 
+class CreateTransferView(forms.ModalFormView):
+    form_class = project_forms.CreateTransferForm
+    template_name = 'project/volumes/volumes/create_transfer.html'
+    success_url = reverse_lazy('horizon:project:volumes:volumes_tab')
+    modal_id = "create_volume_transfer_modal"
+    modal_header = _("Create Volume Transfer")
+    submit_label = _("Create Volume Transfer")
+    submit_url = "horizon:project:volumes:volumes:create_transfer"
+    page_title = _("Create a Volume Transfer")
+
+    def get_context_data(self, *args, **kwargs):
+        context = super(CreateTransferView, self).get_context_data(**kwargs)
+        volume_id = self.kwargs['volume_id']
+        context['volume_id'] = volume_id
+        context['submit_url'] = reverse(self.submit_url, args=[volume_id])
+        return context
+
+    def get_initial(self):
+        return {'volume_id': self.kwargs["volume_id"]}
+
+
+class AcceptTransferView(forms.ModalFormView):
+    form_class = project_forms.AcceptTransferForm
+    template_name = 'project/volumes/volumes/accept_transfer.html'
+    success_url = reverse_lazy('horizon:project:volumes:volumes_tab')
+    modal_id = "accept_volume_transfer_modal"
+    modal_header = _("Accept Volume Transfer")
+    submit_label = _("Accept Volume Transfer")
+    submit_url = reverse_lazy(
+        "horizon:project:volumes:volumes:accept_transfer")
+    page_title = _("Accept Volume Transfer")
+
+
+class ShowTransferView(forms.ModalFormView):
+    form_class = project_forms.ShowTransferForm
+    template_name = 'project/volumes/volumes/show_transfer.html'
+    success_url = reverse_lazy('horizon:project:volumes:volumes_tab')
+    modal_id = "show_volume_transfer_modal"
+    modal_header = _("Volume Transfer")
+    submit_url = "horizon:project:volumes:volumes:show_transfer"
+    cancel_label = _("Close")
+    page_title = _("Volume Transfer Details")
+
+    def get_object(self):
+        try:
+            return self._object
+        except AttributeError:
+            transfer_id = self.kwargs['transfer_id']
+            try:
+                self._object = cinder.transfer_get(self.request, transfer_id)
+                return self._object
+            except Exception:
+                exceptions.handle(self.request,
+                                  _('Unable to retrieve volume transfer.'))
+
+    def get_context_data(self, **kwargs):
+        context = super(ShowTransferView, self).get_context_data(**kwargs)
+        context['transfer_id'] = self.kwargs['transfer_id']
+        context['auth_key'] = self.kwargs['auth_key']
+        context['submit_url'] = reverse(self.submit_url, args=[
+            context['transfer_id'], context['auth_key']])
+        return context
+
+    def get_initial(self):
+        transfer = self.get_object()
+        return {'id': transfer.id,
+                'name': transfer.name,
+                'auth_key': self.kwargs['auth_key']}
+
+
 class UpdateView(forms.ModalFormView):
     form_class = project_forms.UpdateForm
+    modal_header = _("Edit Volume")
+    modal_id = "update_volume_modal"
     template_name = 'project/volumes/volumes/update.html'
+    submit_url = "horizon:project:volumes:volumes:update"
     success_url = reverse_lazy("horizon:project:volumes:index")
+    page_title = _("Edit Volume")
 
     def get_object(self):
         if not hasattr(self, "_object"):
@@ -201,20 +301,28 @@ class UpdateView(forms.ModalFormView):
     def get_context_data(self, **kwargs):
         context = super(UpdateView, self).get_context_data(**kwargs)
         context['volume'] = self.get_object()
+        args = (self.kwargs['volume_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
         volume = self.get_object()
         return {'volume_id': self.kwargs["volume_id"],
                 'name': volume.name,
-                'description': volume.description}
+                'description': volume.description,
+                'bootable': volume.is_bootable}
 
 
 class EditAttachmentsView(tables.DataTableView, forms.ModalFormView):
     table_class = project_tables.AttachmentsTable
     form_class = project_forms.AttachForm
+    form_id = "attach_volume_form"
+    modal_header = _("Manage Volume Attachments")
+    modal_id = "attach_volume_modal"
     template_name = 'project/volumes/volumes/attach.html'
+    submit_url = "horizon:project:volumes:volumes:attach"
     success_url = reverse_lazy("horizon:project:volumes:index")
+    page_title = _("Manage Volume Attachments")
 
     @memoized.memoized_method
     def get_object(self):
@@ -246,14 +354,16 @@ class EditAttachmentsView(tables.DataTableView, forms.ModalFormView):
                 'instances': instances}
 
     @memoized.memoized_method
-    def get_form(self):
-        form_class = self.get_form_class()
+    def get_form(self, **kwargs):
+        form_class = kwargs.get('form_class', self.get_form_class())
         return super(EditAttachmentsView, self).get_form(form_class)
 
     def get_context_data(self, **kwargs):
         context = super(EditAttachmentsView, self).get_context_data(**kwargs)
         context['form'] = self.get_form()
         volume = self.get_object()
+        args = (self.kwargs['volume_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         if volume and volume.status == 'available':
             context['show_attach'] = True
         else:
@@ -280,8 +390,13 @@ class EditAttachmentsView(tables.DataTableView, forms.ModalFormView):
 
 class RetypeView(forms.ModalFormView):
     form_class = project_forms.RetypeForm
+    modal_id = "retype_volume_modal"
+    modal_header = _("Change Volume Type")
     template_name = 'project/volumes/volumes/retype.html'
+    submit_label = _("Change Volume Type")
+    submit_url = "horizon:project:volumes:volumes:retype"
     success_url = reverse_lazy("horizon:project:volumes:index")
+    page_title = _("Change Volume Type")
 
     @memoized.memoized_method
     def get_data(self):
@@ -301,7 +416,8 @@ class RetypeView(forms.ModalFormView):
     def get_context_data(self, **kwargs):
         context = super(RetypeView, self).get_context_data(**kwargs)
         context['volume'] = self.get_data()
-
+        args = (self.kwargs['volume_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     def get_initial(self):
@@ -310,3 +426,48 @@ class RetypeView(forms.ModalFormView):
         return {'id': self.kwargs['volume_id'],
                 'name': volume.name,
                 'volume_type': volume.volume_type}
+
+
+class EncryptionDetailView(generic.TemplateView):
+    template_name = 'project/volumes/volumes/encryption_detail.html'
+    page_title = _("Volume Encryption Details: {{ volume.name }}")
+
+    def get_context_data(self, **kwargs):
+        context = super(EncryptionDetailView, self).get_context_data(**kwargs)
+        volume = self.get_volume_data()
+        context["encryption_metadata"] = self.get_encryption_data()
+        context["volume"] = volume
+        context["page_title"] = _("Volume Encryption Details: "
+                                  "%(volume_name)s") % {'volume_name':
+                                                        volume.name}
+        return context
+
+    @memoized.memoized_method
+    def get_encryption_data(self):
+        try:
+            volume_id = self.kwargs['volume_id']
+            self._encryption_metadata = \
+                cinder.volume_get_encryption_metadata(self.request,
+                                                      volume_id)
+        except Exception:
+            redirect = self.get_redirect_url()
+            exceptions.handle(self.request,
+                              _('Unable to retrieve volume encryption '
+                                'details.'),
+                              redirect=redirect)
+        return self._encryption_metadata
+
+    @memoized.memoized_method
+    def get_volume_data(self):
+        try:
+            volume_id = self.kwargs['volume_id']
+            volume = cinder.volume_get(self.request, volume_id)
+        except Exception:
+            redirect = self.get_redirect_url()
+            exceptions.handle(self.request,
+                              _('Unable to retrieve volume details.'),
+                              redirect=redirect)
+        return volume
+
+    def get_redirect_url(self):
+        return reverse('horizon:project:volumes:index')
