@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -11,14 +9,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Abishek Subramanian, Cisco Systems, Inc.
-# @author: Sergey Sudakovich,   Cisco Systems, Inc.
 
 import logging
 
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import tables
@@ -32,12 +28,26 @@ class CreateNetworkProfile(tables.LinkAction):
     name = "create"
     verbose_name = _("Create Network Profile")
     url = "horizon:router:nexus1000v:create_network_profile"
-    classes = ("ajax-modal", "btn-create")
+    classes = ("ajax-modal",)
+    icon = "plus"
 
 
 class DeleteNetworkProfile(tables.DeleteAction):
-    data_type_singular = _("Network Profile")
-    data_type_plural = _("Network Profiles")
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Network Profile",
+            u"Delete Network Profiles",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Network Profile",
+            u"Deleted Network Profiles",
+            count
+        )
 
     def delete(self, request, obj_id):
         try:
@@ -53,7 +63,8 @@ class EditNetworkProfile(tables.LinkAction):
     name = "update"
     verbose_name = _("Edit Network Profile")
     url = "horizon:router:nexus1000v:update_network_profile"
-    classes = ("ajax-modal", "btn-edit")
+    classes = ("ajax-modal",)
+    icon = "pencil"
 
 
 class NetworkProfile(tables.DataTable):
@@ -71,7 +82,7 @@ class NetworkProfile(tables.DataTable):
     physical_network = tables.Column("physical_network",
                                      verbose_name=_("Physical Network Name"))
 
-    class Meta:
+    class Meta(object):
         name = "network_profile"
         verbose_name = _("Network Profile")
         table_actions = (CreateNetworkProfile, DeleteNetworkProfile,)
@@ -83,6 +94,6 @@ class PolicyProfile(tables.DataTable):
     name = tables.Column("name", verbose_name=_("Policy Profile"), )
     project = tables.Column("project_name", verbose_name=_("Project"))
 
-    class Meta:
+    class Meta(object):
         name = "policy_profile"
         verbose_name = _("Policy Profile")
