@@ -9,13 +9,11 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Abishek Subramanian, Cisco Systems, Inc.
-# @author: Sergey Sudakovich,   Cisco Systems, Inc.
 
 import logging
 
-from django.core import urlresolvers
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django.utils import datastructures
 from django.utils.translation import ugettext_lazy as _
 
@@ -54,22 +52,13 @@ def _get_profiles(request, type_p):
         profiles = []
         msg = _('Network Profiles could not be retrieved.')
         exceptions.handle(request, msg)
-    if profiles:
-        # Set project name
-        tenant_dict = _get_tenant_list(request)
-        bindings = api.neutron.profile_bindings_list(request, type_p)
-        bindings_dict = datastructures.SortedDict(
-            [(b.profile_id, b.tenant_id) for b in bindings])
-        for p in profiles:
-            project_id = bindings_dict.get(p.id)
-            project = tenant_dict.get(project_id)
-            p.project_name = getattr(project, 'name', None)
     return profiles
 
 
 class NetworkProfileIndexView(tables.DataTableView):
     table_class = profiletables.NetworkProfile
     template_name = 'router/nexus1000v/network_profile/index.html'
+    page_title = _("Cisco Nexus 1000V")
 
     def get_data(self):
         return _get_profiles(self.request, 'network')
@@ -78,6 +67,7 @@ class NetworkProfileIndexView(tables.DataTableView):
 class PolicyProfileIndexView(tables.DataTableView):
     table_class = profiletables.PolicyProfile
     template_name = 'router/nexus1000v/policy_profile/index.html'
+    page_title = _("Cisco Nexus 1000V")
 
     def get_data(self):
         return _get_profiles(self.request, 'policy')
@@ -89,9 +79,9 @@ class IndexTabGroup(tabs.TabGroup):
 
 
 class IndexView(tables.MultiTableView):
-    table_classes = (profiletables.NetworkProfile,
-                     profiletables.PolicyProfile,)
+    table_classes = (profiletables.PolicyProfile,)
     template_name = 'router/nexus1000v/index.html'
+    page_title = _("Cisco Nexus 1000V")
 
     def get_network_profile_data(self):
         return _get_profiles(self.request, 'network')
@@ -102,20 +92,33 @@ class IndexView(tables.MultiTableView):
 
 class CreateNetworkProfileView(forms.ModalFormView):
     form_class = profileforms.CreateNetworkProfile
+    form_id = "create_network_profile_form"
+    modal_header = _("Create Network Profile")
     template_name = 'router/nexus1000v/create_network_profile.html'
-    success_url = urlresolvers.reverse_lazy('horizon:router:nexus1000v:index')
+    submit_label = _("Create Network Profile")
+    submit_url = reverse_lazy(
+        "horizon:router:nexus1000v:create_network_profile")
+    success_url = reverse_lazy('horizon:router:nexus1000v:index')
+    page_title = _("Create Network Profile")
 
 
 class UpdateNetworkProfileView(forms.ModalFormView):
     form_class = profileforms.UpdateNetworkProfile
+    form_id = "update_network_profile_form"
+    modal_header = _("Edit Network Profile")
     template_name = 'router/nexus1000v/update_network_profile.html'
     context_object_name = 'network_profile'
-    success_url = urlresolvers.reverse_lazy('horizon:router:nexus1000v:index')
+    submit_label = _("Save Changes")
+    submit_url = "horizon:router:nexus1000v:update_network_profile"
+    success_url = reverse_lazy('horizon:router:nexus1000v:index')
+    page_title = _("Update Network Profile")
 
     def get_context_data(self, **kwargs):
         context = super(UpdateNetworkProfileView,
                         self).get_context_data(**kwargs)
         context["profile_id"] = self.kwargs['profile_id']
+        args = (self.kwargs['profile_id'],)
+        context['submit_url'] = reverse(self.submit_url, args=args)
         return context
 
     @memoized.memoized_method
