@@ -55,7 +55,8 @@ class NeutronApiTests(test.APITestCase):
         network = {'network': self.api_networks.first()}
 
         neutronclient = self.stub_neutronclient()
-        form_data = {'network': {'name': 'net1'}}
+        form_data = {'network': {'name': 'net1',
+                                 'tenant_id': self.request.user.project_id}}
         neutronclient.create_network(body=form_data).AndReturn(network)
         self.mox.ReplayAll()
 
@@ -169,21 +170,46 @@ class NeutronApiTests(test.APITestCase):
         ret_val = api.neutron.port_get(self.request, port_id)
         self.assertIsInstance(ret_val, api.neutron.Port)
 
-    def test_port_create(self):
-        port_data = self.api_ports.first()
-        params = {'network_id': port_data['network_id'],
-                  'tenant_id': port_data['tenant_id'],
-                  'name': port_data['name'],
-                  'device_id': port_data['device_id']}
+    def _test_port_create(self, with_n1kv=False):
+        port = {'port': self.api_ports.first()}
+        params = {'network_id': port['port']['network_id'],
+                  'tenant_id': port['port']['tenant_id'],
+                  'name': port['port']['name'],
+                  'device_id': port['port']['device_id']}
 
         neutronclient = self.stub_neutronclient()
-        neutronclient.create_port(body={'port': params})\
-            .AndReturn({'port': port_data})
-        self.mox.ReplayAll()
-
-        ret_val = api.neutron.port_create(self.request, **params)
+        if with_n1kv:
+            n1kv_profile = 'n1kv:profile'
+            test_policy_profile = 'test_policy_profile'
+            port['port'][n1kv_profile] = test_policy_profile
+            body = {k: v for (k, v) in params.items()}
+            body[n1kv_profile] = port['port'][n1kv_profile]
+            neutronclient.create_port(body={'port': body}).AndReturn(port)
+            self.mox.ReplayAll()
+            ret_val = api.neutron.port_create(
+                self.request,
+                policy_profile_id=test_policy_profile,
+                **params)
+            # assert that when 'policy_profile_id' is passed as a param to
+            # port_create function, 'n1kv:profile' is appended as a key to the
+            # returned port dictionary with value TEST_POLICY_PROFILE
+            self.assertEqual(test_policy_profile, ret_val[n1kv_profile])
+            # also assert that 'policy_profile_id' isn't there in the returned
+            # port dictionary
+            self.assertNotIn('policy_profile_id',
+                             [k for k, _ in ret_val.items()])
+        else:
+            neutronclient.create_port(body={'port': params}).AndReturn(port)
+            self.mox.ReplayAll()
+            ret_val = api.neutron.port_create(self.request, **params)
         self.assertIsInstance(ret_val, api.neutron.Port)
-        self.assertEqual(api.neutron.Port(port_data).id, ret_val.id)
+        self.assertEqual(api.neutron.Port(port['port']).id, ret_val.id)
+
+    def test_port_create(self):
+        self._test_port_create()
+
+    def test_port_create_with_policy_profile(self):
+        self._test_port_create(with_n1kv=True)
 
     def test_port_update(self):
         port_data = self.api_ports.first()
@@ -235,7 +261,8 @@ class NeutronApiTests(test.APITestCase):
         router = {'router': self.api_routers.first()}
 
         neutronclient = self.stub_neutronclient()
-        form_data = {'router': {'name': 'router1'}}
+        form_data = {'router': {'name': 'router1',
+                                'tenant_id': self.request.user.project_id}}
         neutronclient.create_router(body=form_data).AndReturn(router)
         self.mox.ReplayAll()
 
@@ -400,7 +427,7 @@ class NeutronApiTests(test.APITestCase):
         # filter. It generates about 40*10 char length URI.
         # Each port ID is converted to "id=<UUID>&" in URI and
         # it means 40 chars (len(UUID)=36).
-        # If excess lenght is 220, it means 400-220=180 chars
+        # If excess length is 220, it means 400-220=180 chars
         # can be sent in the first request.
         # As a result three API calls with 4, 4, 2 port ID
         # are expected.
