@@ -28,6 +28,11 @@ from openstack_dashboard.utils import settings as util_settings
 HORIZON_CONFIG = copy.deepcopy(settings.HORIZON_CONFIG)
 INSTALLED_APPS = list(settings.INSTALLED_APPS)
 
+# NOTE: Ensure dashboards and default_dashboard are not included in
+# HORIZON_CONFIG to ensure warning messages from update_dashboards below.
+HORIZON_CONFIG.pop('dashboards', None)
+HORIZON_CONFIG.pop('default_dashboard', None)
+
 util_settings.update_dashboards([
     openstack_dashboard.test.test_plugins.panel_config,
 ], HORIZON_CONFIG, INSTALLED_APPS)
@@ -38,13 +43,23 @@ util_settings.update_dashboards([
 class PanelPluginTests(test.PluginTestCase):
     def test_add_panel(self):
         dashboard = horizon.get_dashboard("admin")
+        panel_group = dashboard.get_panel_group('admin')
+        # Check that the panel is in its configured dashboard.
         self.assertIn(plugin_panel.PluginPanel,
                       [p.__class__ for p in dashboard.get_panels()])
+        # Check that the panel is in its configured panel group.
+        self.assertIn(plugin_panel.PluginPanel,
+                      [p.__class__ for p in panel_group])
 
     def test_remove_panel(self):
         dashboard = horizon.get_dashboard("admin")
+        panel_group = dashboard.get_panel_group('admin')
+        # Check that the panel is no longer in the configured dashboard.
         self.assertNotIn(info_panel.Info,
                          [p.__class__ for p in dashboard.get_panels()])
+        # Check that the panel is no longer in the configured panel group.
+        self.assertNotIn(info_panel.Info,
+                         [p.__class__ for p in panel_group])
 
     def test_default_panel(self):
         dashboard = horizon.get_dashboard("admin")
