@@ -167,18 +167,56 @@ def get_tenant_quota_data(request, disabled_quotas=None, tenant_id=None):
     # TODO(jpichon): There is no API to get the default system quotas
     # in Neutron (cf. LP#1204956), so for now handle tenant quotas here.
     # This should be handled in _get_quota_data() eventually.
-    if disabled_quotas and 'floating_ips' in disabled_quotas:
+    if not disabled_quotas:
+        return qs
+
+    # Check if neutron is enabled by looking for network and router
+    if 'network' and 'router' not in disabled_quotas:
+        tenant_id = tenant_id or request.user.tenant_id
+        neutron_quotas = neutron.tenant_quota_get(request, tenant_id)
+    if 'floating_ips' in disabled_quotas:
         # Neutron with quota extension disabled
         if 'floatingip' in disabled_quotas:
             qs.add(base.QuotaSet({'floating_ips': -1}))
         # Neutron with quota extension enabled
         else:
-            tenant_id = tenant_id or request.user.tenant_id
-            neutron_quotas = neutron.tenant_quota_get(request, tenant_id)
             # Rename floatingip to floating_ips since that's how it's
             # expected in some places (e.g. Security & Access' Floating IPs)
             fips_quota = neutron_quotas.get('floatingip').limit
             qs.add(base.QuotaSet({'floating_ips': fips_quota}))
+    if 'security_groups' in disabled_quotas:
+        if 'security_group' in disabled_quotas:
+            qs.add(base.QuotaSet({'security_groups': -1}))
+        # Neutron with quota extension enabled
+        else:
+            # Rename security_group to security_groups since that's how it's
+            # expected in some places (e.g. Security & Access' Security Groups)
+            sec_quota = neutron_quotas.get('security_group').limit
+            qs.add(base.QuotaSet({'security_groups': sec_quota}))
+    if 'network' in disabled_quotas:
+        for item in qs.items:
+            if item.name == 'networks':
+                qs.items.remove(item)
+                break
+    else:
+        net_quota = neutron_quotas.get('network').limit
+        qs.add(base.QuotaSet({'networks': net_quota}))
+    if 'subnet' in disabled_quotas:
+        for item in qs.items:
+            if item.name == 'subnets':
+                qs.items.remove(item)
+                break
+    else:
+        net_quota = neutron_quotas.get('subnet').limit
+        qs.add(base.QuotaSet({'subnets': net_quota}))
+    if 'router' in disabled_quotas:
+        for item in qs.items:
+            if item.name == 'routers':
+                qs.items.remove(item)
+                break
+    else:
+        router_quota = neutron_quotas.get('router').limit
+        qs.add(base.QuotaSet({'routers': router_quota}))
 
     return qs
 
@@ -214,27 +252,7 @@ def get_disabled_quotas(request):
     return disabled_quotas
 
 
-@memoized
-def tenant_quota_usages(request, tenant_id=None):
-    """Get our quotas and construct our usage object."""
-
-    disabled_quotas = get_disabled_quotas(request)
-
-    usages = QuotaUsage()
-    for quota in get_tenant_quota_data(request,
-                                       disabled_quotas=disabled_quotas,
-                                       tenant_id=tenant_id):
-        usages.add_quota(quota)
-
-    # Get our usages.
-    floating_ips = []
-    try:
-        if network.floating_ip_supported(request):
-            floating_ips = network.tenant_floating_ip_list(request)
-    except Exception:
-        pass
-    flavors = dict([(f.id, f) for f in nova.flavor_list(request)])
-
+def _get_tenant_compute_usages(request, usages, disabled_quotas, tenant_id):
     if tenant_id:
         instances, has_more = nova.server_list(
             request, search_opts={'tenant_id': tenant_id}, all_tenants=True)
@@ -242,6 +260,7 @@ def tenant_quota_usages(request, tenant_id=None):
         instances, has_more = nova.server_list(request)
 
     # Fetch deleted flavors if necessary.
+    flavors = dict([(f.id, f) for f in nova.flavor_list(request)])
     missing_flavors = [instance.flavor['id'] for instance in instances
                        if instance.flavor['id'] not in flavors]
     for missing in missing_flavors:
@@ -253,8 +272,53 @@ def tenant_quota_usages(request, tenant_id=None):
                 exceptions.handle(request, ignore=True)
 
     usages.tally('instances', len(instances))
+
+    # Sum our usage based on the flavors of the instances.
+    for flavor in [flavors[instance.flavor['id']] for instance in instances]:
+        usages.tally('cores', getattr(flavor, 'vcpus', None))
+        usages.tally('ram', getattr(flavor, 'ram', None))
+
+    # Initialise the tally if no instances have been launched yet
+    if len(instances) == 0:
+        usages.tally('cores', 0)
+        usages.tally('ram', 0)
+
+
+def _get_tenant_network_usages(request, usages, disabled_quotas, tenant_id):
+    floating_ips = []
+    try:
+        if network.floating_ip_supported(request):
+            floating_ips = network.tenant_floating_ip_list(request)
+    except Exception:
+        pass
     usages.tally('floating_ips', len(floating_ips))
 
+    if 'security_group' not in disabled_quotas:
+        security_groups = []
+        security_groups = network.security_group_list(request)
+        usages.tally('security_groups', len(security_groups))
+
+    if 'network' not in disabled_quotas:
+        networks = []
+        networks = neutron.network_list(request, shared=False)
+        if tenant_id:
+            networks = filter(lambda net: net.tenant_id == tenant_id, networks)
+        usages.tally('networks', len(networks))
+
+    if 'subnet' not in disabled_quotas:
+        subnets = []
+        subnets = neutron.subnet_list(request)
+        usages.tally('subnets', len(subnets))
+
+    if 'router' not in disabled_quotas:
+        routers = []
+        routers = neutron.router_list(request)
+        if tenant_id:
+            routers = filter(lambda rou: rou.tenant_id == tenant_id, routers)
+        usages.tally('routers', len(routers))
+
+
+def _get_tenant_volume_usages(request, usages, disabled_quotas, tenant_id):
     if 'volumes' not in disabled_quotas:
         if tenant_id:
             opts = {'alltenants': 1, 'tenant_id': tenant_id}
@@ -267,15 +331,28 @@ def tenant_quota_usages(request, tenant_id=None):
         usages.tally('volumes', len(volumes))
         usages.tally('snapshots', len(snapshots))
 
-    # Sum our usage based on the flavors of the instances.
-    for flavor in [flavors[instance.flavor['id']] for instance in instances]:
-        usages.tally('cores', getattr(flavor, 'vcpus', None))
-        usages.tally('ram', getattr(flavor, 'ram', None))
 
-    # Initialise the tally if no instances have been launched yet
-    if len(instances) == 0:
-        usages.tally('cores', 0)
-        usages.tally('ram', 0)
+@memoized
+def tenant_quota_usages(request, tenant_id=None):
+    """Get our quotas and construct our usage object.
+    If no tenant_id is provided, a the request.user.project_id
+    is assumed to be used
+    """
+    if not tenant_id:
+        tenant_id = request.user.project_id
+
+    disabled_quotas = get_disabled_quotas(request)
+    usages = QuotaUsage()
+
+    for quota in get_tenant_quota_data(request,
+                                       disabled_quotas=disabled_quotas,
+                                       tenant_id=tenant_id):
+        usages.add_quota(quota)
+
+    # Get our usages.
+    _get_tenant_compute_usages(request, usages, disabled_quotas, tenant_id)
+    _get_tenant_network_usages(request, usages, disabled_quotas, tenant_id)
+    _get_tenant_volume_usages(request, usages, disabled_quotas, tenant_id)
 
     return usages
 
